b=('kkwem','kkweb','kkwebs','kkwes','kkwess','kkweng','kkwej','kkwech','kkwek','kkwet','kkwep','kkweh','kkwi','kkwig','kkwikk','kkwigs','kkwin','kkwinj','kkwinh','kkwid','kkwil','kkwilg','kkwilm','kkwilb','kkwils','kkwilt','kkwilp','kkwilh','kkwim','kkwib','kkwibs','kkwis','kkwiss','kkwing','kkwij','kkwich','kkwik','kkwit','kkwip','kkwih','kkyu','kkyug','kkyukk','kkyugs','kkyun','kkyunj','kkyunh','kkyud','kkyul','kkyulg','kkyulm','kkyulb','kkyuls','kkyult','kkyulp','kkyulh','kkyum','kkyub','kkyubs','kkyus','kkyuss','kkyung','kkyuj','kkyuch','kkyuk','kkyut','kkyup','kkyuh','kkeu','kkeug','kkeukk','kkeugs','kkeun','kkeunj','kkeunh','kkeud','kkeul','kkeulg','kkeulm','kkeulb','kkeuls','kkeult','kkeulp','kkeulh','kkeum','kkeub','kkeubs','kkeus','kkeuss','kkeung','kkeuj','kkeuch','kkeuk','kkeut','kkeup','kkeuh','kkui','kkuig','kkuikk','kkuigs','kkuin','kkuinj','kkuinh','kkuid','kkuil','kkuilg','kkuilm','kkuilb','kkuils','kkuilt','kkuilp','kkuilh','kkuim','kkuib','kkuibs','kkuis','kkuiss','kkuing','kkuij','kkuich','kkuik','kkuit','kkuip','kkuih','kki','kkig','kkikk','kkigs','kkin','kkinj','kkinh','kkid','kkil','kkilg','kkilm','kkilb','kkils','kkilt','kkilp','kkilh','kkim','kkib','kkibs','kkis','kkiss','kking','kkij','kkich','kkik','kkit','kkip','kkih','na','nag','nakk','nags','nan','nanj','nanh','nad','nal','nalg','nalm','nalb','nals','nalt','nalp','nalh','nam','nab','nabs','nas','nass','nang','naj','nach','nak','nat','nap','nah','nae','naeg','naekk','naegs','naen','naenj','naenh','naed','nael','naelg','naelm','naelb','naels','naelt','naelp','naelh','naem','naeb','naebs','naes','naess','naeng','naej','naech','naek','naet','naep','naeh','nya','nyag','nyakk','nyags','nyan','nyanj','nyanh','nyad','nyal','nyalg','nyalm','nyalb','nyals','nyalt','nyalp','nyalh','nyam','nyab','nyabs','nyas','nyass','nyang','nyaj','nyach','nyak','nyat','nyap','nyah','nyae','nyaeg','nyaekk','nyaegs','nyaen','nyaenj','nyaenh','nyaed','nyael','nyaelg','nyaelm','nyaelb','nyaels','nyaelt','nyaelp','nyaelh','nyaem','nyaeb','nyaebs','nyaes')