b=('Xi','Gao','Lang','Fu','Xun','Shui','Lu','Kun','Gan','Jing','Ti','Cheng','Tu','Shao','Shui','Ya','Lun','Lu','Gu','Zuo','Ren','Zhun','Bang','Bai','Ji','Zhi','Zhi','Kun','Leng','Peng','Ke','Bing','Chou','Zui','Yu','Su','Lue','Xiang','Yi','Xi','Bian','Ji','Fu','Pi','Nuo','Jie','Zhong','Zong','Xu','Cheng','Dao','Wen','Xian','Zi','Yu','Ji','Xu','Zhen','Zhi','Dao','Jia','Ji','Gao','Gao','Gu','Rong','Sui','Rong','Ji','Kang','Mu','Can','Mei','Zhi','Ji','Lu','Su','Ji','Ying','Wen','Qiu','Se','He','Yi','Huang','Qie','Ji','Sui','Xiao','Pu','Jiao','Zhuo','Zhong','Zui','Lu','Sui','Nong','Se','Hui','Rang','Nuo','Yu','Pin','Ji','Tui','Wen','Cheng','Huo','Kuang','Lu','Biao','Se','Rang','Zhuo','Li','Cuan','Xue','Wa','Jiu','Qiong','Xi','Qiong','Kong','Yu','Shen','Jing','Yao','Chuan','Zhun','Tu','Lao','Qie','Zhai','Yao','Bian','Bao','Yao','Bing','Wa','Zhu','Jiao','Qiao','Diao','Wu','Gui','Yao','Zhi','Chuang','Yao','Tiao','Jiao','Chuang','Jiong','Xiao','Cheng','Kou','Cuan','Wo','Dan','Ku','Ke','Zhuo','Xu','Su','Guan','Kui','Dou','Zhuo','Xun','Wo','Wa','Ya','Yu','Ju','Qiong','Yao','Yao','Tiao','Chao','Yu','Tian','Diao','Ju','Liao','Xi','Wu','Kui','Chuang','Zhao','Kuan','Kuan','Long','Cheng','Cui','Liao','Zao','Cuan','Qiao','Qiong','Dou','Zao','Long','Qie','Li','Chu','Shi','Fu','Qian','Chu','Hong','Qi','Hao','Sheng','Fen','Shu','Miao','Qu','Zhan','Zhu','Ling','Long','Bing','Jing','Jing','Zhang','Bai','Si','Jun','Hong','Tong','Song','Jing','Diao','Yi','Shu','Jing','Qu','Jie','Ping','Duan','Li','Zhuan','Ceng','Deng','Cun','Wai','Jing','Kan','Jing','Zhu','Zhu','Le','Peng','Yu','Chi','Gan')