b=('nzup','nzurx','nzur','nzyt','nzyx','nzy','nzyp','nzyrx','nzyr','sit','six','si','sip','siex','sie','siep','sat','sax','sa','sap','suox','suo','suop','sot','sox','so','sop','sex','se','sep','sut','sux','su','sup','surx','sur','syt','syx','sy','syp','syrx','syr','ssit','ssix','ssi','ssip','ssiex','ssie','ssiep','ssat','ssax','ssa','ssap','ssot','ssox','sso','ssop','ssex','sse','ssep','ssut','ssux','ssu','ssup','ssyt','ssyx','ssy','ssyp','ssyrx','ssyr','zhat','zhax','zha','zhap','zhuox','zhuo','zhuop','zhot','zhox','zho','zhop','zhet','zhex','zhe','zhep','zhut','zhux','zhu','zhup','zhurx','zhur','zhyt','zhyx','zhy','zhyp','zhyrx','zhyr','chat','chax','cha','chap','chuot','chuox','chuo','chuop','chot','chox','cho','chop','chet','chex','che','chep','chux','chu','chup','churx','chur','chyt','chyx','chy','chyp','chyrx','chyr','rrax','rra','rruox','rruo','rrot','rrox','rro','rrop','rret','rrex','rre','rrep','rrut','rrux','rru','rrup','rrurx','rrur','rryt','rryx','rry','rryp','rryrx','rryr','nrat','nrax','nra','nrap','nrox','nro','nrop','nret','nrex','nre','nrep','nrut','nrux','nru','nrup','nrurx','nrur','nryt','nryx','nry','nryp','nryrx','nryr','shat','shax','sha','shap','shuox','shuo','shuop','shot','shox','sho','shop','shet','shex','she','shep','shut','shux','shu','shup','shurx','shur','shyt','shyx','shy','shyp','shyrx','shyr','rat','rax','ra','rap','ruox','ruo','ruop','rot','rox','ro','rop','rex','re','rep','rut','rux','ru','rup','rurx','rur','ryt','ryx','ry','ryp','ryrx','ryr','jit','jix','ji','jip','jiet','jiex','jie','jiep','juot','juox','juo','juop','jot','jox','jo','jop','jut','jux','ju','jup','jurx','jur','jyt','jyx','jy','jyp','jyrx','jyr','qit','qix','qi','qip')