b=('Chan','Ge','Lou','Zong','Gen','Jiao','Gou','Qin','Rong','Que','Chou','Chuai','Zhan','Sun','Sun','Bo','Chu','Rong','Bang','Cuo','Sao','Ke','Yao','Dao','Zhi','Nu','La','Jian','Sou','Qiu','Gao','Xian','Shuo','Sang','Jin','Mie','E','Chui','Nuo','Shan','Ta','Zha','Tang','Pan','Ban','Da','Li','Tao','Hu','Zhi','Wa','Hua','Qian','Wen','Qiang','Tian','Zhen','E','Xie','Nuo','Quan','Cha','Zha','Ge','Wu','En','She','Kang','She','Shu','Bai','Yao','Bin','Sou','Tan','Sa','Chan','Suo','Jiu','Chong','Chuang','Guai','Bing','Feng','Shuai','Di','Qi','Sou','Zhai','Lian','Cheng','Chi','Guan','Lu','Luo','Lou','Zong','Gai','Hu','Zha','Chuang','Tang','Hua','Cui','Nai','Mo','Jiang','Gui','Ying','Zhi','Ao','Zhi','Nie','Man','Chan','Kou','Chu','She','Tuan','Jiao','Mo','Mo','Zhe','Can','Keng','Biao','Jiang','Yao','Gou','Qian','Liao','Ji','Ying','Jue','Pie','Pie','Lao','Dun','Xian','Ruan','Gui','Zan','Yi','Xian','Cheng','Cheng','Sa','Nao','Hong','Si','Han','Guang','Da','Zun','Nian','Lin','Zheng','Hui','Zhuang','Jiao','Ji','Cao','Dan','Dan','Che','Bo','Che','Jue','Fu','Liao','Ben','Fu','Qiao','Bo','Cuo','Zhuo','Zhuan','Wei','Pu','Qin','Dun','Nian','Hua','Xie','Lu','Jiao','Cuan','Ta','Han','Qiao','Wo','Jian','Gan','Yong','Lei','Nang','Lu','Shan','Zhuo','Ze','Pu','Chuo','Ji','Dang','Se','Cao','Qing','Qing','Huan','Jie','Qin','Kuai','Dan','Xie','Ka','Pi','Bai','Ao','Ju','Ye','E','Meng','Sou','Mi','Ji','Tai','Zhuo','Dao','Xing','Lan','Ca','Ju','Ye','Ru','Ye','Ye','Ni','Wo','Jie','Bin','Ning','Ge','Zhi','Zhi','Kuo','Mo','Jian','Xie','Lie','Tan','Bai','Sou','Lu','Lue','Rao','Ti')