b=('Ci','Xiang','She','Luo','Qin','Ying','Chai','Li','Zei','Xuan','Lian','Zhu','Ze','Xie','Mang','Xie','Qi','Rong','Jian','Meng','Hao','Ru','Huo','Zhuo','Jie','Pin','He','Mie','Fan','Lei','Jie','La','Min','Li','Chun','Li','Qiu','Nie','Lu','Du','Xiao','Zhu','Long','Li','Long','Feng','Ye','Pi','Nang','Gu','Juan','Ying','Shu','Xi','Can','Qu','Quan','Du','Can','Man','Qu','Jie','Zhu','Zhuo','Xue','Huang','Nu','Pei','Nu','Xin','Zhong','Mai','Er','Ka','Mie','Xi','Xing','Yan','Kan','Yuan','Qu','Ling','Xuan','Shu','Xian','Tong','Xiang','Jie','Xian','Ya','Hu','Wei','Dao','Chong','Wei','Dao','Zhun','Heng','Qu','Yi','Yi','Bu','Gan','Yu','Biao','Cha','Yi','Shan','Chen','Fu','Gun','Fen','Shuai','Jie','Na','Zhong','Dan','Yi','Zhong','Zhong','Jie','Zhi','Xie','Ran','Zhi','Ren','Qin','Jin','Jun','Yuan','Mei','Chai','Ao','Niao','Hui','Ran','Jia','Tuo','Ling','Dai','Bao','Pao','Yao','Zuo','Bi','Shao','Tan','Ju','He','Xue','Xiu','Zhen','Yi','Pa','Bo','Di','Wa','Fu','Gun','Zhi','Zhi','Ran','Pan','Yi','Mao','Tuo','Na','Gou','Xuan','Zhe','Qu','Bei','Yu','Xi','Mi','Bo','Bo','Fu','Chi','Chi','Ku','Ren','Jiang','Jia','Jian','Bo','Jie','Er','Ge','Ru','Zhu','Gui','Yin','Cai','Lie','Ka','Xing','Zhuang','Dang','Xu','Kun','Ken','Niao','Shu','Jia','Kun','Cheng','Li','Juan','Shen','Pou','Ge','Yi','Yu','Zhen','Liu','Qiu','Qun','Ji','Yi','Bu','Zhuang','Shui','Sha','Qun','Li','Lian','Lian','Ku','Jian','Fou','Chan','Bi','Kun','Tao','Yuan','Ling','Chi','Chang','Chou','Duo','Biao','Liang','Shang','Pei','Pei','Fei','Yuan','Luo','Guo','Yan','Du','Ti','Zhi','Ju','Yi')