b=('Zhui','Zi','Ke','Xiang','Jian','Mian','Lan','Ti','Miao','Ji','Yun','Hui','Si','Duo','Duan','Bian','Xian','Gou','Zhui','Huan','Di','Lu','Bian','Min','Yuan','Jin','Fu','Ru','Zhen','Feng','Cui','Gao','Chan','Li','Yi','Jian','Bin','Piao','Man','Lei','Ying','Suo','Mou','Sao','Xie','Liao','Shan','Zeng','Jiang','Qian','Qiao','Huan','Jiao','Zuan','Fou','Xie','Gang','Fou','Que','Fou','Qi','Bo','Ping','Xiang','Zhao','Gang','Ying','Ying','Qing','Xia','Guan','Zun','Tan','Cheng','Qi','Weng','Ying','Lei','Tan','Lu','Guan','Wang','Wang','Gang','Wang','Han','Luo','Luo','Fu','Shen','Fa','Gu','Zhu','Ju','Mao','Gu','Min','Gang','Ba','Gua','Ti','Juan','Fu','Shen','Yan','Zhao','Zui','Gua','Zhuo','Yu','Zhi','An','Fa','Lan','Shu','Si','Pi','Ma','Liu','Ba','Fa','Li','Chao','Wei','Bi','Ji','Zeng','Chong','Liu','Ji','Juan','Mi','Zhao','Luo','Pi','Ji','Ji','Luan','Yang','Mi','Qiang','Da','Mei','Yang','You','You','Fen','Ba','Gao','Yang','Gu','Qiang','Zang','Gao','Ling','Yi','Zhu','Di','Xiu','Qiang','Yi','Xian','Rong','Qun','Qun','Qiang','Huan','Suo','Xian','Yi','Yang','Qiang','Qian','Yu','Geng','Jie','Tang','Yuan','Xi','Fan','Shan','Fen','Shan','Lian','Lei','Geng','Nou','Qiang','Chan','Yu','Gong','Yi','Chong','Weng','Fen','Hong','Chi','Chi','Cui','Fu','Xia','Ben','Yi','La','Yi','Pi','Ling','Liu','Zhi','Qu','Xi','Xie','Xiang','Xi','Xi','Ke','Qiao','Hui','Hui','Xiao','Sha','Hong','Jiang','Di','Cui','Fei','Dao','Sha','Chi','Zhu','Jian','Xuan','Chi','Pian','Zong','Wan','Hui','Hou','He','He','Han','Ao','Piao','Yi','Lian','Hou','Ao','Lin','Pen','Qiao','Ao','Fan','Yi','Hui','Xuan','Dao')