b=('You','Yang','Lu','Si','Zhi','Ying','Du','Wang','Hui','Xie','Pan','Shen','Biao','Chan','Mo','Liu','Jian','Pu','Se','Cheng','Gu','Bin','Huo','Xian','Lu','Qin','Han','Ying','Rong','Li','Jing','Xiao','Ying','Sui','Wei','Xie','Huai','Xue','Zhu','Long','Lai','Dui','Fan','Hu','Lai','Shu','Ling','Ying','Mi','Ji','Lian','Jian','Ying','Fen','Lin','Yi','Jian','Yue','Chan','Dai','Rang','Jian','Lan','Fan','Shuang','Yuan','Zhuo','Feng','She','Lei','Lan','Cong','Qu','Yong','Qian','Fa','Guan','Jue','Yan','Hao','Ying','Sa','Zan','Luan','Yan','Li','Mi','Shan','Tan','Dang','Jiao','Chan','Ying','Hao','Ba','Zhu','Lan','Lan','Nang','Wan','Luan','Xun','Xian','Yan','Gan','Yan','Yu','Huo','Biao','Mie','Guang','Deng','Hui','Xiao','Xiao','Hui','Hong','Ling','Zao','Zhuan','Jiu','Zha','Xie','Chi','Zhuo','Zai','Zai','Can','Yang','Qi','Zhong','Fen','Niu','Jiong','Wen','Pu','Yi','Lu','Chui','Pi','Kai','Pan','Yan','Kai','Pang','Mu','Chao','Liao','Gui','Kang','Dun','Guang','Xin','Zhi','Guang','Guang','Wei','Qiang','Bian','Da','Xia','Zheng','Zhu','Ke','Zhao','Fu','Ba','Xie','Xie','Ling','Zhuo','Xuan','Ju','Tan','Pao','Jiong','Pao','Tai','Tai','Bing','Yang','Tong','Shan','Zhu','Zha','Dian','Wei','Shi','Lian','Chi','Huang','Zhou','Hu','Shuo','Lan','Ting','Jiao','Xu','Heng','Quan','Lie','Huan','Yang','Xiu','Xiu','Xian','Yin','Wu','Zhou','Yao','Shi','Wei','Tong','Mie','Zai','Kai','Hong','Lao','Xia','Zhu','Xuan','Zheng','Po','Yan','Hui','Guang','Che','Hui','Kao','Ju','Fan','Shao','Ye','Hui','','Tang','Jin','Re','Lie','Xi','Fu','Jiong','Xie','Pu','Ting','Zhuo','Ting','Wan','Hai','Peng','Lang','Yan','Xu','Feng','Chi','Rong')