b=('syon','syonj','syonh','syod','syol','syolg','syolm','syolb','syols','syolt','syolp','syolh','syom','syob','syobs','syos','syoss','syong','syoj','syoch','syok','syot','syop','syoh','su','sug','sukk','sugs','sun','sunj','sunh','sud','sul','sulg','sulm','sulb','suls','sult','sulp','sulh','sum','sub','subs','sus','suss','sung','suj','such','suk','sut','sup','suh','swo','swog','swokk','swogs','swon','swonj','swonh','swod','swol','swolg','swolm','swolb','swols','swolt','swolp','swolh','swom','swob','swobs','swos','swoss','swong','swoj','swoch','swok','swot','swop','swoh','swe','sweg','swekk','swegs','swen','swenj','swenh','swed','swel','swelg','swelm','swelb','swels','swelt','swelp','swelh','swem','sweb','swebs','swes','swess','sweng','swej','swech','swek','swet','swep','sweh','swi','swig','swikk','swigs','swin','swinj','swinh','swid','swil','swilg','swilm','swilb','swils','swilt','swilp','swilh','swim','swib','swibs','swis','swiss','swing','swij','swich','swik','swit','swip','swih','syu','syug','syukk','syugs','syun','syunj','syunh','syud','syul','syulg','syulm','syulb','syuls','syult','syulp','syulh','syum','syub','syubs','syus','syuss','syung','syuj','syuch','syuk','syut','syup','syuh','seu','seug','seukk','seugs','seun','seunj','seunh','seud','seul','seulg','seulm','seulb','seuls','seult','seulp','seulh','seum','seub','seubs','seus','seuss','seung','seuj','seuch','seuk','seut','seup','seuh','sui','suig','suikk','suigs','suin','suinj','suinh','suid','suil','suilg','suilm','suilb','suils','suilt','suilp','suilh','suim','suib','suibs','suis','suiss','suing','suij','suich','suik','suit','suip','suih','si','sig','sikk','sigs','sin','sinj','sinh','sid','sil','silg','silm','silb','sils','silt','silp','silh','sim','sib','sibs','sis','siss','sing','sij','sich','sik','sit','sip','sih','ssa','ssag','ssakk','ssags','ssan','ssanj','ssanh','ssad')