b=('Zui','Can','Xu','Hui','Yin','Qie','Fen','Pi','Yue','You','Ruan','Peng','Fen','Fu','Ling','Fei','Qu','Ti','Nu','Tiao','Shuo','Zhen','Lang','Lang','Zui','Ming','Huang','Wang','Tun','Chao','Ji','Qi','Ying','Zong','Wang','Tong','Lang','Lao','Meng','Long','Mu','Deng','Wei','Mo','Ben','Zha','Shu','Shu','Mu','Zhu','Ren','Ba','Pu','Duo','Duo','Dao','Li','Gui','Ji','Jiu','Bi','Xiu','Cheng','Ci','Sha','Ru','Za','Quan','Qian','Yu','Gan','Wu','Cha','Shan','Xun','Fan','Wu','Zi','Li','Xing','Cai','Cun','Ren','Biao','Tuo','Di','Zhang','Mang','Chi','Yi','Gai','Gong','Du','Li','Qi','Shu','Gang','Tiao','Jiang','Mian','Wan','Lai','Jiu','Mang','Yang','Ma','Miao','Si','Yuan','Hang','Fei','Bei','Jie','Dong','Gao','Yao','Xian','Chu','Chun','Pa','Shu','Hua','Xin','Chou','Zhu','Chou','Song','Ban','Song','Ji','Wo','Jin','Gou','Ji','Mao','Pi','Bi','Wang','Ang','Fang','Fen','Yi','Fu','Nan','Xi','Hu','Ya','Dou','Xin','Zhen','Yao','Lin','Rui','E','Mei','Zhao','Guo','Zhi','Cong','Yun','Zui','Sheng','Shu','Zao','Di','Li','Lu','Jian','Cheng','Song','Qiang','Feng','Zhan','Xiao','Xian','Ku','Ping','Tai','Xi','Zhi','Guai','Xiao','Jia','Jia','Gou','Bao','Mo','Yi','Ye','Ye','Shi','Nie','Bi','Duo','Yi','Ling','Bing','Ni','La','He','Ban','Fan','Zhong','Dai','Ci','Yang','Fu','Bai','Mou','Gan','Qi','Ran','Rou','Mao','Shao','Song','Zhe','Xia','You','Shen','Gui','Tuo','Zha','Nan','Ning','Yong','Di','Zhi','Zha','Cha','Dan','Gu','Bu','Jiu','Ao','Fu','Jian','Ba','Duo','Ke','Nai','Zhu','Bi','Liu','Chai','Shan','Si','Chu','Pei','Shi','Guai','Zha','Yao','Cheng','Jiu','Shi')