b=('duil','duilg','duilm','duilb','duils','duilt','duilp','duilh','duim','duib','duibs','duis','duiss','duing','duij','duich','duik','duit','duip','duih','di','dig','dikk','digs','din','dinj','dinh','did','dil','dilg','dilm','dilb','dils','dilt','dilp','dilh','dim','dib','dibs','dis','diss','ding','dij','dich','dik','dit','dip','dih','tta','ttag','ttakk','ttags','ttan','ttanj','ttanh','ttad','ttal','ttalg','ttalm','ttalb','ttals','ttalt','ttalp','ttalh','ttam','ttab','ttabs','ttas','ttass','ttang','ttaj','ttach','ttak','ttat','ttap','ttah','ttae','ttaeg','ttaekk','ttaegs','ttaen','ttaenj','ttaenh','ttaed','ttael','ttaelg','ttaelm','ttaelb','ttaels','ttaelt','ttaelp','ttaelh','ttaem','ttaeb','ttaebs','ttaes','ttaess','ttaeng','ttaej','ttaech','ttaek','ttaet','ttaep','ttaeh','ttya','ttyag','ttyakk','ttyags','ttyan','ttyanj','ttyanh','ttyad','ttyal','ttyalg','ttyalm','ttyalb','ttyals','ttyalt','ttyalp','ttyalh','ttyam','ttyab','ttyabs','ttyas','ttyass','ttyang','ttyaj','ttyach','ttyak','ttyat','ttyap','ttyah','ttyae','ttyaeg','ttyaekk','ttyaegs','ttyaen','ttyaenj','ttyaenh','ttyaed','ttyael','ttyaelg','ttyaelm','ttyaelb','ttyaels','ttyaelt','ttyaelp','ttyaelh','ttyaem','ttyaeb','ttyaebs','ttyaes','ttyaess','ttyaeng','ttyaej','ttyaech','ttyaek','ttyaet','ttyaep','ttyaeh','tteo','tteog','tteokk','tteogs','tteon','tteonj','tteonh','tteod','tteol','tteolg','tteolm','tteolb','tteols','tteolt','tteolp','tteolh','tteom','tteob','tteobs','tteos','tteoss','tteong','tteoj','tteoch','tteok','tteot','tteop','tteoh','tte','tteg','ttekk','ttegs','tten','ttenj','ttenh','tted','ttel','ttelg','ttelm','ttelb','ttels','ttelt','ttelp','ttelh','ttem','tteb','ttebs','ttes','ttess','tteng','ttej','ttech','ttek','ttet','ttep','tteh','ttyeo','ttyeog','ttyeokk','ttyeogs','ttyeon','ttyeonj','ttyeonh','ttyeod','ttyeol','ttyeolg','ttyeolm','ttyeolb','ttyeols','ttyeolt','ttyeolp','ttyeolh','ttyeom','ttyeob','ttyeobs','ttyeos','ttyeoss','ttyeong','ttyeoj','ttyeoch','ttyeok','ttyeot','ttyeop','ttyeoh','ttye','ttyeg','ttyekk','ttyegs','ttyen','ttyenj','ttyenh','ttyed','ttyel','ttyelg','ttyelm','ttyelb')