b=('Ti','Li','Bin','Zong','Di','Peng','Song','Zheng','Quan','Zong','Shun','Jian','Tuo','Hu','La','Jiu','Qi','Lian','Zhen','Bin','Peng','Ma','San','Man','Man','Seng','Xu','Lie','Qian','Qian','Nang','Huan','Kuo','Ning','Bin','Lie','Rang','Dou','Dou','Nao','Hong','Xi','Dou','Han','Dou','Dou','Jiu','Chang','Yu','Yu','Ge','Yan','Fu','Qin','Gui','Zong','Liu','Gui','Shang','Yu','Gui','Mei','Ji','Qi','Ga','Kui','Hun','Ba','Po','Mei','Xu','Yan','Xiao','Liang','Yu','Tui','Qi','Wang','Liang','Wei','Gan','Chi','Piao','Bi','Mo','Ji','Xu','Chou','Yan','Zhan','Yu','Dao','Ren','Jie','Ba','Hong','Tuo','Diao','Ji','Xu','E','E','Sha','Hang','Tun','Mo','Jie','Shen','Ban','Yuan','Pi','Lu','Wen','Hu','Lu','Za','Fang','Fen','Na','You','Pian','Mo','He','Xia','Qu','Han','Pi','Ling','Tuo','Bo','Qiu','Ping','Fu','Bi','Ci','Wei','Ju','Diao','Ba','You','Gun','Pi','Nian','Xing','Tai','Bao','Fu','Zha','Ju','Gu','Shi','Dong','Dai','Ta','Jie','Shu','Hou','Xiang','Er','An','Wei','Zhao','Zhu','Yin','Lie','Luo','Tong','Ti','Yi','Bing','Wei','Jiao','Ku','Gui','Xian','Ge','Hui','Lao','Fu','Kao','Xiu','Duo','Jun','Ti','Mian','Shao','Zha','Suo','Qin','Yu','Nei','Zhe','Gun','Geng','Su','Wu','Qiu','Shan','Pu','Huan','Tiao','Li','Sha','Sha','Kao','Meng','Cheng','Li','Zou','Xi','Yong','Shen','Zi','Qi','Zheng','Xiang','Nei','Chun','Ji','Diao','Qie','Gu','Zhou','Dong','Lai','Fei','Ni','Yi','Kun','Lu','Jiu','Chang','Jing','Lun','Ling','Zou','Li','Meng','Zong','Zhi','Nian','Hu','Yu','Di','Shi','Shen','Huan','Ti','Hou','Xing','Zhu','La','Zong','Zei','Bian','Bian')