b=('Yu','Cui','Ya','Zhu','Cu','Dan','Shen','Zhong','Chi','Yu','Hou','Feng','La','Yang','Chen','Tu','Yu','Guo','Wen','Huan','Ku','Jia','Yin','Yi','Lou','Sao','Jue','Chi','Xi','Guan','Yi','Wen','Ji','Chuang','Ban','Hui','Liu','Chai','Shou','Nue','Dian','Da','Bie','Tan','Zhang','Biao','Shen','Cu','Luo','Yi','Zong','Chou','Zhang','Zhai','Sou','Se','Que','Diao','Lou','Lou','Mo','Qin','Yin','Ying','Huang','Fu','Liao','Long','Qiao','Liu','Lao','Xian','Fei','Dan','Yin','He','Ai','Ban','Xian','Guan','Gui','Nong','Yu','Wei','Yi','Yong','Pi','Lei','Li','Shu','Dan','Lin','Dian','Lin','Lai','Bie','Ji','Chi','Yang','Xuan','Jie','Zheng','Me','Li','Huo','Lai','Ji','Dian','Xuan','Ying','Yin','Qu','Yong','Tan','Dian','Luo','Luan','Luan','Bo','Bo','Gui','Ba','Fa','Deng','Fa','Bai','Bai','Qie','Ji','Zao','Zao','Mao','De','Pa','Jie','Huang','Gui','Ci','Ling','Gao','Mo','Ji','Jiao','Peng','Gao','Ai','E','Hao','Han','Bi','Wan','Chou','Qian','Xi','Ai','Xiao','Hao','Huang','Hao','Ze','Cui','Hao','Xiao','Ye','Po','Hao','Jiao','Ai','Xing','Huang','Li','Piao','He','Jiao','Pi','Gan','Pao','Zhou','Jun','Qiu','Cun','Que','Zha','Gu','Jun','Jun','Zhou','Zha','Gu','Zhao','Du','Min','Qi','Ying','Yu','Bei','Zhao','Zhong','Pen','He','Ying','He','Yi','Bo','Wan','He','Ang','Zhan','Yan','Jian','He','Yu','Kui','Fan','Gai','Dao','Pan','Fu','Qiu','Sheng','Dao','Lu','Zhan','Meng','Li','Jin','Xu','Jian','Pan','Guan','An','Lu','Xu','Zhou','Dang','An','Gu','Li','Mu','Ding','Gan','Xu','Mang','Wang','Zhi','Qi','Yuan','Tian','Xiang','Dun','Xin','Xi','Pan','Feng','Dun','Min')