b=('E','Cheng','Xing','Ai','Lu','Zhui','Zhou','She','Pian','Kun','Tao','Lai','Zong','Ke','Qi','Qi','Yan','Fei','Sao','Yan','Ge','Yao','Wu','Pian','Cong','Pian','Qian','Fei','Huang','Qian','Huo','Yu','Ti','Quan','Xia','Zong','Kui','Rou','Si','Gua','Tuo','Gui','Sou','Qian','Cheng','Zhi','Liu','Peng','Teng','Xi','Cao','Du','Yan','Yuan','Zou','Sao','Shan','Qi','Zhi','Shuang','Lu','Xi','Luo','Zhang','Mo','Ao','Can','Biao','Cong','Qu','Bi','Zhi','Yu','Xu','Hua','Bo','Su','Xiao','Lin','Zhan','Dun','Liu','Tuo','Ceng','Dian','Jiao','Tie','Yan','Luo','Zhan','Jing','Yi','Ye','Tuo','Pin','Zhou','Yan','Long','Lu','Teng','Xiang','Ji','Shuang','Ju','Xi','Huan','Li','Biao','Ma','Yu','Tuo','Xun','Chi','Qu','Ri','Bo','Lu','Zang','Shi','Si','Fu','Ju','Zou','Zhu','Tuo','Nu','Jia','Yi','Dai','Xiao','Ma','Yin','Jiao','Hua','Luo','Hai','Pian','Biao','Li','Cheng','Yan','Xing','Qin','Jun','Qi','Qi','Ke','Zhui','Zong','Su','Can','Pian','Zhi','Kui','Sao','Wu','Ao','Liu','Qian','Shan','Biao','Luo','Cong','Chan','Zhou','Ji','Shuang','Xiang','Gu','Wei','Wei','Wei','Yu','Gan','Yi','Ang','Tou','Jie','Bao','Bei','Ci','Ti','Di','Ku','Hai','Qiao','Hou','Kua','Ge','Tui','Geng','Pian','Bi','Ke','Qia','Yu','Sui','Lou','Bo','Xiao','Bang','Bo','Ci','Kuan','Bin','Mo','Liao','Lou','Xiao','Du','Zang','Sui','Ti','Bin','Kuan','Lu','Gao','Gao','Qiao','Kao','Qiao','Lao','Sao','Biao','Kun','Kun','Di','Fang','Xiu','Ran','Mao','Dan','Kun','Bin','Fa','Tiao','Pi','Zi','Fa','Ran','Ti','Bao','Bi','Mao','Fu','Er','Rong','Qu','Gong','Xiu','Kuo','Ji','Peng','Zhua','Shao','Suo')