b=('Song','Wei','Hong','Wa','Lou','Ya','Rao','Jiao','Luan','Ping','Xian','Shao','Li','Cheng','Xie','Mang','Fu','Suo','Mei','Wei','Ke','Chuo','Chuo','Ting','Niang','Xing','Nan','Yu','Na','Pou','Nei','Juan','Shen','Zhi','Han','Di','Zhuang','E','Pin','Tui','Xian','Mian','Wu','Yan','Wu','Ai','Yan','Yu','Si','Yu','Wa','Li','Xian','Ju','Qu','Zhui','Qi','Xian','Zhuo','Dong','Chang','Lu','Ai','E','E','Lou','Mian','Cong','Pou','Ju','Po','Cai','Ling','Wan','Biao','Xiao','Shu','Qi','Hui','Fan','Wo','Rui','Tan','Fei','Fei','Jie','Tian','Ni','Quan','Jing','Hun','Jing','Qian','Dian','Xing','Hu','Wan','Lai','Bi','Yin','Chou','Nao','Fu','Jing','Lun','An','Lan','Kun','Yin','Ya','Ju','Li','Dian','Xian','Hua','Hua','Ying','Chan','Shen','Ting','Dang','Yao','Wu','Nan','Chuo','Jia','Tou','Xu','Yu','Wei','Di','Rou','Mei','Dan','Ruan','Qin','Hui','Wo','Qian','Chun','Miao','Fu','Jie','Duan','Yi','Zhong','Mei','Huang','Mian','An','Ying','Xuan','Jie','Wei','Mei','Yuan','Zheng','Qiu','Shi','Xie','Tuo','Lian','Mao','Ran','Si','Pian','Wei','Wa','Cu','Hu','Ao','Jie','Bao','Xu','Tou','Gui','Chu','Yao','Pi','Xi','Yuan','Ying','Rong','Ru','Chi','Liu','Mei','Pan','Ao','Ma','Gou','Kui','Qin','Jia','Sao','Zhen','Yuan','Jie','Rong','Ming','Ying','Ji','Su','Niao','Xian','Tao','Pang','Lang','Nao','Bao','Ai','Pi','Pin','Yi','Piao','Yu','Lei','Xuan','Man','Yi','Zhang','Kang','Yong','Ni','Li','Di','Gui','Yan','Jin','Zhuan','Chang','Ze','Han','Nen','Lao','Mo','Zhe','Hu','Hu','Ao','Nen','Qiang','Ma','Pie','Gu','Wu','Qiao','Tuo','Zhan','Miao','Xian','Xian','Mo','Liao','Lian','Hua')