b=('jeo','jeog','jeokk','jeogs','jeon','jeonj','jeonh','jeod','jeol','jeolg','jeolm','jeolb','jeols','jeolt','jeolp','jeolh','jeom','jeob','jeobs','jeos','jeoss','jeong','jeoj','jeoch','jeok','jeot','jeop','jeoh','je','jeg','jekk','jegs','jen','jenj','jenh','jed','jel','jelg','jelm','jelb','jels','jelt','jelp','jelh','jem','jeb','jebs','jes','jess','jeng','jej','jech','jek','jet','jep','jeh','jyeo','jyeog','jyeokk','jyeogs','jyeon','jyeonj','jyeonh','jyeod','jyeol','jyeolg','jyeolm','jyeolb','jyeols','jyeolt','jyeolp','jyeolh','jyeom','jyeob','jyeobs','jyeos','jyeoss','jyeong','jyeoj','jyeoch','jyeok','jyeot','jyeop','jyeoh','jye','jyeg','jyekk','jyegs','jyen','jyenj','jyenh','jyed','jyel','jyelg','jyelm','jyelb','jyels','jyelt','jyelp','jyelh','jyem','jyeb','jyebs','jyes','jyess','jyeng','jyej','jyech','jyek','jyet','jyep','jyeh','jo','jog','jokk','jogs','jon','jonj','jonh','jod','jol','jolg','jolm','jolb','jols','jolt','jolp','jolh','jom','job','jobs','jos','joss','jong','joj','joch','jok','jot','jop','joh','jwa','jwag','jwakk','jwags','jwan','jwanj','jwanh','jwad','jwal','jwalg','jwalm','jwalb','jwals','jwalt','jwalp','jwalh','jwam','jwab','jwabs','jwas','jwass','jwang','jwaj','jwach','jwak','jwat','jwap','jwah','jwae','jwaeg','jwaekk','jwaegs','jwaen','jwaenj','jwaenh','jwaed','jwael','jwaelg','jwaelm','jwaelb','jwaels','jwaelt','jwaelp','jwaelh','jwaem','jwaeb','jwaebs','jwaes','jwaess','jwaeng','jwaej','jwaech','jwaek','jwaet','jwaep','jwaeh','joe','joeg','joekk','joegs','joen','joenj','joenh','joed','joel','joelg','joelm','joelb','joels','joelt','joelp','joelh','joem','joeb','joebs','joes','joess','joeng','joej','joech','joek','joet','joep','joeh','jyo','jyog','jyokk','jyogs','jyon','jyonj','jyonh','jyod','jyol','jyolg','jyolm','jyolb','jyols','jyolt','jyolp','jyolh','jyom','jyob','jyobs','jyos','jyoss','jyong','jyoj','jyoch','jyok','jyot','jyop','jyoh','ju','jug','jukk','jugs')