b=('Zhi','Liu','Mei','Li','Rong','Zha','Zao','Biao','Zhan','Zhi','Long','Dong','Lu','Sheng','Li','Lan','Yong','Shu','Xun','Shuan','Qi','Zhen','Qi','Li','Yi','Xiang','Zhen','Li','Se','Gua','Kan','Ben','Ren','Xiao','Bai','Ren','Bing','Zi','Chou','Yi','Ci','Xu','Zhu','Jian','Zui','Er','Er','You','Fa','Gong','Kao','Lao','Zhan','Lie','Yin','Yang','He','Gen','Yi','Shi','Ge','Zai','Luan','Fu','Jie','Heng','Gui','Tao','Guang','Wei','Kuang','Ru','An','An','Juan','Yi','Zhuo','Ku','Zhi','Qiong','Tong','Sang','Sang','Huan','Ju','Jiu','Xue','Duo','Zhui','Yu','Zan','Kasei','Ying','Jie','Liu','Zhan','Ya','Rao','Zhen','Dang','Qi','Qiao','Hua','Gui','Jiang','Zhuang','Xun','Suo','Sha','Zhen','Bei','Ting','Kuo','Jing','Po','Ben','Fu','Rui','Tong','Jue','Xi','Lang','Liu','Feng','Qi','Wen','Jun','Gan','Su','Liang','Qiu','Ting','You','Mei','Bang','Long','Peng','Zhuang','Di','Xuan','Tu','Zao','Ao','Gu','Bi','Di','Han','Zi','Zhi','Ren','Bei','Geng','Jian','Huan','Wan','Nuo','Jia','Tiao','Ji','Xiao','Lu','Hun','Shao','Cen','Fen','Song','Meng','Wu','Li','Li','Dou','Qin','Ying','Suo','Ju','Ti','Xie','Kun','Zhuo','Shu','Chan','Fan','Wei','Jing','Li','Bin','Xia','Fo','Tao','Zhi','Lai','Lian','Jian','Zhuo','Ling','Li','Qi','Bing','Lun','Cong','Qian','Mian','Qi','Qi','Cai','Gun','Chan','De','Fei','Pai','Bang','Bang','Hun','Zong','Cheng','Zao','Ji','Li','Peng','Yu','Yu','Gu','Jun','Dong','Tang','Gang','Wang','Di','Cuo','Fan','Cheng','Zhan','Qi','Yuan','Yan','Yu','Quan','Yi','Sen','Ren','Chui','Leng','Qi','Zhuo','Fu','Ke','Lai','Zou','Zou','Zhao','Guan','Fen','Fen','Shen','Qing','Ni')