b=('jjuim','jjuib','jjuibs','jjuis','jjuiss','jjuing','jjuij','jjuich','jjuik','jjuit','jjuip','jjuih','jji','jjig','jjikk','jjigs','jjin','jjinj','jjinh','jjid','jjil','jjilg','jjilm','jjilb','jjils','jjilt','jjilp','jjilh','jjim','jjib','jjibs','jjis','jjiss','jjing','jjij','jjich','jjik','jjit','jjip','jjih','cha','chag','chakk','chags','chan','chanj','chanh','chad','chal','chalg','chalm','chalb','chals','chalt','chalp','chalh','cham','chab','chabs','chas','chass','chang','chaj','chach','chak','chat','chap','chah','chae','chaeg','chaekk','chaegs','chaen','chaenj','chaenh','chaed','chael','chaelg','chaelm','chaelb','chaels','chaelt','chaelp','chaelh','chaem','chaeb','chaebs','chaes','chaess','chaeng','chaej','chaech','chaek','chaet','chaep','chaeh','chya','chyag','chyakk','chyags','chyan','chyanj','chyanh','chyad','chyal','chyalg','chyalm','chyalb','chyals','chyalt','chyalp','chyalh','chyam','chyab','chyabs','chyas','chyass','chyang','chyaj','chyach','chyak','chyat','chyap','chyah','chyae','chyaeg','chyaekk','chyaegs','chyaen','chyaenj','chyaenh','chyaed','chyael','chyaelg','chyaelm','chyaelb','chyaels','chyaelt','chyaelp','chyaelh','chyaem','chyaeb','chyaebs','chyaes','chyaess','chyaeng','chyaej','chyaech','chyaek','chyaet','chyaep','chyaeh','cheo','cheog','cheokk','cheogs','cheon','cheonj','cheonh','cheod','cheol','cheolg','cheolm','cheolb','cheols','cheolt','cheolp','cheolh','cheom','cheob','cheobs','cheos','cheoss','cheong','cheoj','cheoch','cheok','cheot','cheop','cheoh','che','cheg','chekk','chegs','chen','chenj','chenh','ched','chel','chelg','chelm','chelb','chels','chelt','chelp','chelh','chem','cheb','chebs','ches','chess','cheng','chej','chech','chek','chet','chep','cheh','chyeo','chyeog','chyeokk','chyeogs','chyeon','chyeonj','chyeonh','chyeod','chyeol','chyeolg','chyeolm','chyeolb','chyeols','chyeolt','chyeolp','chyeolh','chyeom','chyeob','chyeobs','chyeos','chyeoss','chyeong','chyeoj','chyeoch','chyeok','chyeot','chyeop','chyeoh','chye','chyeg','chyekk','chyegs','chyen','chyenj','chyenh','chyed','chyel','chyelg','chyelm','chyelb','chyels','chyelt','chyelp','chyelh','chyem','chyeb','chyebs','chyes')