b=('Shou','Yi','Zhi','Gu','Chu','Jiang','Feng','Bei','Zhai','Bian','Sui','Qun','Ling','Fu','Cuo','Xia','Xiong','Xie','Nao','Xia','Kui','Xi','Wai','Yuan','Mao','Su','Duo','Duo','Ye','Qing','Wai','Gou','Gou','Qi','Meng','Meng','Yin','Huo','Chen','Da','Ze','Tian','Tai','Fu','Guai','Yao','Yang','Hang','Gao','Shi','Tao','Tai','Tou','Yan','Bi','Yi','Kua','Jia','Duo','Hua','Kuang','Yun','Jia','Ba','En','Lian','Huan','Di','Yan','Pao','Juan','Qi','Nai','Feng','Xie','Fen','Dian','Quan','Kui','Zou','Huan','Qi','Kai','Zha','Ben','Yi','Jiang','Tao','Zang','Ben','Xi','Huang','Fei','Diao','Xun','Beng','Dian','Ao','She','Weng','Ha','Ao','Wu','Ao','Jiang','Lian','Duo','Yun','Jiang','Shi','Fen','Huo','Bi','Luan','Duo','Nu','Nu','Ding','Nai','Qian','Jian','Ta','Jiu','Nuan','Cha','Hao','Xian','Fan','Ji','Shuo','Ru','Fei','Wang','Hong','Zhuang','Fu','Ma','Dan','Ren','Fu','Jing','Yan','Hai','Wen','Zhong','Pa','Du','Ji','Keng','Zhong','Yao','Jin','Yun','Miao','Fou','Chi','Yue','Zhuang','Niu','Yan','Na','Xin','Fen','Bi','Yu','Tuo','Feng','Wan','Fang','Wu','Yu','Gui','Du','Ba','Ni','Zhou','Zhuo','Zhao','Da','Nai','Yuan','Tou','Xian','Zhi','E','Mei','Mo','Qi','Bi','Shen','Qie','E','He','Xu','Fa','Zheng','Min','Ban','Mu','Fu','Ling','Zi','Zi','Shi','Ran','Shan','Yang','Man','Jie','Gu','Si','Xing','Wei','Zi','Ju','Shan','Pin','Ren','Yao','Dong','Jiang','Shu','Ji','Gai','Xiang','Hua','Juan','Jiao','Gou','Lao','Jian','Jian','Yi','Nian','Zhi','Ji','Ji','Xian','Heng','Guang','Jun','Kua','Yan','Ming','Lie','Pei','E','You','Yan','Cha','Shen','Yin','Shi','Gui','Quan','Zi')