b=('Zhui','Ping','Bian','Zhou','Zhen','Lei','Ci','Ying','Qi','Xian','Lou','Di','Ou','Meng','Zhuan','Beng','Lin','Zeng','Wu','Pi','Dan','Weng','Ying','Yan','Gan','Dai','Shen','Tian','Tian','Han','Chang','Sheng','Qing','Shen','Chan','Chan','Rui','Sheng','Su','Shen','Yong','Shuai','Lu','Fu','Yong','Beng','Feng','Ning','Tian','You','Jia','Shen','Zha','Dian','Fu','Nan','Dian','Ping','Ting','Hua','Ting','Zhen','Zai','Meng','Bi','Bi','Liu','Xun','Liu','Chang','Mu','Yun','Fan','Fu','Geng','Tian','Jie','Jie','Quan','Wei','Fu','Tian','Mu','Duo','Pan','Jiang','Wa','Da','Nan','Liu','Ben','Zhen','Chu','Mu','Mu','Ce','Tian','Gai','Bi','Da','Zhi','Lue','Qi','Lue','Pan','Yi','Fan','Hua','She','Yu','Mu','Jun','Yi','Liu','She','Die','Chou','Hua','Dang','Zhui','Ji','Wan','Jiang','Cheng','Chang','Tun','Lei','Ji','Cha','Liu','Die','Tuan','Lin','Jiang','Jiang','Chou','Pi','Die','Die','Pi','Jie','Dan','Shu','Shu','Zhi','Yi','Ne','Nai','Ding','Bi','Jie','Liao','Gang','Ge','Jiu','Zhou','Xia','Shan','Xu','Nue','Li','Yang','Chen','You','Ba','Jie','Jue','Qi','Xia','Cui','Bi','Yi','Li','Zong','Chuang','Feng','Zhu','Pao','Pi','Gan','Ke','Ci','Xue','Zhi','Dan','Zhen','Fa','Zhi','Teng','Ju','Ji','Fei','Ju','Shan','Jia','Xuan','Zha','Bing','Nie','Zheng','Yong','Jing','Quan','Teng','Tong','Yi','Jie','Wei','Hui','Tan','Yang','Chi','Zhi','Hen','Ya','Mei','Dou','Jing','Xiao','Tong','Tu','Mang','Pi','Xiao','Suan','Fu','Li','Zhi','Cuo','Duo','Wu','Sha','Lao','Shou','Huan','Xian','Yi','Beng','Zhang','Guan','Tan','Fei','Ma','Lin','Chi','Ji','Tian','An','Chi','Bi','Bi','Min','Gu','Dui','E','Wei')