b=('leoss','leong','leoj','leoch','leok','leot','leop','leoh','le','leg','lekk','legs','len','lenj','lenh','led','lel','lelg','lelm','lelb','lels','lelt','lelp','lelh','lem','leb','lebs','les','less','leng','lej','lech','lek','let','lep','leh','lyeo','lyeog','lyeokk','lyeogs','lyeon','lyeonj','lyeonh','lyeod','lyeol','lyeolg','lyeolm','lyeolb','lyeols','lyeolt','lyeolp','lyeolh','lyeom','lyeob','lyeobs','lyeos','lyeoss','lyeong','lyeoj','lyeoch','lyeok','lyeot','lyeop','lyeoh','lye','lyeg','lyekk','lyegs','lyen','lyenj','lyenh','lyed','lyel','lyelg','lyelm','lyelb','lyels','lyelt','lyelp','lyelh','lyem','lyeb','lyebs','lyes','lyess','lyeng','lyej','lyech','lyek','lyet','lyep','lyeh','lo','log','lokk','logs','lon','lonj','lonh','lod','lol','lolg','lolm','lolb','lols','lolt','lolp','lolh','lom','lob','lobs','los','loss','long','loj','loch','lok','lot','lop','loh','lwa','lwag','lwakk','lwags','lwan','lwanj','lwanh','lwad','lwal','lwalg','lwalm','lwalb','lwals','lwalt','lwalp','lwalh','lwam','lwab','lwabs','lwas','lwass','lwang','lwaj','lwach','lwak','lwat','lwap','lwah','lwae','lwaeg','lwaekk','lwaegs','lwaen','lwaenj','lwaenh','lwaed','lwael','lwaelg','lwaelm','lwaelb','lwaels','lwaelt','lwaelp','lwaelh','lwaem','lwaeb','lwaebs','lwaes','lwaess','lwaeng','lwaej','lwaech','lwaek','lwaet','lwaep','lwaeh','loe','loeg','loekk','loegs','loen','loenj','loenh','loed','loel','loelg','loelm','loelb','loels','loelt','loelp','loelh','loem','loeb','loebs','loes','loess','loeng','loej','loech','loek','loet','loep','loeh','lyo','lyog','lyokk','lyogs','lyon','lyonj','lyonh','lyod','lyol','lyolg','lyolm','lyolb','lyols','lyolt','lyolp','lyolh','lyom','lyob','lyobs','lyos','lyoss','lyong','lyoj','lyoch','lyok','lyot','lyop','lyoh','lu','lug','lukk','lugs','lun','lunj','lunh','lud','lul','lulg','lulm','lulb','luls','lult','lulp','lulh','lum','lub','lubs','lus','luss','lung','luj','luch')