b=('moen','moenj','moenh','moed','moel','moelg','moelm','moelb','moels','moelt','moelp','moelh','moem','moeb','moebs','moes','moess','moeng','moej','moech','moek','moet','moep','moeh','myo','myog','myokk','myogs','myon','myonj','myonh','myod','myol','myolg','myolm','myolb','myols','myolt','myolp','myolh','myom','myob','myobs','myos','myoss','myong','myoj','myoch','myok','myot','myop','myoh','mu','mug','mukk','mugs','mun','munj','munh','mud','mul','mulg','mulm','mulb','muls','mult','mulp','mulh','mum','mub','mubs','mus','muss','mung','muj','much','muk','mut','mup','muh','mwo','mwog','mwokk','mwogs','mwon','mwonj','mwonh','mwod','mwol','mwolg','mwolm','mwolb','mwols','mwolt','mwolp','mwolh','mwom','mwob','mwobs','mwos','mwoss','mwong','mwoj','mwoch','mwok','mwot','mwop','mwoh','mwe','mweg','mwekk','mwegs','mwen','mwenj','mwenh','mwed','mwel','mwelg','mwelm','mwelb','mwels','mwelt','mwelp','mwelh','mwem','mweb','mwebs','mwes','mwess','mweng','mwej','mwech','mwek','mwet','mwep','mweh','mwi','mwig','mwikk','mwigs','mwin','mwinj','mwinh','mwid','mwil','mwilg','mwilm','mwilb','mwils','mwilt','mwilp','mwilh','mwim','mwib','mwibs','mwis','mwiss','mwing','mwij','mwich','mwik','mwit','mwip','mwih','myu','myug','myukk','myugs','myun','myunj','myunh','myud','myul','myulg','myulm','myulb','myuls','myult','myulp','myulh','myum','myub','myubs','myus','myuss','myung','myuj','myuch','myuk','myut','myup','myuh','meu','meug','meukk','meugs','meun','meunj','meunh','meud','meul','meulg','meulm','meulb','meuls','meult','meulp','meulh','meum','meub','meubs','meus','meuss','meung','meuj','meuch','meuk','meut','meup','meuh','mui','muig','muikk','muigs','muin','muinj','muinh','muid','muil','muilg','muilm','muilb','muils','muilt','muilp','muilh','muim','muib','muibs','muis','muiss','muing','muij','muich','muik','muit','muip','muih','mi','mig','mikk','migs','min','minj','minh','mid')