b=('ppess','ppeng','ppej','ppech','ppek','ppet','ppep','ppeh','ppyeo','ppyeog','ppyeokk','ppyeogs','ppyeon','ppyeonj','ppyeonh','ppyeod','ppyeol','ppyeolg','ppyeolm','ppyeolb','ppyeols','ppyeolt','ppyeolp','ppyeolh','ppyeom','ppyeob','ppyeobs','ppyeos','ppyeoss','ppyeong','ppyeoj','ppyeoch','ppyeok','ppyeot','ppyeop','ppyeoh','ppye','ppyeg','ppyekk','ppyegs','ppyen','ppyenj','ppyenh','ppyed','ppyel','ppyelg','ppyelm','ppyelb','ppyels','ppyelt','ppyelp','ppyelh','ppyem','ppyeb','ppyebs','ppyes','ppyess','ppyeng','ppyej','ppyech','ppyek','ppyet','ppyep','ppyeh','ppo','ppog','ppokk','ppogs','ppon','pponj','pponh','ppod','ppol','ppolg','ppolm','ppolb','ppols','ppolt','ppolp','ppolh','ppom','ppob','ppobs','ppos','pposs','ppong','ppoj','ppoch','ppok','ppot','ppop','ppoh','ppwa','ppwag','ppwakk','ppwags','ppwan','ppwanj','ppwanh','ppwad','ppwal','ppwalg','ppwalm','ppwalb','ppwals','ppwalt','ppwalp','ppwalh','ppwam','ppwab','ppwabs','ppwas','ppwass','ppwang','ppwaj','ppwach','ppwak','ppwat','ppwap','ppwah','ppwae','ppwaeg','ppwaekk','ppwaegs','ppwaen','ppwaenj','ppwaenh','ppwaed','ppwael','ppwaelg','ppwaelm','ppwaelb','ppwaels','ppwaelt','ppwaelp','ppwaelh','ppwaem','ppwaeb','ppwaebs','ppwaes','ppwaess','ppwaeng','ppwaej','ppwaech','ppwaek','ppwaet','ppwaep','ppwaeh','ppoe','ppoeg','ppoekk','ppoegs','ppoen','ppoenj','ppoenh','ppoed','ppoel','ppoelg','ppoelm','ppoelb','ppoels','ppoelt','ppoelp','ppoelh','ppoem','ppoeb','ppoebs','ppoes','ppoess','ppoeng','ppoej','ppoech','ppoek','ppoet','ppoep','ppoeh','ppyo','ppyog','ppyokk','ppyogs','ppyon','ppyonj','ppyonh','ppyod','ppyol','ppyolg','ppyolm','ppyolb','ppyols','ppyolt','ppyolp','ppyolh','ppyom','ppyob','ppyobs','ppyos','ppyoss','ppyong','ppyoj','ppyoch','ppyok','ppyot','ppyop','ppyoh','ppu','ppug','ppukk','ppugs','ppun','ppunj','ppunh','ppud','ppul','ppulg','ppulm','ppulb','ppuls','ppult','ppulp','ppulh','ppum','ppub','ppubs','ppus','ppuss','ppung','ppuj','ppuch','ppuk','pput','ppup','ppuh','ppwo','ppwog','ppwokk','ppwogs','ppwon','ppwonj','ppwonh','ppwod','ppwol','ppwolg','ppwolm','ppwolb','ppwols','ppwolt','ppwolp','ppwolh','ppwom','ppwob','ppwobs','ppwos','ppwoss','ppwong','ppwoj','ppwoch')