b=('kwon','kwonj','kwonh','kwod','kwol','kwolg','kwolm','kwolb','kwols','kwolt','kwolp','kwolh','kwom','kwob','kwobs','kwos','kwoss','kwong','kwoj','kwoch','kwok','kwot','kwop','kwoh','kwe','kweg','kwekk','kwegs','kwen','kwenj','kwenh','kwed','kwel','kwelg','kwelm','kwelb','kwels','kwelt','kwelp','kwelh','kwem','kweb','kwebs','kwes','kwess','kweng','kwej','kwech','kwek','kwet','kwep','kweh','kwi','kwig','kwikk','kwigs','kwin','kwinj','kwinh','kwid','kwil','kwilg','kwilm','kwilb','kwils','kwilt','kwilp','kwilh','kwim','kwib','kwibs','kwis','kwiss','kwing','kwij','kwich','kwik','kwit','kwip','kwih','kyu','kyug','kyukk','kyugs','kyun','kyunj','kyunh','kyud','kyul','kyulg','kyulm','kyulb','kyuls','kyult','kyulp','kyulh','kyum','kyub','kyubs','kyus','kyuss','kyung','kyuj','kyuch','kyuk','kyut','kyup','kyuh','keu','keug','keukk','keugs','keun','keunj','keunh','keud','keul','keulg','keulm','keulb','keuls','keult','keulp','keulh','keum','keub','keubs','keus','keuss','keung','keuj','keuch','keuk','keut','keup','keuh','kui','kuig','kuikk','kuigs','kuin','kuinj','kuinh','kuid','kuil','kuilg','kuilm','kuilb','kuils','kuilt','kuilp','kuilh','kuim','kuib','kuibs','kuis','kuiss','kuing','kuij','kuich','kuik','kuit','kuip','kuih','ki','kig','kikk','kigs','kin','kinj','kinh','kid','kil','kilg','kilm','kilb','kils','kilt','kilp','kilh','kim','kib','kibs','kis','kiss','king','kij','kich','kik','kit','kip','kih','ta','tag','takk','tags','tan','tanj','tanh','tad','tal','talg','talm','talb','tals','talt','talp','talh','tam','tab','tabs','tas','tass','tang','taj','tach','tak','tat','tap','tah','tae','taeg','taekk','taegs','taen','taenj','taenh','taed','tael','taelg','taelm','taelb','taels','taelt','taelp','taelh','taem','taeb','taebs','taes','taess','taeng','taej','taech','taek','taet','taep','taeh','tya','tyag','tyakk','tyags','tyan','tyanj','tyanh','tyad')