b=('Yun','Bei','Ang','Ze','Ban','Jie','Kun','Sheng','Hu','Fang','Hao','Gui','Chang','Xuan','Ming','Hun','Fen','Qin','Hu','Yi','Xi','Xin','Yan','Ze','Fang','Tan','Shen','Ju','Yang','Zan','Bing','Xing','Ying','Xuan','Po','Zhen','Ling','Chun','Hao','Mei','Zuo','Mo','Bian','Xu','Hun','Zhao','Zong','Shi','Shi','Yu','Fei','Die','Mao','Ni','Chang','Wen','Dong','Ai','Bing','Ang','Zhou','Long','Xian','Kuang','Tiao','Chao','Shi','Huang','Huang','Xuan','Kui','Xu','Jiao','Jin','Zhi','Jin','Shang','Tong','Hong','Yan','Gai','Xiang','Shai','Xiao','Ye','Yun','Hui','Han','Han','Jun','Wan','Xian','Kun','Zhou','Xi','Cheng','Sheng','Bu','Zhe','Zhe','Wu','Wan','Hui','Hao','Chen','Wan','Tian','Zhuo','Zui','Zhou','Pu','Jing','Xi','Shan','Ni','Xi','Qing','Qi','Jing','Gui','Zheng','Yi','Zhi','An','Wan','Lin','Liang','Chang','Wang','Xiao','Zan','Fei','Xuan','Geng','Yi','Xia','Yun','Hui','Xu','Min','Kui','Ye','Ying','Shu','Wei','Shu','Qing','Mao','Nan','Jian','Nuan','An','Yang','Chun','Yao','Suo','Pu','Ming','Jiao','Kai','Gao','Weng','Chang','Qi','Hao','Yan','Li','Ai','Ji','Ji','Men','Zan','Xie','Hao','Mu','Mo','Cong','Ni','Zhang','Hui','Bao','Han','Xuan','Chuan','Liao','Xian','Tan','Jing','Pie','Lin','Tun','Xi','Yi','Ji','Huang','Dai','Ye','Ye','Li','Tan','Tong','Xiao','Fei','Shen','Zhao','Hao','Yi','Xiang','Xing','Shen','Jiao','Bao','Jing','Yan','Ai','Ye','Ru','Shu','Meng','Xun','Yao','Pu','Li','Chen','Kuang','Die','Liao','Yan','Huo','Lu','Xi','Rong','Long','Nang','Luo','Luan','Shai','Tang','Yan','Zhu','Yue','Yue','Qu','Ye','Geng','Ye','Hu','He','Shu','Cao','Cao','Sheng','Man','Ceng','Ceng','Ti')