b=('byum','byub','byubs','byus','byuss','byung','byuj','byuch','byuk','byut','byup','byuh','beu','beug','beukk','beugs','beun','beunj','beunh','beud','beul','beulg','beulm','beulb','beuls','beult','beulp','beulh','beum','beub','beubs','beus','beuss','beung','beuj','beuch','beuk','beut','beup','beuh','bui','buig','buikk','buigs','buin','buinj','buinh','buid','buil','builg','builm','builb','buils','built','builp','builh','buim','buib','buibs','buis','buiss','buing','buij','buich','buik','buit','buip','buih','bi','big','bikk','bigs','bin','binj','binh','bid','bil','bilg','bilm','bilb','bils','bilt','bilp','bilh','bim','bib','bibs','bis','biss','bing','bij','bich','bik','bit','bip','bih','ppa','ppag','ppakk','ppags','ppan','ppanj','ppanh','ppad','ppal','ppalg','ppalm','ppalb','ppals','ppalt','ppalp','ppalh','ppam','ppab','ppabs','ppas','ppass','ppang','ppaj','ppach','ppak','ppat','ppap','ppah','ppae','ppaeg','ppaekk','ppaegs','ppaen','ppaenj','ppaenh','ppaed','ppael','ppaelg','ppaelm','ppaelb','ppaels','ppaelt','ppaelp','ppaelh','ppaem','ppaeb','ppaebs','ppaes','ppaess','ppaeng','ppaej','ppaech','ppaek','ppaet','ppaep','ppaeh','ppya','ppyag','ppyakk','ppyags','ppyan','ppyanj','ppyanh','ppyad','ppyal','ppyalg','ppyalm','ppyalb','ppyals','ppyalt','ppyalp','ppyalh','ppyam','ppyab','ppyabs','ppyas','ppyass','ppyang','ppyaj','ppyach','ppyak','ppyat','ppyap','ppyah','ppyae','ppyaeg','ppyaekk','ppyaegs','ppyaen','ppyaenj','ppyaenh','ppyaed','ppyael','ppyaelg','ppyaelm','ppyaelb','ppyaels','ppyaelt','ppyaelp','ppyaelh','ppyaem','ppyaeb','ppyaebs','ppyaes','ppyaess','ppyaeng','ppyaej','ppyaech','ppyaek','ppyaet','ppyaep','ppyaeh','ppeo','ppeog','ppeokk','ppeogs','ppeon','ppeonj','ppeonh','ppeod','ppeol','ppeolg','ppeolm','ppeolb','ppeols','ppeolt','ppeolp','ppeolh','ppeom','ppeob','ppeobs','ppeos','ppeoss','ppeong','ppeoj','ppeoch','ppeok','ppeot','ppeop','ppeoh','ppe','ppeg','ppekk','ppegs','ppen','ppenj','ppenh','pped','ppel','ppelg','ppelm','ppelb','ppels','ppelt','ppelp','ppelh','ppem','ppeb','ppebs','ppes')