b=('ssal','ssalg','ssalm','ssalb','ssals','ssalt','ssalp','ssalh','ssam','ssab','ssabs','ssas','ssass','ssang','ssaj','ssach','ssak','ssat','ssap','ssah','ssae','ssaeg','ssaekk','ssaegs','ssaen','ssaenj','ssaenh','ssaed','ssael','ssaelg','ssaelm','ssaelb','ssaels','ssaelt','ssaelp','ssaelh','ssaem','ssaeb','ssaebs','ssaes','ssaess','ssaeng','ssaej','ssaech','ssaek','ssaet','ssaep','ssaeh','ssya','ssyag','ssyakk','ssyags','ssyan','ssyanj','ssyanh','ssyad','ssyal','ssyalg','ssyalm','ssyalb','ssyals','ssyalt','ssyalp','ssyalh','ssyam','ssyab','ssyabs','ssyas','ssyass','ssyang','ssyaj','ssyach','ssyak','ssyat','ssyap','ssyah','ssyae','ssyaeg','ssyaekk','ssyaegs','ssyaen','ssyaenj','ssyaenh','ssyaed','ssyael','ssyaelg','ssyaelm','ssyaelb','ssyaels','ssyaelt','ssyaelp','ssyaelh','ssyaem','ssyaeb','ssyaebs','ssyaes','ssyaess','ssyaeng','ssyaej','ssyaech','ssyaek','ssyaet','ssyaep','ssyaeh','sseo','sseog','sseokk','sseogs','sseon','sseonj','sseonh','sseod','sseol','sseolg','sseolm','sseolb','sseols','sseolt','sseolp','sseolh','sseom','sseob','sseobs','sseos','sseoss','sseong','sseoj','sseoch','sseok','sseot','sseop','sseoh','sse','sseg','ssekk','ssegs','ssen','ssenj','ssenh','ssed','ssel','sselg','sselm','sselb','ssels','sselt','sselp','sselh','ssem','sseb','ssebs','sses','ssess','sseng','ssej','ssech','ssek','sset','ssep','sseh','ssyeo','ssyeog','ssyeokk','ssyeogs','ssyeon','ssyeonj','ssyeonh','ssyeod','ssyeol','ssyeolg','ssyeolm','ssyeolb','ssyeols','ssyeolt','ssyeolp','ssyeolh','ssyeom','ssyeob','ssyeobs','ssyeos','ssyeoss','ssyeong','ssyeoj','ssyeoch','ssyeok','ssyeot','ssyeop','ssyeoh','ssye','ssyeg','ssyekk','ssyegs','ssyen','ssyenj','ssyenh','ssyed','ssyel','ssyelg','ssyelm','ssyelb','ssyels','ssyelt','ssyelp','ssyelh','ssyem','ssyeb','ssyebs','ssyes','ssyess','ssyeng','ssyej','ssyech','ssyek','ssyet','ssyep','ssyeh','sso','ssog','ssokk','ssogs','sson','ssonj','ssonh','ssod','ssol','ssolg','ssolm','ssolb','ssols','ssolt','ssolp','ssolh','ssom','ssob','ssobs','ssos','ssoss','ssong','ssoj','ssoch','ssok','ssot','ssop','ssoh','sswa','sswag','sswakk','sswags','sswan','sswanj','sswanh','sswad','sswal','sswalg','sswalm','sswalb')