b=('luk','lut','lup','luh','lwo','lwog','lwokk','lwogs','lwon','lwonj','lwonh','lwod','lwol','lwolg','lwolm','lwolb','lwols','lwolt','lwolp','lwolh','lwom','lwob','lwobs','lwos','lwoss','lwong','lwoj','lwoch','lwok','lwot','lwop','lwoh','lwe','lweg','lwekk','lwegs','lwen','lwenj','lwenh','lwed','lwel','lwelg','lwelm','lwelb','lwels','lwelt','lwelp','lwelh','lwem','lweb','lwebs','lwes','lwess','lweng','lwej','lwech','lwek','lwet','lwep','lweh','lwi','lwig','lwikk','lwigs','lwin','lwinj','lwinh','lwid','lwil','lwilg','lwilm','lwilb','lwils','lwilt','lwilp','lwilh','lwim','lwib','lwibs','lwis','lwiss','lwing','lwij','lwich','lwik','lwit','lwip','lwih','lyu','lyug','lyukk','lyugs','lyun','lyunj','lyunh','lyud','lyul','lyulg','lyulm','lyulb','lyuls','lyult','lyulp','lyulh','lyum','lyub','lyubs','lyus','lyuss','lyung','lyuj','lyuch','lyuk','lyut','lyup','lyuh','leu','leug','leukk','leugs','leun','leunj','leunh','leud','leul','leulg','leulm','leulb','leuls','leult','leulp','leulh','leum','leub','leubs','leus','leuss','leung','leuj','leuch','leuk','leut','leup','leuh','lui','luig','luikk','luigs','luin','luinj','luinh','luid','luil','luilg','luilm','luilb','luils','luilt','luilp','luilh','luim','luib','luibs','luis','luiss','luing','luij','luich','luik','luit','luip','luih','li','lig','likk','ligs','lin','linj','linh','lid','lil','lilg','lilm','lilb','lils','lilt','lilp','lilh','lim','lib','libs','lis','liss','ling','lij','lich','lik','lit','lip','lih','ma','mag','makk','mags','man','manj','manh','mad','mal','malg','malm','malb','mals','malt','malp','malh','mam','mab','mabs','mas','mass','mang','maj','mach','mak','mat','map','mah','mae','maeg','maekk','maegs','maen','maenj','maenh','maed','mael','maelg','maelm','maelb','maels','maelt','maelp','maelh','maem','maeb','maebs','maes','maess','maeng','maej','maech','maek','maet','maep','maeh')