b=('Xia','Yuan','Zong','Xu','Sheng','Wei','Geng','Xuan','Ying','Jin','Yi','Zhui','Ni','Bang','Gu','Pan','Zhou','Jian','Ci','Quan','Shuang','Yun','Xia','Cui','Xi','Rong','Tao','Fu','Yun','Chen','Gao','Ru','Hu','Zai','Teng','Xian','Su','Zhen','Zong','Tao','Huang','Cai','Bi','Feng','Cu','Li','Suo','Yan','Xi','Zong','Lei','Juan','Qian','Man','Zhi','Lu','Mu','Piao','Lian','Mi','Xuan','Zong','Ji','Shan','Sui','Fan','Lu','Beng','Yi','Sao','Mou','Yao','Qiang','Hun','Xian','Ji','Sha','Xiu','Ran','Xuan','Sui','Qiao','Zeng','Zuo','Zhi','Shan','San','Lin','Yu','Fan','Liao','Chuo','Zun','Jian','Rao','Chan','Rui','Xiu','Hui','Hua','Zuan','Xi','Qiang','Yun','Da','Sheng','Hui','Xi','Se','Jian','Jiang','Huan','Zao','Cong','Xie','Jiao','Bi','Dan','Yi','Nong','Sui','Yi','Shai','Xu','Ji','Bin','Qian','Lan','Pu','Xun','Zuan','Qi','Peng','Yao','Mo','Lei','Xie','Zuan','Kuang','You','Xu','Lei','Xian','Chan','Jiao','Lu','Chan','Ying','Cai','Rang','Xian','Zui','Zuan','Luo','Li','Dao','Lan','Lei','Lian','Si','Jiu','Yu','Hong','Zhou','Xian','Ge','Yue','Ji','Wan','Kuang','Ji','Ren','Wei','Yun','Hong','Chun','Pi','Sha','Gang','Na','Ren','Zong','Lun','Fen','Zhi','Wen','Fang','Zhu','Zhen','Niu','Shu','Xian','Gan','Xie','Fu','Lian','Zu','Shen','Xi','Zhi','Zhong','Zhou','Ban','Fu','Chu','Shao','Yi','Jing','Dai','Bang','Rong','Jie','Ku','Rao','Die','Hang','Hui','Gei','Xuan','Jiang','Luo','Jue','Jiao','Tong','Geng','Xiao','Juan','Xiu','Xi','Sui','Tao','Ji','Ti','Ji','Xu','Ling','Ying','Xu','Qi','Fei','Chuo','Shang','Gun','Sheng','Wei','Mian','Shou','Beng','Chou','Tao','Liu','Quan','Zong','Zhan','Wan','Lu')