b=('kax','ka','kap','kuox','kuo','kuop','kot','kox','ko','kop','ket','kex','ke','kep','kut','kux','ku','kup','kurx','kur','ggit','ggix','ggi','ggiex','ggie','ggiep','ggat','ggax','gga','ggap','gguot','gguox','gguo','gguop','ggot','ggox','ggo','ggop','gget','ggex','gge','ggep','ggut','ggux','ggu','ggup','ggurx','ggur','mgiex','mgie','mgat','mgax','mga','mgap','mguox','mguo','mguop','mgot','mgox','mgo','mgop','mgex','mge','mgep','mgut','mgux','mgu','mgup','mgurx','mgur','hxit','hxix','hxi','hxip','hxiet','hxiex','hxie','hxiep','hxat','hxax','hxa','hxap','hxuot','hxuox','hxuo','hxuop','hxot','hxox','hxo','hxop','hxex','hxe','hxep','ngiex','ngie','ngiep','ngat','ngax','nga','ngap','nguot','nguox','nguo','ngot','ngox','ngo','ngop','ngex','nge','ngep','hit','hiex','hie','hat','hax','ha','hap','huot','huox','huo','huop','hot','hox','ho','hop','hex','he','hep','wat','wax','wa','wap','wuox','wuo','wuop','wox','wo','wop','wex','we','wep','zit','zix','zi','zip','ziex','zie','ziep','zat','zax','za','zap','zuox','zuo','zuop','zot','zox','zo','zop','zex','ze','zep','zut','zux','zu','zup','zurx','zur','zyt','zyx','zy','zyp','zyrx','zyr','cit','cix','ci','cip','ciet','ciex','cie','ciep','cat','cax','ca','cap','cuox','cuo','cuop','cot','cox','co','cop','cex','ce','cep','cut','cux','cu','cup','curx','cur','cyt','cyx','cy','cyp','cyrx','cyr','zzit','zzix','zzi','zzip','zziet','zziex','zzie','zziep','zzat','zzax','zza','zzap','zzox','zzo','zzop','zzex','zze','zzep','zzux','zzu','zzup','zzurx','zzur','zzyt','zzyx','zzy','zzyp','zzyrx','zzyr','nzit','nzix','nzi','nzip','nziex','nzie','nziep','nzat','nzax','nza','nzap','nzuox','nzuo','nzox','nzop','nzex','nze','nzux','nzu')