b=('Za','Bi','Shi','Bu','Ding','Shuai','Fan','Nie','Shi','Fen','Pa','Zhi','Xi','Hu','Dan','Wei','Zhang','Tang','Dai','Mo','Pei','Pa','Tie','Bo','Lian','Zhi','Zhou','Bo','Zhi','Di','Mo','Yi','Yi','Ping','Qia','Juan','Ru','Shuai','Dai','Zheng','Shui','Qiao','Zhen','Shi','Qun','Xi','Bang','Dai','Gui','Chou','Ping','Zhang','San','Wan','Dai','Wei','Chang','Sha','Qi','Ze','Guo','Mao','Du','Hou','Zheng','Xu','Mi','Wei','Wo','Fu','Yi','Bang','Ping','Die','Gong','Pan','Huang','Tao','Mi','Jia','Teng','Hui','Zhong','Shan','Man','Mu','Biao','Guo','Ze','Mu','Bang','Zhang','Jing','Chan','Fu','Zhi','Hu','Fan','Chuang','Bi','Bi','Zhang','Mi','Qiao','Chan','Fen','Meng','Bang','Chou','Mie','Chu','Jie','Xian','Lan','Gan','Ping','Nian','Jian','Bing','Bing','Xing','Gan','Yao','Huan','You','You','Ji','Guang','Pi','Ting','Ze','Guang','Zhuang','Mo','Qing','Bi','Qin','Dun','Chuang','Gui','Ya','Bai','Jie','Xu','Lu','Wu','Zhuang','Ku','Ying','Di','Pao','Dian','Ya','Miao','Geng','Ci','Fu','Tong','Pang','Fei','Xiang','Yi','Zhi','Tiao','Zhi','Xiu','Du','Zuo','Xiao','Tu','Gui','Ku','Mang','Ting','You','Bu','Bing','Cheng','Lai','Bi','Ji','An','Shu','Kang','Yong','Tuo','Song','Shu','Qing','Yu','Yu','Miao','Sou','Ce','Xiang','Fei','Jiu','E','Gui','Liu','Sha','Lian','Lang','Sou','Zhi','Bu','Qing','Jiu','Jiu','Jin','Ao','Kuo','Lou','Yin','Liao','Dai','Lu','Yi','Chu','Chan','Tu','Si','Xin','Miao','Chang','Wu','Fei','Guang','Ku','Kuai','Bi','Qiang','Xie','Lin','Lin','Liao','Lu','Ji','Ying','Xian','Ting','Yong','Li','Ting','Yin','Xun','Yan','Ting','Di','Pai','Jian','Hui','Nai','Hui','Gong','Nian')