b=('ttwim','ttwib','ttwibs','ttwis','ttwiss','ttwing','ttwij','ttwich','ttwik','ttwit','ttwip','ttwih','ttyu','ttyug','ttyukk','ttyugs','ttyun','ttyunj','ttyunh','ttyud','ttyul','ttyulg','ttyulm','ttyulb','ttyuls','ttyult','ttyulp','ttyulh','ttyum','ttyub','ttyubs','ttyus','ttyuss','ttyung','ttyuj','ttyuch','ttyuk','ttyut','ttyup','ttyuh','tteu','tteug','tteukk','tteugs','tteun','tteunj','tteunh','tteud','tteul','tteulg','tteulm','tteulb','tteuls','tteult','tteulp','tteulh','tteum','tteub','tteubs','tteus','tteuss','tteung','tteuj','tteuch','tteuk','tteut','tteup','tteuh','ttui','ttuig','ttuikk','ttuigs','ttuin','ttuinj','ttuinh','ttuid','ttuil','ttuilg','ttuilm','ttuilb','ttuils','ttuilt','ttuilp','ttuilh','ttuim','ttuib','ttuibs','ttuis','ttuiss','ttuing','ttuij','ttuich','ttuik','ttuit','ttuip','ttuih','tti','ttig','ttikk','ttigs','ttin','ttinj','ttinh','ttid','ttil','ttilg','ttilm','ttilb','ttils','ttilt','ttilp','ttilh','ttim','ttib','ttibs','ttis','ttiss','tting','ttij','ttich','ttik','ttit','ttip','ttih','la','lag','lakk','lags','lan','lanj','lanh','lad','lal','lalg','lalm','lalb','lals','lalt','lalp','lalh','lam','lab','labs','las','lass','lang','laj','lach','lak','lat','lap','lah','lae','laeg','laekk','laegs','laen','laenj','laenh','laed','lael','laelg','laelm','laelb','laels','laelt','laelp','laelh','laem','laeb','laebs','laes','laess','laeng','laej','laech','laek','laet','laep','laeh','lya','lyag','lyakk','lyags','lyan','lyanj','lyanh','lyad','lyal','lyalg','lyalm','lyalb','lyals','lyalt','lyalp','lyalh','lyam','lyab','lyabs','lyas','lyass','lyang','lyaj','lyach','lyak','lyat','lyap','lyah','lyae','lyaeg','lyaekk','lyaegs','lyaen','lyaenj','lyaenh','lyaed','lyael','lyaelg','lyaelm','lyaelb','lyaels','lyaelt','lyaelp','lyaelh','lyaem','lyaeb','lyaebs','lyaes','lyaess','lyaeng','lyaej','lyaech','lyaek','lyaet','lyaep','lyaeh','leo','leog','leokk','leogs','leon','leonj','leonh','leod','leol','leolg','leolm','leolb','leols','leolt','leolp','leolh','leom','leob','leobs','leos')