b=('Qing','Yu','Piao','Ji','Ya','Chao','Qi','Xi','Ji','Lu','Lou','Long','Jin','Guo','Cong','Lou','Zhi','Gai','Qiang','Li','Yan','Cao','Jiao','Cong','Chun','Tuan','Ou','Teng','Ye','Xi','Mi','Tang','Mo','Shang','Han','Lian','Lan','Wa','Chi','Gan','Feng','Xuan','Yi','Man','Zi','Mang','Kang','Luo','Peng','Shu','Zhang','Zhang','Zhuang','Xu','Huan','Huo','Jian','Yan','Shuang','Liao','Cui','Ti','Yang','Jiang','Cong','Ying','Hong','Xiu','Shu','Guan','Ying','Xiao','Zong','Kun','Xu','Lian','Zhi','Wei','Pi','Yu','Jiao','Po','Dang','Hui','Jie','Wu','Pa','Ji','Pan','Wei','Su','Qian','Qian','Xi','Lu','Xi','Xun','Dun','Huang','Min','Run','Su','Lao','Zhen','Cong','Yi','Zhe','Wan','Shan','Tan','Chao','Xun','Kui','Ye','Shao','Tu','Zhu','Sa','Hei','Bi','Shan','Chan','Chan','Shu','Tong','Pu','Lin','Wei','Se','Se','Cheng','Jiong','Cheng','Hua','Jiao','Lao','Che','Gan','Cun','Hong','Si','Shu','Peng','Han','Yun','Liu','Hong','Fu','Hao','He','Xian','Jian','Shan','Xi','Yu','Lu','Lan','Ning','Yu','Lin','Mian','Zao','Dang','Huan','Ze','Xie','Yu','Li','Shi','Xue','Ling','Wan','Zi','Yong','Hui','Can','Lian','Dian','Ye','Ao','Huan','Zhen','Chan','Man','Dan','Dan','Yi','Sui','Pi','Ju','Ta','Qin','Ji','Zhuo','Lian','Nong','Guo','Jin','Fen','Se','Ji','Sui','Hui','Chu','Ta','Song','Ding','Se','Zhu','Lai','Bin','Lian','Mi','Shi','Shu','Mi','Ning','Ying','Ying','Meng','Jin','Qi','Bi','Ji','Hao','Ru','Cui','Wo','Tao','Yin','Yin','Dui','Ci','Huo','Qing','Lan','Jun','Ai','Pu','Zhuo','Wei','Bin','Gu','Qian','Ying','Bin','Kuo','Fei','Cang','Me','Jian','Wei','Luo','Zan','Lu','Li')