b=('Yu','Shei','Shen','Diao','Chan','Liang','Zhun','Sui','Tan','Shen','Yi','Mou','Chen','Die','Huang','Jian','Xie','Xue','Ye','Wei','E','Yu','Xuan','Chan','Zi','An','Yan','Di','Mi','Pian','Xu','Mo','Dang','Su','Xie','Yao','Bang','Shi','Qian','Mi','Jin','Man','Zhe','Jian','Miu','Tan','Zen','Qiao','Lan','Pu','Jue','Yan','Qian','Zhan','Chen','Gu','Qian','Hong','Xia','Ji','Hong','Han','Hong','Xi','Xi','Huo','Liao','Han','Du','Long','Dou','Jiang','Qi','Shi','Li','Deng','Wan','Bi','Shu','Xian','Feng','Zhi','Zhi','Yan','Yan','Shi','Chu','Hui','Tun','Yi','Tun','Yi','Jian','Ba','Hou','E','Chu','Xiang','Huan','Jian','Ken','Gai','Ju','Fu','Xi','Bin','Hao','Yu','Zhu','Jia','Fen','Xi','Bo','Wen','Huan','Bin','Di','Zong','Fen','Yi','Zhi','Bao','Chai','An','Pi','Na','Pi','Gou','Na','You','Diao','Mo','Si','Xiu','Huan','Kun','He','Hao','Mo','An','Mao','Li','Ni','Bi','Yu','Jia','Tuan','Mao','Pi','Xi','Yi','Ju','Mo','Chu','Tan','Huan','Jue','Bei','Zhen','Yuan','Fu','Cai','Gong','Te','Yi','Hang','Wan','Pin','Huo','Fan','Tan','Guan','Ze','Zhi','Er','Zhu','Shi','Bi','Zi','Er','Gui','Pian','Bian','Mai','Dai','Sheng','Kuang','Fei','Tie','Yi','Chi','Mao','He','Bi','Lu','Lin','Hui','Gai','Pian','Zi','Jia','Xu','Zei','Jiao','Gai','Zang','Jian','Ying','Xun','Zhen','She','Bin','Bin','Qiu','She','Chuan','Zang','Zhou','Lai','Zan','Ci','Chen','Shang','Tian','Pei','Geng','Xian','Mai','Jian','Sui','Fu','Tan','Cong','Cong','Zhi','Ji','Zhang','Du','Jin','Xiong','Chun','Yun','Bao','Zai','Lai','Feng','Cang','Ji','Sheng','Yi','Zhuan','Fu','Gou','Sai','Ze','Liao')