b=('Mou','Ye','Wei','Xing','Teng','Zhou','Shan','Jian','Po','Kui','Huang','Huo','Ge','Ying','Mi','Xiao','Mi','Xi','Qiang','Chen','Xue','Ti','Su','Bang','Chi','Qian','Shi','Jiang','Yuan','Xie','He','Tao','Yao','Yao','Lu','Yu','Biao','Cong','Qing','Li','Mo','Mo','Shang','Zhe','Miu','Jian','Ze','Jie','Lian','Lou','Can','Ou','Gun','Xi','Zhuo','Ao','Ao','Jin','Zhe','Yi','Hu','Jiang','Man','Chao','Han','Hua','Chan','Xu','Zeng','Se','Xi','Zha','Dui','Zheng','Nao','Lan','E','Ying','Jue','Ji','Zun','Jiao','Bo','Hui','Zhuan','Wu','Zen','Zha','Shi','Qiao','Tan','Zen','Pu','Sheng','Xuan','Zao','Tan','Dang','Sui','Xian','Ji','Jiao','Jing','Zhan','Nang','Yi','Ai','Zhan','Pi','Hui','Hua','Yi','Yi','Shan','Rang','Nou','Qian','Dui','Ta','Hu','Zhou','Hao','Ai','Ying','Jian','Yu','Jian','Hui','Du','Zhe','Xuan','Zan','Lei','Shen','Wei','Chan','Li','Yi','Bian','Zhe','Yan','E','Chou','Wei','Chou','Yao','Chan','Rang','Yin','Lan','Chen','Xie','Nie','Huan','Zan','Yi','Dang','Zhan','Yan','Du','Yan','Ji','Ding','Fu','Ren','Ji','Jie','Hong','Tao','Rang','Shan','Qi','Tuo','Xun','Yi','Xun','Ji','Ren','Jiang','Hui','Ou','Ju','Ya','Ne','Xu','E','Lun','Xiong','Song','Feng','She','Fang','Jue','Zheng','Gu','He','Ping','Zu','Shi','Xiong','Zha','Su','Zhen','Di','Zhou','Ci','Qu','Zhao','Bi','Yi','Yi','Kuang','Lei','Shi','Gua','Shi','Ji','Hui','Cheng','Zhu','Shen','Hua','Dan','Gou','Quan','Gui','Xun','Yi','Zheng','Gai','Xiang','Cha','Hun','Xu','Zhou','Jie','Wu','Yu','Qiao','Wu','Gao','You','Hui','Kuang','Shuo','Song','Ei','Qing','Zhu','Zou','Nuo','Du','Zhuo','Fei','Ke','Wei')