b=('Yi','Bai','Chen','Wan','Zhi','Zhui','Biao','Yun','Zeng','Dan','Zan','Yan','Pu','Shan','Wan','Ying','Jin','Gan','Xian','Zang','Bi','Du','Shu','Yan','Shang','Xuan','Long','Gan','Zang','Bei','Zhen','Fu','Yuan','Gong','Cai','Ze','Xian','Bai','Zhang','Huo','Zhi','Fan','Tan','Pin','Bian','Gou','Zhu','Guan','Er','Jian','Ben','Shi','Tie','Gui','Kuang','Dai','Mao','Fei','He','Yi','Zei','Zhi','Jia','Hui','Zi','Lin','Lu','Zang','Zi','Gai','Jin','Qiu','Zhen','Lai','She','Fu','Du','Ji','Shu','Shang','Ci','Bi','Zhou','Geng','Pei','Dan','Lai','Feng','Zhui','Fu','Zhuan','Sai','Ze','Yan','Zan','Yun','Zeng','Shan','Ying','Gan','Chi','Xi','She','Nan','Tong','Xi','Cheng','He','Cheng','Zhe','Xia','Tang','Zou','Zou','Li','Jiu','Fu','Zhao','Gan','Qi','Shan','Qiong','Yin','Xian','Zi','Jue','Qin','Chi','Ci','Chen','Chen','Die','Ju','Chao','Di','Xi','Zhan','Jue','Yue','Qu','Ji','Chi','Chu','Gua','Xue','Zi','Tiao','Duo','Lie','Gan','Suo','Cu','Xi','Zhao','Su','Yin','Ju','Jian','Que','Tang','Chuo','Cui','Lu','Qu','Dang','Qiu','Zi','Ti','Qu','Chi','Huang','Qiao','Qiao','Jiao','Zao','Ti','Er','Zan','Zan','Zu','Pa','Bao','Ku','Ke','Dun','Jue','Fu','Chen','Jian','Fang','Zhi','Ta','Yue','Ba','Qi','Yue','Qiang','Tuo','Tai','Yi','Nian','Ling','Mei','Ba','Die','Ku','Tuo','Jia','Ci','Pao','Qia','Zhu','Ju','Dian','Zhi','Fu','Pan','Ju','Shan','Bo','Ni','Ju','Li','Gen','Yi','Ji','Duo','Xian','Jiao','Duo','Zhu','Quan','Kua','Zhuai','Gui','Qiong','Kui','Xiang','Chi','Lu','Pian','Zhi','Jia','Tiao','Cai','Jian','Da','Qiao','Bi','Xian','Duo','Ji','Ju','Ji','Shu','Tu')