b=('Gae','Gaeng','Geo','Go','Gol','Gwan','Gwi','Gau','Gyun','Geul','Geum','Na','Na','Na','Na','Na','Na','Na','Na','Na','Nag','Nag','Nag','Nag','Nag','Nag','Nag','Nan','Nan','Nan','Nan','Nan','Nan','Nam','Nam','Nam','Nam','Nab','Nab','Nab','Long','Nang','Nang','Nang','Nang','Nae','Naeng','No','No','No','No','No','No','No','Lou','No','No','No','No','Nog','Nog','Nog','Nog','Nog','Nog','Non','Nong','Nong','Nong','Nong','Noe','Noe','Noe','Noe','Nu','Nu','Nu','Nu','Nu','Nu','Nu','Nu','Neug','Neug','Neum','Neung','Neung','Neung','Neung','Neung','Du','La','Lag','Lag','Lan','Lyeong','Lo','Lyul','Li','Bae','Beon','Byeon','Bu','Bul','Bi','Sag','Sag','Sam','Saeg','Saeng','Seob','Se','Swae','Sin','Sim','Sib','Ya','Yag','Yag','Yang','Yang','Yang','Yang','Yang','Yang','Yang','Yang','Yeo','Yeo','Yeo','Yeo','Yeo','Yeo','Yeo','Yeo','Yeo','Yeo','Yeo','Yeog','Yeog','Yeog','Yeog','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeon','Yeol','Yeol','Yeol','Yeol','Yeol','Yeol','Yeom','Yeom','Yeom','Yeom','Yeom','Yeob','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Yeong','Ye','Ye','Ye','Ye','O','Yo','Yo','Yo','Yo','Yo','Yo','Yo','Yo','Yo','Yo','Yong','Un','Won','Yu','Yu','Yu','Yu','Yu','Yu','Yu','Yu','Yu','Yu','Yug','Yug','Yug','Yun','Yun','Yun','Yun','Yul','Yul','Yul','Yul','Yung','I','I','I','I','I','I','I','I','I','I','I','I','I','I','Ig','Ig','In','In','In','In','In','In','In','Im','Im','Im','Ib','Ib','Ib','Jang','Jeog','Ji','Jib','Cha','Cheog')