b=('Ben','Yuan','Wen','Ruo','Fei','Qing','Yuan','Ke','Ji','She','Yuan','Se','Lu','Zi','Du','Yi','Jian','Mian','Pai','Xi','Yu','Yuan','Shen','Shen','Rou','Huan','Zhu','Jian','Nuan','Yu','Qiu','Ting','Qu','Du','Fan','Zha','Bo','Wo','Wo','Di','Wei','Wen','Ru','Xie','Ce','Wei','He','Gang','Yan','Hong','Xuan','Mi','Ke','Mao','Ying','Yan','You','Hong','Miao','Sheng','Mei','Zai','Hun','Nai','Gui','Chi','E','Pai','Mei','Lian','Qi','Qi','Mei','Tian','Cou','Wei','Can','Tuan','Mian','Hui','Mo','Xu','Ji','Pen','Jian','Jian','Hu','Feng','Xiang','Yi','Yin','Zhan','Shi','Jie','Cheng','Huang','Tan','Yu','Bi','Min','Shi','Tu','Sheng','Yong','Ju','Dong','Tuan','Jiao','Jiao','Qiu','Yan','Tang','Long','Huo','Yuan','Nan','Ban','You','Quan','Zhuang','Liang','Chan','Xian','Chun','Nie','Zi','Wan','Shi','Man','Ying','La','Kui','Feng','Jian','Xu','Lou','Wei','Gai','Bo','Ying','Po','Jin','Yan','Tang','Yuan','Suo','Yuan','Lian','Yao','Meng','Zhun','Cheng','Ke','Tai','Ta','Wa','Liu','Gou','Sao','Ming','Zha','Shi','Yi','Lun','Ma','Pu','Wei','Li','Zai','Wu','Xi','Wen','Qiang','Ze','Shi','Su','Ai','Qin','Sou','Yun','Xiu','Yin','Rong','Hun','Su','Suo','Ni','Ta','Shi','Ru','Ai','Pan','Chu','Chu','Pang','Weng','Cang','Mie','Ge','Dian','Hao','Huang','Xi','Zi','Di','Zhi','Xing','Fu','Jie','Hua','Ge','Zi','Tao','Teng','Sui','Bi','Jiao','Hui','Gun','Yin','Gao','Long','Zhi','Yan','She','Man','Ying','Chun','Lu','Lan','Luan','Yao','Bin','Tan','Yu','Xiu','Hu','Bi','Biao','Zhi','Jiang','Kou','Shen','Shang','Di','Mi','Ao','Lu','Hu','Hu','You','Chan','Fan','Yong','Gun','Man')