b=('mya','myag','myakk','myags','myan','myanj','myanh','myad','myal','myalg','myalm','myalb','myals','myalt','myalp','myalh','myam','myab','myabs','myas','myass','myang','myaj','myach','myak','myat','myap','myah','myae','myaeg','myaekk','myaegs','myaen','myaenj','myaenh','myaed','myael','myaelg','myaelm','myaelb','myaels','myaelt','myaelp','myaelh','myaem','myaeb','myaebs','myaes','myaess','myaeng','myaej','myaech','myaek','myaet','myaep','myaeh','meo','meog','meokk','meogs','meon','meonj','meonh','meod','meol','meolg','meolm','meolb','meols','meolt','meolp','meolh','meom','meob','meobs','meos','meoss','meong','meoj','meoch','meok','meot','meop','meoh','me','meg','mekk','megs','men','menj','menh','med','mel','melg','melm','melb','mels','melt','melp','melh','mem','meb','mebs','mes','mess','meng','mej','mech','mek','met','mep','meh','myeo','myeog','myeokk','myeogs','myeon','myeonj','myeonh','myeod','myeol','myeolg','myeolm','myeolb','myeols','myeolt','myeolp','myeolh','myeom','myeob','myeobs','myeos','myeoss','myeong','myeoj','myeoch','myeok','myeot','myeop','myeoh','mye','myeg','myekk','myegs','myen','myenj','myenh','myed','myel','myelg','myelm','myelb','myels','myelt','myelp','myelh','myem','myeb','myebs','myes','myess','myeng','myej','myech','myek','myet','myep','myeh','mo','mog','mokk','mogs','mon','monj','monh','mod','mol','molg','molm','molb','mols','molt','molp','molh','mom','mob','mobs','mos','moss','mong','moj','moch','mok','mot','mop','moh','mwa','mwag','mwakk','mwags','mwan','mwanj','mwanh','mwad','mwal','mwalg','mwalm','mwalb','mwals','mwalt','mwalp','mwalh','mwam','mwab','mwabs','mwas','mwass','mwang','mwaj','mwach','mwak','mwat','mwap','mwah','mwae','mwaeg','mwaekk','mwaegs','mwaen','mwaenj','mwaenh','mwaed','mwael','mwaelg','mwaelm','mwaelb','mwaels','mwaelt','mwaelp','mwaelh','mwaem','mwaeb','mwaebs','mwaes','mwaess','mwaeng','mwaej','mwaech','mwaek','mwaet','mwaep','mwaeh','moe','moeg','moekk','moegs')