b=('bols','bolt','bolp','bolh','bom','bob','bobs','bos','boss','bong','boj','boch','bok','bot','bop','boh','bwa','bwag','bwakk','bwags','bwan','bwanj','bwanh','bwad','bwal','bwalg','bwalm','bwalb','bwals','bwalt','bwalp','bwalh','bwam','bwab','bwabs','bwas','bwass','bwang','bwaj','bwach','bwak','bwat','bwap','bwah','bwae','bwaeg','bwaekk','bwaegs','bwaen','bwaenj','bwaenh','bwaed','bwael','bwaelg','bwaelm','bwaelb','bwaels','bwaelt','bwaelp','bwaelh','bwaem','bwaeb','bwaebs','bwaes','bwaess','bwaeng','bwaej','bwaech','bwaek','bwaet','bwaep','bwaeh','boe','boeg','boekk','boegs','boen','boenj','boenh','boed','boel','boelg','boelm','boelb','boels','boelt','boelp','boelh','boem','boeb','boebs','boes','boess','boeng','boej','boech','boek','boet','boep','boeh','byo','byog','byokk','byogs','byon','byonj','byonh','byod','byol','byolg','byolm','byolb','byols','byolt','byolp','byolh','byom','byob','byobs','byos','byoss','byong','byoj','byoch','byok','byot','byop','byoh','bu','bug','bukk','bugs','bun','bunj','bunh','bud','bul','bulg','bulm','bulb','buls','bult','bulp','bulh','bum','bub','bubs','bus','buss','bung','buj','buch','buk','but','bup','buh','bwo','bwog','bwokk','bwogs','bwon','bwonj','bwonh','bwod','bwol','bwolg','bwolm','bwolb','bwols','bwolt','bwolp','bwolh','bwom','bwob','bwobs','bwos','bwoss','bwong','bwoj','bwoch','bwok','bwot','bwop','bwoh','bwe','bweg','bwekk','bwegs','bwen','bwenj','bwenh','bwed','bwel','bwelg','bwelm','bwelb','bwels','bwelt','bwelp','bwelh','bwem','bweb','bwebs','bwes','bwess','bweng','bwej','bwech','bwek','bwet','bwep','bweh','bwi','bwig','bwikk','bwigs','bwin','bwinj','bwinh','bwid','bwil','bwilg','bwilm','bwilb','bwils','bwilt','bwilp','bwilh','bwim','bwib','bwibs','bwis','bwiss','bwing','bwij','bwich','bwik','bwit','bwip','bwih','byu','byug','byukk','byugs','byun','byunj','byunh','byud','byul','byulg','byulm','byulb','byuls','byult','byulp','byulh')