b=('wek','wet','wep','weh','wi','wig','wikk','wigs','win','winj','winh','wid','wil','wilg','wilm','wilb','wils','wilt','wilp','wilh','wim','wib','wibs','wis','wiss','wing','wij','wich','wik','wit','wip','wih','yu','yug','yukk','yugs','yun','yunj','yunh','yud','yul','yulg','yulm','yulb','yuls','yult','yulp','yulh','yum','yub','yubs','yus','yuss','yung','yuj','yuch','yuk','yut','yup','yuh','eu','eug','eukk','eugs','eun','eunj','eunh','eud','eul','eulg','eulm','eulb','euls','eult','eulp','eulh','eum','eub','eubs','eus','euss','eung','euj','euch','euk','eut','eup','euh','ui','uig','uikk','uigs','uin','uinj','uinh','uid','uil','uilg','uilm','uilb','uils','uilt','uilp','uilh','uim','uib','uibs','uis','uiss','uing','uij','uich','uik','uit','uip','uih','i','ig','ikk','igs','in','inj','inh','id','il','ilg','ilm','ilb','ils','ilt','ilp','ilh','im','ib','ibs','is','iss','ing','ij','ich','ik','it','ip','ih','ja','jag','jakk','jags','jan','janj','janh','jad','jal','jalg','jalm','jalb','jals','jalt','jalp','jalh','jam','jab','jabs','jas','jass','jang','jaj','jach','jak','jat','jap','jah','jae','jaeg','jaekk','jaegs','jaen','jaenj','jaenh','jaed','jael','jaelg','jaelm','jaelb','jaels','jaelt','jaelp','jaelh','jaem','jaeb','jaebs','jaes','jaess','jaeng','jaej','jaech','jaek','jaet','jaep','jaeh','jya','jyag','jyakk','jyags','jyan','jyanj','jyanh','jyad','jyal','jyalg','jyalm','jyalb','jyals','jyalt','jyalp','jyalh','jyam','jyab','jyabs','jyas','jyass','jyang','jyaj','jyach','jyak','jyat','jyap','jyah','jyae','jyaeg','jyaekk','jyaegs','jyaen','jyaenj','jyaenh','jyaed','jyael','jyaelg','jyaelm','jyaelb','jyaels','jyaelt','jyaelp','jyaelh','jyaem','jyaeb','jyaebs','jyaes','jyaess','jyaeng','jyaej','jyaech','jyaek','jyaet','jyaep','jyaeh')