b=('Wan','Guo','Lu','Hao','Jie','Yi','Chou','Ju','Ju','Cheng','Zuo','Liang','Qiang','Zhi','Chui','Ya','Ju','Bei','Jiao','Zhuo','Zi','Bin','Peng','Ding','Chu','Chang','Men','Hua','Jian','Gui','Xi','Du','Qian','Dao','Gui','Dian','Luo','Zhi','Quan','Ming','Fu','Geng','Peng','Shan','Yi','Tuo','Sen','Duo','Ye','Fu','Wei','Wei','Duan','Jia','Zong','Jian','Yi','Shen','Xi','Yan','Yan','Chuan','Jian','Chun','Yu','He','Zha','Wo','Pian','Bi','Yao','Huo','Xu','Ruo','Yang','La','Yan','Ben','Hui','Kui','Jie','Kui','Si','Feng','Xie','Tuo','Zhi','Jian','Mu','Mao','Chu','Hu','Hu','Lian','Leng','Ting','Nan','Yu','You','Mei','Song','Xuan','Xuan','Yang','Zhen','Pian','Ye','Ji','Jie','Ye','Chu','Dun','Yu','Zou','Wei','Mei','Ti','Ji','Jie','Kai','Qiu','Ying','Rou','Huang','Lou','Le','Quan','Xiang','Pin','Shi','Gai','Tan','Lan','Wen','Yu','Chen','Lu','Ju','Shen','Chu','Bi','Xie','Jia','Yi','Zhan','Fu','Nuo','Mi','Lang','Rong','Gu','Jian','Ju','Ta','Yao','Zhen','Bang','Sha','Yuan','Zi','Ming','Su','Jia','Yao','Jie','Huang','Gan','Fei','Zha','Qian','Ma','Sun','Yuan','Xie','Rong','Shi','Zhi','Cui','Wen','Ting','Liu','Rong','Tang','Que','Zhai','Si','Sheng','Ta','Ke','Xi','Gu','Qi','Gao','Gao','Sun','Pan','Tao','Ge','Chun','Dian','Nou','Ji','Shuo','Gou','Chui','Qiang','Cha','Qian','Huai','Mei','Xu','Gang','Gao','Zhuo','Tuo','Qiao','Yang','Dian','Jia','Kan','Zui','Dao','Long','Bin','Zhu','Sang','Xi','Ji','Lian','Hui','Yong','Qian','Guo','Gai','Gai','Tuan','Hua','Qi','Sen','Cui','Peng','You','Hu','Jiang','Hu','Huan','Gui','Nie','Yi','Gao','Kang','Gui','Gui','Cao','Man','Jin')