b=('sseum','sseub','sseubs','sseus','sseuss','sseung','sseuj','sseuch','sseuk','sseut','sseup','sseuh','ssui','ssuig','ssuikk','ssuigs','ssuin','ssuinj','ssuinh','ssuid','ssuil','ssuilg','ssuilm','ssuilb','ssuils','ssuilt','ssuilp','ssuilh','ssuim','ssuib','ssuibs','ssuis','ssuiss','ssuing','ssuij','ssuich','ssuik','ssuit','ssuip','ssuih','ssi','ssig','ssikk','ssigs','ssin','ssinj','ssinh','ssid','ssil','ssilg','ssilm','ssilb','ssils','ssilt','ssilp','ssilh','ssim','ssib','ssibs','ssis','ssiss','ssing','ssij','ssich','ssik','ssit','ssip','ssih','a','ag','akk','ags','an','anj','anh','ad','al','alg','alm','alb','als','alt','alp','alh','am','ab','abs','as','ass','ang','aj','ach','ak','at','ap','ah','ae','aeg','aekk','aegs','aen','aenj','aenh','aed','ael','aelg','aelm','aelb','aels','aelt','aelp','aelh','aem','aeb','aebs','aes','aess','aeng','aej','aech','aek','aet','aep','aeh','ya','yag','yakk','yags','yan','yanj','yanh','yad','yal','yalg','yalm','yalb','yals','yalt','yalp','yalh','yam','yab','yabs','yas','yass','yang','yaj','yach','yak','yat','yap','yah','yae','yaeg','yaekk','yaegs','yaen','yaenj','yaenh','yaed','yael','yaelg','yaelm','yaelb','yaels','yaelt','yaelp','yaelh','yaem','yaeb','yaebs','yaes','yaess','yaeng','yaej','yaech','yaek','yaet','yaep','yaeh','eo','eog','eokk','eogs','eon','eonj','eonh','eod','eol','eolg','eolm','eolb','eols','eolt','eolp','eolh','eom','eob','eobs','eos','eoss','eong','eoj','eoch','eok','eot','eop','eoh','e','eg','ekk','egs','en','enj','enh','ed','el','elg','elm','elb','els','elt','elp','elh','em','eb','ebs','es','ess','eng','ej','ech','ek','et','ep','eh','yeo','yeog','yeokk','yeogs','yeon','yeonj','yeonh','yeod','yeol','yeolg','yeolm','yeolb','yeols','yeolt','yeolp','yeolh','yeom','yeob','yeobs','yeos')