b=('Yao','Yu','Chong','Xi','Xi','Jiu','Yu','Yu','Xing','Ju','Jiu','Xin','She','She','She','Jiu','Shi','Tan','Shu','Shi','Tian','Tan','Pu','Pu','Guan','Hua','Tian','Chuan','Shun','Xia','Wu','Zhou','Dao','Chuan','Shan','Yi','Fan','Pa','Tai','Fan','Ban','Chuan','Hang','Fang','Ban','Bi','Lu','Zhong','Jian','Cang','Ling','Zhu','Ze','Duo','Bo','Xian','Ge','Chuan','Xia','Lu','Qiong','Pang','Xi','Kua','Fu','Zao','Feng','Li','Shao','Yu','Lang','Ting','Yu','Wei','Bo','Meng','Nian','Ju','Huang','Shou','Ke','Bian','Mu','Die','Dao','Bang','Cha','Yi','Sou','Cang','Cao','Lou','Dai','Xue','Yao','Chong','Deng','Dang','Qiang','Lu','Yi','Ji','Jian','Huo','Meng','Qi','Lu','Lu','Chan','Shuang','Gen','Liang','Jian','Jian','Se','Yan','Fu','Ping','Yan','Yan','Cao','Cao','Yi','Le','Ting','Jiao','Ai','Nai','Tiao','Jiao','Jie','Peng','Wan','Yi','Chai','Mian','Mi','Gan','Qian','Yu','Yu','Shao','Qiong','Du','Hu','Qi','Mang','Zi','Hui','Sui','Zhi','Xiang','Pi','Fu','Tun','Wei','Wu','Zhi','Qi','Shan','Wen','Qian','Ren','Fu','Kou','Jie','Lu','Xu','Ji','Qin','Qi','Yan','Fen','Ba','Rui','Xin','Ji','Hua','Hua','Fang','Wu','Jue','Gou','Zhi','Yun','Qin','Ao','Chu','Mao','Ya','Fei','Reng','Hang','Cong','Yin','You','Bian','Yi','Qie','Wei','Li','Pi','E','Xian','Chang','Cang','Zhu','Su','Ti','Yuan','Ran','Ling','Tai','Shao','Di','Miao','Qing','Li','Yong','Ke','Mu','Bei','Bao','Gou','Min','Yi','Yi','Ju','Pie','Ruo','Ku','Ning','Ni','Bo','Bing','Shan','Xiu','Yao','Xian','Ben','Hong','Ying','Zha','Dong','Ju','Die','Nie','Gan','Hu','Ping','Mei','Fu','Sheng','Gu','Bi','Wei')