b=('Lang','Kan','Lao','Lai','Xian','Que','Kong','Chong','Chong','Ta','Lin','Hua','Ju','Lai','Qi','Min','Kun','Kun','Zu','Gu','Cui','Ya','Ya','Gang','Lun','Lun','Leng','Jue','Duo','Zheng','Guo','Yin','Dong','Han','Zheng','Wei','Xiao','Pi','Yan','Song','Jie','Beng','Zu','Ku','Dong','Zhan','Gu','Yin','Zi','Ze','Huang','Yu','Wai','Yang','Feng','Qiu','Yang','Ti','Yi','Zhi','Shi','Zai','Yao','E','Zhu','Kan','Lu','Yan','Mei','Han','Ji','Ji','Huan','Ting','Sheng','Mei','Qian','Wu','Yu','Zong','Lan','Ke','Yan','Yan','Wei','Zong','Cha','Sui','Rong','Ke','Qin','Yu','Qi','Lou','Tu','Dui','Xi','Weng','Cang','Dang','Rong','Jie','Kai','Liu','Wu','Song','Qiao','Zi','Wei','Beng','Dian','Cuo','Qian','Yong','Nie','Cuo','Ji','Shi','Ruo','Song','Zong','Jiang','Liao','Kang','Chan','Die','Cen','Ding','Tu','Lou','Zhang','Zhan','Zhan','Ao','Cao','Qu','Qiang','Cui','Zui','Dao','Dao','Xi','Yu','Pei','Long','Xiang','Ceng','Bo','Qin','Jiao','Yan','Lao','Zhan','Lin','Liao','Liao','Jin','Deng','Duo','Zun','Jiao','Gui','Yao','Jiao','Yao','Jue','Zhan','Yi','Xue','Nao','Ye','Ye','Yi','Nie','Xian','Ji','Xie','Ke','Xi','Di','Ao','Zui','Wei','Yi','Rong','Dao','Ling','Jie','Yu','Yue','Yin','Ru','Jie','Li','Gui','Long','Long','Dian','Rong','Xi','Ju','Chan','Ying','Kui','Yan','Wei','Nao','Quan','Chao','Cuan','Luan','Dian','Dian','Nie','Yan','Yan','Yan','Kui','Yan','Chuan','Kuai','Chuan','Zhou','Huang','Jing','Xun','Chao','Chao','Lie','Gong','Zuo','Qiao','Ju','Gong','Ju','Wu','Pu','Pu','Cha','Qiu','Qiu','Ji','Yi','Si','Ba','Zhi','Zhao','Xiang','Yi','Jin','Xun','Juan','Ba','Xun','Jin','Fu')