b=('Er','Gong','Ju','Jiao','Guang','He','Kai','Quan','Zhou','Zai','Zhi','She','Liang','Yu','Shao','You','Wan','Yin','Zhe','Wan','Fu','Qing','Zhou','Ni','Leng','Zhe','Zhan','Liang','Zi','Hui','Wang','Chuo','Guo','Kan','Yi','Peng','Qian','Gun','Nian','Ping','Guan','Bei','Lun','Pai','Liang','Ruan','Rou','Ji','Yang','Xian','Chuan','Cou','Chun','Ge','You','Hong','Shu','Fu','Zi','Fu','Wen','Ben','Zhan','Yu','Wen','Tao','Gu','Zhen','Xia','Yuan','Lu','Jiao','Chao','Zhuan','Wei','Hun','Xue','Zhe','Jiao','Zhan','Bu','Lao','Fen','Fan','Lin','Ge','Se','Kan','Huan','Yi','Ji','Zhui','Er','Yu','Jian','Hong','Lei','Pei','Li','Li','Lu','Lin','Che','Ya','Gui','Xuan','Dai','Ren','Zhuan','E','Lun','Ruan','Hong','Gu','Ke','Lu','Zhou','Zhi','Yi','Hu','Zhen','Li','Yao','Qing','Shi','Zai','Zhi','Jiao','Zhou','Quan','Lu','Jiao','Zhe','Fu','Liang','Nian','Bei','Hui','Gun','Wang','Liang','Chuo','Zi','Cou','Fu','Ji','Wen','Shu','Pei','Yuan','Xia','Nian','Lu','Zhe','Lin','Xin','Gu','Ci','Ci','Pi','Zui','Bian','La','La','Ci','Xue','Ban','Bian','Bian','Bian','Xue','Bian','Ban','Ci','Bian','Bian','Chen','Ru','Nong','Nong','Chan','Chuo','Chuo','Yi','Reng','Bian','Bian','Shi','Yu','Liao','Da','Chan','Gan','Qian','Yu','Yu','Qi','Xun','Yi','Guo','Mai','Qi','Za','Wang','Tu','Zhun','Ying','Da','Yun','Jin','Hang','Ya','Fan','Wu','Da','E','Hai','Zhe','Da','Jin','Yuan','Wei','Lian','Chi','Che','Ni','Tiao','Zhi','Yi','Jiong','Jia','Chen','Dai','Er','Di','Po','Zhu','Die','Ze','Tao','Shu','Tuo','Qu','Jing','Hui','Dong','You','Mi','Beng','Ji','Nai','Yi','Jie','Zhui','Lie','Xun')