b=('San','Lun','Ping','Zhao','Han','Yu','Dai','Zhao','Fei','Sha','Ling','Ta','Qu','Mang','Ye','Bao','Gui','Gua','Nan','Ge','Gaa','Shi','Ke','Suo','Ci','Zhou','Tai','Kuai','Qin','Xu','Du','Ce','Huan','Cong','Sai','Zheng','Qian','Jin','Zong','Wei','','','Xi','Na','Pu','Sou','Ju','Zhen','Shao','Tao','Ban','Ta','Qian','Weng','Rong','Luo','Hu','Sou','Zhong','Pu','Mie','Jin','Shao','Mi','Shu','Ling','Lei','Jiang','Leng','Zhi','Diao','','San','Gu','Fan','Mei','Sui','Jian','Tang','Xie','Ku','Wu','Fan','Luo','Can','Ceng','Ling','Yi','Cong','Yun','Meng','Yu','Zhi','Yi','Dan','Huo','Wei','Tan','Se','Xie','Sou','Song','Qian','Liu','Yi','Aau','Lei','Li','Fei','Lie','Lin','Xian','Xiao','Ou','Mi','Xian','Rang','Zhuan','Shuang','Yan','Bian','Ling','Hong','Qi','Liao','Ban','Bi','Hu','Hu','Caap','Ce','Pei','Qiong','Ming','Jiu','Bu','Mei','San','Wei','Zong','Bei','Li','Quan','Sam','Hun','Xiang','Zing','Shi','Ying','Gin','Nan','Huang','Jiu','Yan','Deoi','Sa','Tuan','Xie','Zhe','Men','Xi','Man','Zoeng','Huang','Tan','Xiao','Ye','Bi','Luo','Fan','Li','Cui','Chua','Dao','Di','Kuang','Chu','Xian','Chan','Mi','Qian','Qiu','Zhen','Zi','Heoi','Cim','Hu','Gan','Chi','Guai','Mu','Bo','Hua','Geng','Yao','Mao','Wang','','','','Ru','Xue','Zheng','Min','Jiang','O','Zhan','Zuo','Yue','Lie','Nou','Zhou','Bi','Ren','Yu','Gin','Chuo','Er','Yi','Mi','Qing','Zing','Wang','Ji','Bu','Syu','Bie','Fan','Yue','Li','Fan','Qu','Fu','Er','E','Zheng','Tian','Yu','Jin','Qi','Ju','Lai','Che','Bei','Niu','Yi','Xu','Mou','Xun','Fu','Cau','Nin','Ting','Beng','Zha','Wei')