b=('Ze','Shai','Gui','Yi','Hu','Chan','Kou','Cu','Ping','Zao','Ji','Gui','Su','Lou','Ce','Lu','Nian','Suo','Cuan','Diao','Suo','Le','Duan','Liang','Xiao','Bo','Mi','Shai','Dang','Liao','Dan','Dian','Fu','Jian','Min','Kui','Dai','Jiao','Deng','Huang','Sun','Lao','Zan','Xiao','Lu','Shi','Zan','Qi','Pai','Qi','Pai','Gan','Ju','Lu','Lu','Yan','Bo','Dang','Sai','Zhua','Gou','Qian','Lian','Bu','Zhou','Lai','Shi','Lan','Kui','Yu','Yue','Hao','Zhen','Tai','Ti','Nie','Chou','Ji','Yi','Qi','Teng','Zhuan','Zhou','Fan','Sou','Zhou','Qian','Zhuo','Teng','Lu','Lu','Jian','Tuo','Ying','Yu','Lai','Long','Qie','Lian','Lan','Qian','Yue','Zhong','Qu','Lian','Bian','Duan','Zuan','Li','Si','Luo','Ying','Yue','Zhuo','Yu','Mi','Di','Fan','Shen','Zhe','Shen','Nu','He','Lei','Xian','Zi','Ni','Cun','Zhang','Qian','Zhai','Bi','Ban','Wu','Sha','Kang','Rou','Fen','Bi','Cui','Yin','Zhe','Mi','Tai','Hu','Ba','Li','Gan','Ju','Po','Mo','Cu','Zhan','Zhou','Chi','Su','Tiao','Li','Xi','Su','Hong','Tong','Zi','Ce','Yue','Zhou','Lin','Zhuang','Bai','Lao','Fen','Er','Qu','He','Liang','Xian','Fu','Liang','Can','Jing','Li','Yue','Lu','Ju','Qi','Cui','Bai','Zhang','Lin','Zong','Jing','Guo','Hua','San','San','Tang','Bian','Rou','Mian','Hou','Xu','Zong','Hu','Jian','Zan','Ci','Li','Xie','Fu','Nuo','Bei','Gu','Xiu','Gao','Tang','Qiu','Jia','Cao','Zhuang','Tang','Mi','San','Fen','Zao','Kang','Jiang','Mo','San','San','Nuo','Xi','Liang','Jiang','Kuai','Bo','Huan','Shu','Zong','Xian','Nuo','Tuan','Nie','Li','Zuo','Di','Nie','Tiao','Lan','Mi','Si','Jiu','Xi','Gong','Zheng','Jiu','You')