b=('Hu','Ye','Ding','Qing','Kui','Xiang','Shun','Han','Xu','Yi','Xu','E','Song','Kui','Qi','Hang','Yu','Wan','Ban','Dun','Di','Dan','Pan','Po','Ling','Che','Jing','Lei','He','Qiao','E','E','Wei','Xie','Kuo','Shen','Yi','Yi','Hai','Dui','Yu','Ping','Lei','Fu','Jia','Tou','Hui','Kui','Jia','Luo','Ting','Cheng','Ying','Yun','Hu','Han','Jing','Tui','Tui','Pin','Lai','Tui','Zi','Zi','Chui','Ding','Lai','Tan','Han','Qian','Ke','Cui','Xuan','Qin','Yi','Sai','Ti','E','E','Yan','Wen','Kan','Yong','Zhuan','Yan','Xian','Xin','Yi','Yuan','Sang','Dian','Dian','Jiang','Kui','Lei','Lao','Piao','Wai','Man','Cu','Yao','Hao','Qiao','Gu','Xun','Yan','Hui','Chan','Ru','Meng','Bin','Xian','Pin','Lu','Lan','Nie','Quan','Ye','Ding','Qing','Han','Xiang','Shun','Xu','Xu','Wan','Gu','Dun','Qi','Ban','Song','Hang','Yu','Lu','Ling','Po','Jing','Jie','Jia','Ting','He','Ying','Jiong','Ke','Yi','Pin','Hui','Tui','Han','Ying','Ying','Ke','Ti','Yong','E','Zhuan','Yan','E','Nie','Man','Dian','Sang','Hao','Lei','Chan','Ru','Pin','Quan','Feng','Biao','Gua','Fu','Xia','Zhan','Biao','Sa','Ba','Tai','Lie','Gua','Xuan','Shao','Ju','Biao','Si','Wei','Yang','Yao','Sou','Kai','Sou','Fan','Liu','Xi','Liu','Piao','Piao','Liu','Biao','Biao','Biao','Liao','Biao','Se','Feng','Xiu','Feng','Yang','Zhan','Biao','Sa','Ju','Si','Sou','Yao','Liu','Piao','Biao','Biao','Fei','Fan','Fei','Fei','Shi','Shi','Can','Ji','Ding','Si','Tuo','Zhan','Sun','Xiang','Tun','Ren','Yu','Juan','Chi','Yin','Fan','Fan','Sun','Yin','Tou','Yi','Zuo','Bi','Jie','Tao','Bao','Ci','Tie','Si','Bao','Shi','Duo')