b=('Chang','Zhi','Bing','Jiu','Yao','Cui','Lia','Wan','Lai','Cang','Zong','Ge','Guan','Bei','Tian','Shu','Shu','Men','Dao','Tan','Jue','Chui','Xing','Peng','Tang','Hou','Yi','Qi','Ti','Gan','Jing','Jie','Sui','Chang','Jie','Fang','Zhi','Kong','Juan','Zong','Ju','Qian','Ni','Lun','Zhuo','Wo','Luo','Song','Leng','Hun','Dong','Zi','Ben','Wu','Ju','Nai','Cai','Jian','Zhai','Ye','Zhi','Sha','Qing','Ning','Ying','Cheng','Qian','Yan','Ruan','Zhong','Chun','Jia','Ji','Wei','Yu','Bing','Ruo','Ti','Wei','Pian','Yan','Feng','Tang','Wo','E','Xie','Che','Sheng','Kan','Di','Zuo','Cha','Ting','Bei','Xie','Huang','Yao','Zhan','Chou','Yan','You','Jian','Xu','Zha','Ci','Fu','Bi','Zhi','Zong','Mian','Ji','Yi','Xie','Xun','Cai','Duan','Ce','Zhen','Ou','Tou','Tou','Bei','Za','Lou','Jie','Wei','Fen','Chang','Gui','Sou','Zhi','Su','Xia','Fu','Yuan','Rong','Li','Nu','Yun','Jiang','Ma','Bang','Dian','Tang','Hao','Jie','Xi','Shan','Qian','Jue','Cang','Chu','San','Bei','Xiao','Yong','Yao','Tan','Suo','Yang','Fa','Bing','Jia','Dai','Zai','Tang','Gu','Bin','Chu','Nuo','Can','Lei','Cui','Yong','Zao','Zong','Beng','Song','Ao','Chuan','Yu','Zhai','Zu','Shang','Chuang','Jing','Chi','Sha','Han','Zhang','Qing','Yan','Di','Xie','Lou','Bei','Piao','Jin','Lian','Lu','Man','Qian','Xian','Tan','Ying','Dong','Zhuan','Xiang','Shan','Qiao','Jiong','Tui','Zun','Pu','Xi','Lao','Chang','Guang','Liao','Qi','Cheng','Chan','Wei','Ji','Bo','Hui','Chuan','Tie','Dan','Jiao','Jiu','Seng','Fen','Xian','Ju','E','Jiao','Jian','Tong','Lin','Bo','Gu','Xian','Su','Xian','Jiang','Min','Ye','Jin','Jia','Qiao','Pi','Feng','Zhou','Ai','Sai')