b=('Han','Xuan','Yan','Qiu','Xuan','Lang','Li','Xiu','Fu','Liu','Ya','Xi','Ling','Li','Jin','Lian','Suo','Suo','Feng','Wan','Dian','Pin','Zhan','Se','Min','Yu','Ju','Chen','Lai','Min','Sheng','Wei','Tian','Chu','Zuo','Beng','Cheng','Hu','Qi','E','Kun','Chang','Qi','Beng','Wan','Lu','Cong','Guan','Yan','Diao','Bei','Lin','Qin','Pi','Pa','Que','Zhuo','Qin','Fa','Jin','Qiong','Du','Jie','Hun','Yu','Mao','Mei','Chun','Xuan','Ti','Xing','Dai','Rou','Min','Jian','Wei','Ruan','Huan','Xie','Chuan','Jian','Zhuan','Chang','Lian','Quan','Xia','Duan','Yuan','Ya','Nao','Hu','Ying','Yu','Huang','Rui','Se','Liu','Shi','Rong','Suo','Yao','Wen','Wu','Zhen','Jin','Ying','Ma','Tao','Liu','Tang','Li','Lang','Gui','Zhen','Qiang','Cuo','Jue','Zhao','Yao','Ai','Bin','Shu','Chang','Kun','Zhuan','Cong','Jin','Yi','Cui','Cong','Qi','Li','Jing','Suo','Qiu','Xuan','Ao','Lian','Men','Zhang','Yin','Ye','Ying','Wei','Lu','Wu','Deng','Xiu','Zeng','Xun','Qu','Dang','Lin','Liao','Qiong','Su','Huang','Gui','Pu','Jing','Fan','Jin','Liu','Ji','Hui','Jing','Ai','Bi','Can','Qu','Zao','Dang','Jiao','Gun','Tan','Hui','Huan','Se','Sui','Tian','Chu','Yu','Jin','Lu','Bin','Shu','Wen','Zui','Lan','Xi','Zi','Xuan','Ruan','Wo','Gai','Lei','Du','Li','Zhi','Rou','Li','Zan','Qiong','Ti','Gui','Sui','La','Long','Lu','Li','Zan','Lan','Ying','Mi','Xiang','Qiong','Guan','Dao','Zan','Huan','Gua','Bo','Die','Bo','Hu','Zhi','Piao','Ban','Rang','Li','Wa','Ngaa','Xiang','Qian','Ban','Pen','Fang','Dan','Weng','Ou','Fan','Hou','Wa','Hu','Ling','Yi','Ping','Ci','Bai','Juan','Chang','Chi','Sarake','Dang','Meng','Bu')