b=('Ba','Fang','Chen','Xing','Dou','Yue','Qian','Fu','Pi','Na','Xin','E','Jue','Dun','Gou','Yin','Qian','Ban','Sa','Ren','Chao','Niu','Fen','Yun','Yi','Qin','Pi','Guo','Hong','Yin','Jun','Diao','Yi','Zhong','Xi','Gai','Ri','Huo','Tai','Kang','Yuan','Lu','E','Qin','Duo','Zi','Ni','Tu','Shi','Min','Gu','Ke','Ling','Bing','Si','Gu','Bo','Pi','Yu','Si','Zuo','Bu','You','Tian','Jia','Zhen','Shi','Shi','Zhi','Ju','Chan','Shi','Shi','Xuan','Zhao','Bao','He','Bi','Sheng','Chu','Shi','Bo','Zhu','Chi','Za','Po','Tong','Qian','Fu','Zhai','Liu','Qian','Fu','Li','Yue','Pi','Yang','Ban','Bo','Jie','Gou','Shu','Zheng','Mu','Xi','Xi','Di','Jia','Mu','Tan','Huan','Yi','Si','Kuang','Ka','Bei','Jian','Tong','Xing','Hong','Jiao','Chi','Er','Luo','Bing','Shi','Mou','Jia','Yin','Jun','Zhou','Chong','Xiang','Tong','Mo','Lei','Ji','Yu','Xu','Ren','Zun','Zhi','Qiong','Shan','Chi','Xian','Xing','Quan','Pi','Tie','Zhu','Xiang','Ming','Kua','Yao','Xian','Xian','Xiu','Jun','Cha','Lao','Ji','Pi','Ru','Mi','Yi','Yin','Guang','An','Diu','You','Se','Kao','Qian','Luan','Si','Ai','Diao','Han','Rui','Shi','Keng','Qiu','Xiao','Zhe','Xiu','Zang','Ti','Cuo','Gua','Hong','Zhong','Tou','Lu','Mei','Lang','Wan','Xin','Yun','Bei','Wu','Su','Yu','Chan','Ding','Bo','Han','Jia','Hong','Cuan','Feng','Chan','Wan','Zhi','Si','Xuan','Hua','Yu','Tiao','Kuang','Zhuo','Lue','Xing','Qin','Shen','Han','Lue','Ye','Chu','Zeng','Ju','Xian','Tie','Mang','Pu','Li','Pan','Rui','Cheng','Gao','Li','Te','Bing','Zhu','Zhen','Tu','Liu','Zui','Ju','Chang','Yuan','Jian','Gang','Diao','Tao','Chang')