b=('Yi','Jun','Nong','Chan','Yi','Dang','Jing','Xuan','Kuai','Jian','Chu','Dan','Jiao','Sha','Zai','Can','Bin','An','Ru','Tai','Chou','Chai','Lan','Ni','Jin','Qian','Meng','Wu','Ning','Qiong','Ni','Chang','Lie','Lei','Lu','Kuang','Bao','Yu','Biao','Zan','Zhi','Si','You','Hao','Qing','Chen','Li','Teng','Wei','Long','Chu','Chan','Rang','Shu','Hui','Li','Luo','Zan','Nuo','Tang','Yan','Lei','Nang','Er','Wu','Yun','Zan','Yuan','Xiong','Chong','Zhao','Xiong','Xian','Guang','Dui','Ke','Dui','Mian','Tu','Chang','Er','Dui','Er','Jin','Tu','Si','Yan','Yan','Shi','Shi ','Dang','Qian','Dou','Fen','Mao','Shen','Dou','Bai ','Jing','Li','Huang','Ru','Wang','Nei','Quan','Liang','Yu','Ba','Gong','Liu','Xi','Han','Lan','Gong','Tian','Guan','Xing','Bing','Qi','Ju','Dian','Zi','Fen','Yang','Jian','Shou','Ji','Yi','Ji','Chan','Jiong','Mao','Ran','Nei','Yuan','Mao','Gang','Ran','Ce','Jiong','Ce','Zai','Gua','Jiong','Mao','Zhou','Mao','Gou','Xu','Mian','Mi','Rong','Yin','Xie','Kan','Jun','Nong','Yi','Mi','Shi','Guan','Meng','Zhong','Ju','Yuan','Ming','Kou','Lin','Fu','Xie','Mi','Bing','Dong','Tai','Gang','Feng','Bing','Hu','Chong','Jue','Hu','Kuang','Ye','Leng','Pan','Fu','Min','Dong','Xian','Lie','Qia','Jian','Jing','Sou','Mei','Tu','Qi','Gu','Zhun','Song','Jing','Liang','Qing','Diao','Ling','Dong','Gan','Jian','Yin','Cou','Ai','Li','Chuang','Ming','Zhun','Cui','Si','Duo','Jin','Lin','Lin','Ning','Xi','Du','Ji','Fan','Fan','Fan','Feng','Ju','Chu','Zheng','Feng','Mu','Zhi','Fu','Feng','Ping','Feng','Kai','Huang','Kai','Gan','Deng','Ping','Qian','Xiong','Kuai','Tu','Ao','Chu','Ji','Dang','Han','Han','Zao')