b=('sswals','sswalt','sswalp','sswalh','sswam','sswab','sswabs','sswas','sswass','sswang','sswaj','sswach','sswak','sswat','sswap','sswah','sswae','sswaeg','sswaekk','sswaegs','sswaen','sswaenj','sswaenh','sswaed','sswael','sswaelg','sswaelm','sswaelb','sswaels','sswaelt','sswaelp','sswaelh','sswaem','sswaeb','sswaebs','sswaes','sswaess','sswaeng','sswaej','sswaech','sswaek','sswaet','sswaep','sswaeh','ssoe','ssoeg','ssoekk','ssoegs','ssoen','ssoenj','ssoenh','ssoed','ssoel','ssoelg','ssoelm','ssoelb','ssoels','ssoelt','ssoelp','ssoelh','ssoem','ssoeb','ssoebs','ssoes','ssoess','ssoeng','ssoej','ssoech','ssoek','ssoet','ssoep','ssoeh','ssyo','ssyog','ssyokk','ssyogs','ssyon','ssyonj','ssyonh','ssyod','ssyol','ssyolg','ssyolm','ssyolb','ssyols','ssyolt','ssyolp','ssyolh','ssyom','ssyob','ssyobs','ssyos','ssyoss','ssyong','ssyoj','ssyoch','ssyok','ssyot','ssyop','ssyoh','ssu','ssug','ssukk','ssugs','ssun','ssunj','ssunh','ssud','ssul','ssulg','ssulm','ssulb','ssuls','ssult','ssulp','ssulh','ssum','ssub','ssubs','ssus','ssuss','ssung','ssuj','ssuch','ssuk','ssut','ssup','ssuh','sswo','sswog','sswokk','sswogs','sswon','sswonj','sswonh','sswod','sswol','sswolg','sswolm','sswolb','sswols','sswolt','sswolp','sswolh','sswom','sswob','sswobs','sswos','sswoss','sswong','sswoj','sswoch','sswok','sswot','sswop','sswoh','sswe','ssweg','sswekk','sswegs','sswen','sswenj','sswenh','sswed','sswel','sswelg','sswelm','sswelb','sswels','sswelt','sswelp','sswelh','sswem','ssweb','sswebs','sswes','sswess','ssweng','sswej','sswech','sswek','sswet','sswep','ssweh','sswi','sswig','sswikk','sswigs','sswin','sswinj','sswinh','sswid','sswil','sswilg','sswilm','sswilb','sswils','sswilt','sswilp','sswilh','sswim','sswib','sswibs','sswis','sswiss','sswing','sswij','sswich','sswik','sswit','sswip','sswih','ssyu','ssyug','ssyukk','ssyugs','ssyun','ssyunj','ssyunh','ssyud','ssyul','ssyulg','ssyulm','ssyulb','ssyuls','ssyult','ssyulp','ssyulh','ssyum','ssyub','ssyubs','ssyus','ssyuss','ssyung','ssyuj','ssyuch','ssyuk','ssyut','ssyup','ssyuh','sseu','sseug','sseukk','sseugs','sseun','sseunj','sseunh','sseud','sseul','sseulg','sseulm','sseulb','sseuls','sseult','sseulp','sseulh')