b=('Gui','Deng','Zhi','Xu','Yi','Hua','Xi','Kui','Rao','Xi','Yan','Chan','Jiao','Mei','Fan','Fan','Xian','Yi','Hui','Jiao','Fu','Shi','Bi','Shan','Sui','Qiang','Lian','Huan','Xin','Niao','Dong','Yi','Can','Ai','Niang','Ning','Ma','Tiao','Chou','Jin','Ci','Yu','Pin','Rong','Ru','Nai','Yan','Tai','Ying','Qian','Niao','Yue','Ying','Mian','Bi','Ma','Shen','Xing','Ni','Du','Liu','Yuan','Lan','Yan','Shuang','Ling','Jiao','Niang','Lan','Qian','Ying','Shuang','Hui','Quan','Mi','Li','Luan','Yan','Zhu','Lan','Zi','Jie','Jue','Jue','Kong','Yun','Ma','Zi','Cun','Sun','Fu','Bei','Zi','Xiao','Xin','Meng','Si','Tai','Bao','Ji','Gu','Nu','Xue','You','Zhuan','Hai','Luan','Sun','Nao','Mie','Cong','Qian','Shu','Can','Ya','Zi','Ni','Fu','Zi','Li','Xue','Bo','Ru','Nai','Nie','Nie','Ying','Luan','Mian','Ning','Rong','Ta','Gui','Zhai','Qiong','Yu','Shou','An','Tu','Song','Wan','Rou','Yao','Hong','Yi','Jing','Zhun','Mi','Zhu','Dang','Hong','Zong','Guan','Zhou','Ding','Wan','Yi','Bao','Shi','Shi','Chong','Shen','Ke','Xuan','Shi','You','Huan','Yi','Tiao','Shi','Xian','Gong','Cheng','Qun','Gong','Xiao','Zai','Zha','Bao','Hai','Yan','Xiao','Jia','Shen','Chen','Rong','Huang','Mi','Kou','Kuan','Bin','Su','Cai','Zan','Ji','Yuan','Ji','Yin','Mi','Kou','Qing','He','Zhen','Jian','Fu','Ning','Bing','Huan','Mei','Qin','Han','Yu','Shi','Ning','Jin','Ning','Zhi','Yu','Bao','Kuan','Ning','Qin','Mo','Cha','Ju','Gua','Qin','Hu','Wu','Liao','Shi','Ning','Zhai','Shen','Wei','Xie','Kuan','Hui','Liao','Jun','Huan','Yi','Yi','Bao','Qin','Chong','Bao','Feng','Cun','Dui','Si','Xun','Dao','Lu','Dui','Shou')