b=('jjael','jjaelg','jjaelm','jjaelb','jjaels','jjaelt','jjaelp','jjaelh','jjaem','jjaeb','jjaebs','jjaes','jjaess','jjaeng','jjaej','jjaech','jjaek','jjaet','jjaep','jjaeh','jjya','jjyag','jjyakk','jjyags','jjyan','jjyanj','jjyanh','jjyad','jjyal','jjyalg','jjyalm','jjyalb','jjyals','jjyalt','jjyalp','jjyalh','jjyam','jjyab','jjyabs','jjyas','jjyass','jjyang','jjyaj','jjyach','jjyak','jjyat','jjyap','jjyah','jjyae','jjyaeg','jjyaekk','jjyaegs','jjyaen','jjyaenj','jjyaenh','jjyaed','jjyael','jjyaelg','jjyaelm','jjyaelb','jjyaels','jjyaelt','jjyaelp','jjyaelh','jjyaem','jjyaeb','jjyaebs','jjyaes','jjyaess','jjyaeng','jjyaej','jjyaech','jjyaek','jjyaet','jjyaep','jjyaeh','jjeo','jjeog','jjeokk','jjeogs','jjeon','jjeonj','jjeonh','jjeod','jjeol','jjeolg','jjeolm','jjeolb','jjeols','jjeolt','jjeolp','jjeolh','jjeom','jjeob','jjeobs','jjeos','jjeoss','jjeong','jjeoj','jjeoch','jjeok','jjeot','jjeop','jjeoh','jje','jjeg','jjekk','jjegs','jjen','jjenj','jjenh','jjed','jjel','jjelg','jjelm','jjelb','jjels','jjelt','jjelp','jjelh','jjem','jjeb','jjebs','jjes','jjess','jjeng','jjej','jjech','jjek','jjet','jjep','jjeh','jjyeo','jjyeog','jjyeokk','jjyeogs','jjyeon','jjyeonj','jjyeonh','jjyeod','jjyeol','jjyeolg','jjyeolm','jjyeolb','jjyeols','jjyeolt','jjyeolp','jjyeolh','jjyeom','jjyeob','jjyeobs','jjyeos','jjyeoss','jjyeong','jjyeoj','jjyeoch','jjyeok','jjyeot','jjyeop','jjyeoh','jjye','jjyeg','jjyekk','jjyegs','jjyen','jjyenj','jjyenh','jjyed','jjyel','jjyelg','jjyelm','jjyelb','jjyels','jjyelt','jjyelp','jjyelh','jjyem','jjyeb','jjyebs','jjyes','jjyess','jjyeng','jjyej','jjyech','jjyek','jjyet','jjyep','jjyeh','jjo','jjog','jjokk','jjogs','jjon','jjonj','jjonh','jjod','jjol','jjolg','jjolm','jjolb','jjols','jjolt','jjolp','jjolh','jjom','jjob','jjobs','jjos','jjoss','jjong','jjoj','jjoch','jjok','jjot','jjop','jjoh','jjwa','jjwag','jjwakk','jjwags','jjwan','jjwanj','jjwanh','jjwad','jjwal','jjwalg','jjwalm','jjwalb','jjwals','jjwalt','jjwalp','jjwalh','jjwam','jjwab','jjwabs','jjwas','jjwass','jjwang','jjwaj','jjwach','jjwak','jjwat','jjwap','jjwah','jjwae','jjwaeg','jjwaekk','jjwaegs','jjwaen','jjwaenj','jjwaenh','jjwaed','jjwael','jjwaelg','jjwaelm','jjwaelb')