b=('Tong','Yu','Xiang','Nao','Shun','Fen','Pu','Ling','Ao','Huan','Yi','Huan','Meng','Ying','Lei','Yan','Bao','Die','Ling','Shi','Jiao','Lie','Jing','Ju','Ti','Pi','Gang','Xiao','Wai','Chuai','Di','Huan','Yao','Li','Mi','Hu','Sheng','Jia','Yin','Wei','','Piao','Lu','Ling','Yi','Cai','Shan','Hu','Shu','Tuo','Mo','Hua','Tie','Bing','Peng','Hun','Fu','Guo','Bu','Li','Chan','Pi','Cuo','Meng','Suo','Qiang','Zhi','Kuang','Bi','Ao','Meng','Xian','Ku','Tou','Tuan','Wei','Xian','Tan','Tuan','Lao','Chan','Ni','Ni','Li','Dong','Ju','Qian','Bo','Shai','Zha','Tao','Qian','Nong','Yi','Jing','Gan','Di','Jian','Mei','Da','Jian','Yu','Xie','Zai','Mang','Li','Gun','Xun','Ta','Zhe','Yang','Tuan','Shang','Xi','Qiao','Wei','Ying','Chua','Qu','Wa','Caau','Zhi','Ting','Gu','Shang','Ca','Fu','Tie','Ta','Ta','Zhuo','Han','Ping','He','Zhui','Zhou','Bo','Liu','Nu','Xi','Pao','Di','He','Ti','Wai','Ti','Qi','Ji','Chi','Ba','Jin','Ke','Li','Ju','Qu','La','Gu','Qia','Qi','Xian','Jian','Shi','Jian','Ai','Hua','Zha','Ze','Yao','Zhan','Ji','Cha','Yan','Jian','','Yan','Gwaai','Jiao','Tong','Nan','Yue','Ceoi','Chi','','','','','','','','','','','Qian','Kun','Zhun','Meng','Xu','Song','Shi','Bi','XiaoChu','Lu','Tai','Pi','TongRen','DaYou','Qian','Yu','Sui','Gu','Lin','Guan','ShiKe','Bi','Bo','Fu','WuWang','DaChu','Yi','DaGuo','Kan','Li','Xian','Heng','Dun','DaZhuang','Jin','MingYi','JiaRen','Kui','Jian','Xie','Sun','Yi','Guai','Gou','Cui','Sheng','Kun','Jing','Ge','Ding','Zhen','Gen','Jian','GuiMei','Feng','Lu','Xun','Dui','Huan','Jie','ZhongFu','XiaoGuo','JiJi','WeiJi')