b=('Dao','Diao','Dao','Ren','Ren','Chuang','Fen','Qie','Yi','Ji','Kan','Qian','Cun','Chu','Wen','Ji','Dan','Xing','Hua','Wan','Jue','Li','Yue','Lie','Liu','Ze','Gang','Chuang','Fu','Chu','Qu','Diao','Shan','Min','Ling','Zhong','Pan','Bie','Jie','Jie','Pao','Li','Shan','Bie','Chan','Jing','Gua','Geng','Dao','Chuang','Kui','Ku','Duo','Er','Zhi','Shua','Quan','Sha','Ci','Ke','Jie','Gui','Ci','Gui','Kai','Duo','Ji','Ti','Jing','Lou','Luo','Ze','Yuan','Cuo','Xue','Ke','La','Qian','Sha','Chuang','Gua','Jian','Cuo','Li','Ti','Fei','Pou','Chan','Qi','Chuang','Zi','Gang','Wan','Bo','Ji','Duo','Qing','Shan','Du','Jian','Ji','Bo','Yan','Ju','Huo','Sheng','Jian','Duo','Duan','Wu','Gua','Fu','Sheng','Jian','Ge','Da','Kai','Chuang','Chuan','Chan','Tuan','Lu','Li','Peng','Shan','Piao','Kou','Jiao','Gua','Qiao','Jue','Hua','Zha','Zhuo','Lian','Ju','Pi','Liu','Gui','Jiao','Gui','Jian','Jian','Tang','Huo','Ji','Jian','Yi','Jian','Zhi','Chan','Jian','Mo','Li','Zhu','Li','Ya','Quan','Ban','Gong','Jia','Wu','Mai','Lie','Jin','Keng','Xie','Zhi','Dong','Zhu','Nu','Jie','Qu','Shao','Yi','Zhu','Mo','Li','Jin','Lao','Lao','Juan','Kou','Yang','Wa','Xiao','Mou','Kuang','Jie','Lie','He','Shi','Ke','Jin','Gao','Bo','Min','Chi','Lang','Yong','Yong','Mian','Ke','Xun','Juan','Qing','Lu','Bu','Meng','Chi','Lei','Kai','Mian','Dong','Xu','Xu','Kan','Wu','Yi','Xun','Weng','Sheng','Lao','Mu','Lu','Piao','Shi','Ji','Qin','Jiang','Chao','Quan','Xiang','Yi','Jue','Fan','Juan','Tong','Ju','Dan','Xie','Mai','Xun','Xun','Lu','Li','Che','Rang','Quan','Bao','Shao','Yun','Jiu','Bao','Gou','Wu')