b=('Sha','Li','Han','Xian','Jing','Pai','Fei','Xiao','Bai','Qi','Ni','Biao','Yin','Lai','Lie','Jian','Qiang','Kun','Yan','Guo','Zong','Mi','Chang','Yi','Zhi','Zheng','Ya','Meng','Cai','Cu','She','Lie','Dian','Luo','Hu','Zong','Gui','Wei','Feng','Wo','Yuan','Xing','Zhu','Mao','Wei','Chuan','Xian','Tuan','Ya','Nao','Xie','Jia','Hou','Bian','You','You','Mei','Cha','Yao','Sun','Bo','Ming','Hua','Yuan','Sou','Ma','Yuan','Dai','Yu','Shi','Hao','Qiang','Yi','Zhen','Cang','Hao','Man','Jing','Jiang','Mo','Zhang','Chan','Ao','Ao','Hao','Cui','Ben','Jue','Bi','Bi','Huang','Pu','Lin','Xu','Tong','Yao','Liao','Shuo','Xiao','Shou','Dun','Jiao','Ge','Juan','Du','Hui','Kuai','Xian','Xie','Ta','Xian','Xun','Ning','Bian','Huo','Nou','Meng','Lie','Nao','Guang','Shou','Lu','Ta','Xian','Mi','Rang','Huan','Nao','Luo','Xian','Qi','Jue','Xuan','Miao','Zi','Lu','Lu','Yu','Su','Wang','Qiu','Ga','Ding','Le','Ba','Ji','Hong','Di','Chuan','Gan','Jiu','Yu','Qi','Yu','Chang','Ma','Hong','Wu','Fu','Wen','Jie','Ya','Bin','Bian','Bang','Yue','Jue','Men','Jue','Wan','Jian','Mei','Dan','Pin','Wei','Huan','Xian','Qiang','Ling','Dai','Yi','An','Ping','Dian','Fu','Xuan','Xi','Bo','Ci','Gou','Jia','Shao','Po','Ci','Ke','Ran','Sheng','Shen','Yi','Zu','Jia','Min','Shan','Liu','Bi','Zhen','Zhen','Jue','Fa','Long','Jin','Jiao','Jian','Li','Guang','Xian','Zhou','Gong','Yan','Xiu','Yang','Xu','Luo','Su','Zhu','Qin','Yin','Xun','Bao','Er','Xiang','Yao','Xia','Hang','Gui','Chong','Xu','Ban','Pei','Lao','Dang','Ying','Hui','Wen','E','Cheng','Di','Wu','Wu','Cheng','Jun','Mei','Bei','Ting','Xian','Chu')