b=('nyok','nyot','nyop','nyoh','nu','nug','nukk','nugs','nun','nunj','nunh','nud','nul','nulg','nulm','nulb','nuls','nult','nulp','nulh','num','nub','nubs','nus','nuss','nung','nuj','nuch','nuk','nut','nup','nuh','nwo','nwog','nwokk','nwogs','nwon','nwonj','nwonh','nwod','nwol','nwolg','nwolm','nwolb','nwols','nwolt','nwolp','nwolh','nwom','nwob','nwobs','nwos','nwoss','nwong','nwoj','nwoch','nwok','nwot','nwop','nwoh','nwe','nweg','nwekk','nwegs','nwen','nwenj','nwenh','nwed','nwel','nwelg','nwelm','nwelb','nwels','nwelt','nwelp','nwelh','nwem','nweb','nwebs','nwes','nwess','nweng','nwej','nwech','nwek','nwet','nwep','nweh','nwi','nwig','nwikk','nwigs','nwin','nwinj','nwinh','nwid','nwil','nwilg','nwilm','nwilb','nwils','nwilt','nwilp','nwilh','nwim','nwib','nwibs','nwis','nwiss','nwing','nwij','nwich','nwik','nwit','nwip','nwih','nyu','nyug','nyukk','nyugs','nyun','nyunj','nyunh','nyud','nyul','nyulg','nyulm','nyulb','nyuls','nyult','nyulp','nyulh','nyum','nyub','nyubs','nyus','nyuss','nyung','nyuj','nyuch','nyuk','nyut','nyup','nyuh','neu','neug','neukk','neugs','neun','neunj','neunh','neud','neul','neulg','neulm','neulb','neuls','neult','neulp','neulh','neum','neub','neubs','neus','neuss','neung','neuj','neuch','neuk','neut','neup','neuh','nui','nuig','nuikk','nuigs','nuin','nuinj','nuinh','nuid','nuil','nuilg','nuilm','nuilb','nuils','nuilt','nuilp','nuilh','nuim','nuib','nuibs','nuis','nuiss','nuing','nuij','nuich','nuik','nuit','nuip','nuih','ni','nig','nikk','nigs','nin','ninj','ninh','nid','nil','nilg','nilm','nilb','nils','nilt','nilp','nilh','nim','nib','nibs','nis','niss','ning','nij','nich','nik','nit','nip','nih','da','dag','dakk','dags','dan','danj','danh','dad','dal','dalg','dalm','dalb','dals','dalt','dalp','dalh','dam','dab','dabs','das','dass','dang','daj','dach','dak','dat','dap','dah')