b=('Fu','Zhuo','Mao','Fan','Jia','Mao','Mao','Ba','Ci','Mo','Zi','Zhi','Chi','Ji','Jing','Long','Cong','Niao','Yuan','Xue','Ying','Qiong','Ge','Ming','Li','Rong','Yin','Gen','Qian','Chai','Chen','Yu','Hao','Zi','Lie','Wu','Ji','Gui','Ci','Jian','Ci','Gou','Guang','Mang','Cha','Jiao','Jiao','Fu','Yu','Zhu','Zi','Jiang','Hui','Yin','Cha','Fa','Rong','Ru','Chong','Mang','Tong','Zhong','Qian','Zhu','Xun','Huan','Fu','Quan','Gai','Da','Jing','Xing','Chuan','Cao','Jing','Er','An','Qiao','Chi','Ren','Jian','Ti','Huang','Ping','Li','Jin','Lao','Shu','Zhuang','Da','Jia','Rao','Bi','Ce','Qiao','Hui','Ji','Dang','Zi','Rong','Hun','Xing','Luo','Ying','Xun','Jin','Sun','Yin','Mai','Hong','Zhou','Yao','Du','Wei','Li','Dou','Fu','Ren','Yin','He','Bi','Bu','Yun','Di','Tu','Sui','Sui','Cheng','Chen','Wu','Bie','Xi','Geng','Li','Pu','Zhu','Mo','Li','Zhuang','Zuo','Tuo','Qiu','Sha','Suo','Chen','Peng','Ju','Mei','Meng','Xing','Jing','Che','Shen','Jun','Yan','Ting','You','Cuo','Guan','Han','You','Cuo','Jia','Wang','Su','Niu','Shao','Xian','Lang','Fu','E','Mo','Wen','Jie','Nan','Mu','Kan','Lai','Lian','Shi','Wo','Tu','Xian','Huo','You','Ying','Ying','Gong','Chun','Mang','Mang','Ci','Wan','Jing','Di','Qu','Dong','Jian','Zou','Gu','La','Lu','Ju','Wei','Jun','Nie','Kun','He','Pu','Zai','Gao','Guo','Fu','Lun','Chang','Chou','Song','Chui','Zhan','Men','Cai','Ba','Li','Tu','Bo','Han','Bao','Qin','Juan','Xi','Qin','Di','Jie','Pu','Dang','Jin','Qiao','Tai','Geng','Hua','Gu','Ling','Fei','Qin','An','Wang','Beng','Zhou','Yan','Ju','Jian','Lin','Tan','Shu','Tian','Dao')