b=('Ruo','Bei','E','Shu','Juan','Yu','Yun','Hou','Kui','Xiang','Xiang','Sou','Tang','Ming','Xi','Ru','Chu','Zi','Zou','Ye','Wu','Xiang','Yun','Hao','Yong','Bi','Mao','Chao','Fu','Liao','Yin','Zhuan','Hu','Qiao','Yan','Zhang','Man','Qiao','Xu','Deng','Bi','Xun','Bi','Zeng','Wei','Zheng','Mao','Shan','Lin','Po','Dan','Meng','Ye','Cao','Kuai','Feng','Meng','Zou','Kuang','Lian','Zan','Chan','You','Ji','Yan','Chan','Cuo','Ling','Huan','Xi','Feng','Zan','Li','You','Ding','Qiu','Zhuo','Pei','Zhou','Yi','Gan','Yu','Jiu','Yan','Zui','Mao','Zhen','Xu','Dou','Zhen','Fen','Yuan','Fu','Yun','Tai','Tian','Qia','Tuo','Cu','Han','Gu','Su','Po','Chou','Zai','Ming','Lao','Chuo','Chou','You','Tong','Zhi','Xian','Jiang','Cheng','Yin','Tu','Jiao','Mei','Ku','Suan','Lei','Pu','Zui','Hai','Yan','Shai','Niang','Wei','Lu','Lan','Yan','Tao','Pei','Zhan','Chun','Tan','Zui','Zhui','Cu','Kun','Ti','Xian','Du','Hu','Xu','Xing','Tan','Qiu','Chun','Yun','Po','Ke','Sou','Mi','Quan','Chou','Cuo','Yun','Yong','Ang','Zha','Hai','Tang','Jiang','Piao','Chen','Yu','Li','Zao','Lao','Yi','Jiang','Bu','Jiao','Xi','Tan','Fa','Nong','Yi','Li','Ju','Yan','Yi','Niang','Ru','Xun','Chou','Yan','Ling','Mi','Mi','Niang','Xin','Jiao','Shai','Mi','Yan','Bian','Cai','Shi','You','Shi','Shi','Li','Zhong','Ye','Liang','Li','Jin','Jin','Qiu','Yi','Liao','Dao','Zhao','Ding','Po','Qiu','Ba','Fu','Zhen','Zhi','Ba','Luan','Fu','Nai','Diao','Shan','Qiao','Kou','Chuan','Zi','Fan','Hua','Hua','Han','Gang','Qi','Mang','Ri','Di','Si','Xi','Yi','Chai','Shi','Tu','Xi','Nu','Qian','Qiu','Jian','Pi','Ye','Jin')