b=('kkyeols','kkyeolt','kkyeolp','kkyeolh','kkyeom','kkyeob','kkyeobs','kkyeos','kkyeoss','kkyeong','kkyeoj','kkyeoch','kkyeok','kkyeot','kkyeop','kkyeoh','kkye','kkyeg','kkyekk','kkyegs','kkyen','kkyenj','kkyenh','kkyed','kkyel','kkyelg','kkyelm','kkyelb','kkyels','kkyelt','kkyelp','kkyelh','kkyem','kkyeb','kkyebs','kkyes','kkyess','kkyeng','kkyej','kkyech','kkyek','kkyet','kkyep','kkyeh','kko','kkog','kkokk','kkogs','kkon','kkonj','kkonh','kkod','kkol','kkolg','kkolm','kkolb','kkols','kkolt','kkolp','kkolh','kkom','kkob','kkobs','kkos','kkoss','kkong','kkoj','kkoch','kkok','kkot','kkop','kkoh','kkwa','kkwag','kkwakk','kkwags','kkwan','kkwanj','kkwanh','kkwad','kkwal','kkwalg','kkwalm','kkwalb','kkwals','kkwalt','kkwalp','kkwalh','kkwam','kkwab','kkwabs','kkwas','kkwass','kkwang','kkwaj','kkwach','kkwak','kkwat','kkwap','kkwah','kkwae','kkwaeg','kkwaekk','kkwaegs','kkwaen','kkwaenj','kkwaenh','kkwaed','kkwael','kkwaelg','kkwaelm','kkwaelb','kkwaels','kkwaelt','kkwaelp','kkwaelh','kkwaem','kkwaeb','kkwaebs','kkwaes','kkwaess','kkwaeng','kkwaej','kkwaech','kkwaek','kkwaet','kkwaep','kkwaeh','kkoe','kkoeg','kkoekk','kkoegs','kkoen','kkoenj','kkoenh','kkoed','kkoel','kkoelg','kkoelm','kkoelb','kkoels','kkoelt','kkoelp','kkoelh','kkoem','kkoeb','kkoebs','kkoes','kkoess','kkoeng','kkoej','kkoech','kkoek','kkoet','kkoep','kkoeh','kkyo','kkyog','kkyokk','kkyogs','kkyon','kkyonj','kkyonh','kkyod','kkyol','kkyolg','kkyolm','kkyolb','kkyols','kkyolt','kkyolp','kkyolh','kkyom','kkyob','kkyobs','kkyos','kkyoss','kkyong','kkyoj','kkyoch','kkyok','kkyot','kkyop','kkyoh','kku','kkug','kkukk','kkugs','kkun','kkunj','kkunh','kkud','kkul','kkulg','kkulm','kkulb','kkuls','kkult','kkulp','kkulh','kkum','kkub','kkubs','kkus','kkuss','kkung','kkuj','kkuch','kkuk','kkut','kkup','kkuh','kkwo','kkwog','kkwokk','kkwogs','kkwon','kkwonj','kkwonh','kkwod','kkwol','kkwolg','kkwolm','kkwolb','kkwols','kkwolt','kkwolp','kkwolh','kkwom','kkwob','kkwobs','kkwos','kkwoss','kkwong','kkwoj','kkwoch','kkwok','kkwot','kkwop','kkwoh','kkwe','kkweg','kkwekk','kkwegs','kkwen','kkwenj','kkwenh','kkwed','kkwel','kkwelg','kkwelm','kkwelb','kkwels','kkwelt','kkwelp','kkwelh')