b=('Guo','Yin','Hun','Pu','Yu','Han','Yuan','Lun','Quan','Yu','Qing','Guo','Chuan','Wei','Yuan','Quan','Ku','Pu','Yuan','Yuan','Ya','Tu','Tu','Tu','Tuan','Lue','Hui','Yi','Huan','Luan','Luan','Tu','Ya','Tu','Ting','Sheng','Pu','Lu','Kuai','Ya','Zai','Wei','Ge','Yu','Wu','Gui','Pi','Yi','De','Qian','Qian','Zhen','Zhuo','Dang','Qia','Xia','Shan','Kuang','Chang','Qi','Nie','Mo','Ji','Jia','Zhi','Zhi','Ban','Xun','Yi','Qin','Mei','Jun','Rong','Tun','Fang','Ben','Ben','Tan','Kan','Huai','Zuo','Keng','Bi','Jing','Di','Jing','Ji','Kuai','Di','Jing','Jian','Tan','Li','Ba','Wu','Fen','Zhui','Po','Ban','Tang','Kun','Qu','Tan','Zhi','Tuo','Gan','Ping','Dian','Gua','Ni','Tai','Pi','Jiong','Yang','Fo','Ao','Lu','Qiu','Mu','Ke','Gou','Xue','Ba','Chi','Che','Ling','Zhu','Fu','Hu','Zhi','Chui','La','Long','Long','Lu','Ao','Dai','Pao','Min','Xing','Dong','Ji','He','Lu','Ci','Chi','Lei','Gai','Yin','Hou','Dui','Zhao','Fu','Guang','Yao','Duo','Duo','Gui','Cha','Yang','Yin','Fa','Gou','Yuan','Die','Xie','Ken','Shang','Shou','E','Bing','Dian','Hong','Ya','Kua','Da','Ka','Dang','Kai','Hang','Nao','An','Xing','Xian','Yuan','Bang','Fu','Ba','Yi','Yin','Han','Xu','Chui','Qin','Geng','Ai','Beng','Fang','Que','Yong','Jun','Jia','Di','Mai','Lang','Juan','Cheng','Shan','Jin','Zhe','Lie','Lie','Bu','Cheng','Hua','Bu','Shi','Xun','Guo','Jiong','Ye','Nian','Di','Yu','Bu','Ya','Quan','Sui','Pi','Qing','Wan','Ju','Lun','Zheng','Kong','Chong','Dong','Dai','Tan','An','Cai','Chu','Beng','Kan','Zhi','Duo','Yi','Zhi','Yi','Pei','Ji','Zhun','Qi','Sao','Ju','Ni')