b=('syae','syaeg','syaekk','syaegs','syaen','syaenj','syaenh','syaed','syael','syaelg','syaelm','syaelb','syaels','syaelt','syaelp','syaelh','syaem','syaeb','syaebs','syaes','syaess','syaeng','syaej','syaech','syaek','syaet','syaep','syaeh','seo','seog','seokk','seogs','seon','seonj','seonh','seod','seol','seolg','seolm','seolb','seols','seolt','seolp','seolh','seom','seob','seobs','seos','seoss','seong','seoj','seoch','seok','seot','seop','seoh','se','seg','sekk','segs','sen','senj','senh','sed','sel','selg','selm','selb','sels','selt','selp','selh','sem','seb','sebs','ses','sess','seng','sej','sech','sek','set','sep','seh','syeo','syeog','syeokk','syeogs','syeon','syeonj','syeonh','syeod','syeol','syeolg','syeolm','syeolb','syeols','syeolt','syeolp','syeolh','syeom','syeob','syeobs','syeos','syeoss','syeong','syeoj','syeoch','syeok','syeot','syeop','syeoh','sye','syeg','syekk','syegs','syen','syenj','syenh','syed','syel','syelg','syelm','syelb','syels','syelt','syelp','syelh','syem','syeb','syebs','syes','syess','syeng','syej','syech','syek','syet','syep','syeh','so','sog','sokk','sogs','son','sonj','sonh','sod','sol','solg','solm','solb','sols','solt','solp','solh','som','sob','sobs','sos','soss','song','soj','soch','sok','sot','sop','soh','swa','swag','swakk','swags','swan','swanj','swanh','swad','swal','swalg','swalm','swalb','swals','swalt','swalp','swalh','swam','swab','swabs','swas','swass','swang','swaj','swach','swak','swat','swap','swah','swae','swaeg','swaekk','swaegs','swaen','swaenj','swaenh','swaed','swael','swaelg','swaelm','swaelb','swaels','swaelt','swaelp','swaelh','swaem','swaeb','swaebs','swaes','swaess','swaeng','swaej','swaech','swaek','swaet','swaep','swaeh','soe','soeg','soekk','soegs','soen','soenj','soenh','soed','soel','soelg','soelm','soelb','soels','soelt','soelp','soelh','soem','soeb','soebs','soes','soess','soeng','soej','soech','soek','soet','soep','soeh','syo','syog','syokk','syogs')