b=('Huan','Quan','Zei','Wei','Wei','Yu','Chun','Rou','Die','Huang','Lian','Yan','Qiu','Qiu','Jian','Bi','E','Yang','Fu','Sai','Gan','Xia','Tuo','Hu','Shi','Ruo','Xuan','Wen','Qian','Hao','Wu','Fang','Sao','Liu','Ma','Shi','Shi','Guan','Zi','Teng','Ta','Yao','E','Yong','Qian','Qi','Wen','Ruo','Shen','Lian','Ao','Le','Hui','Min','Ji','Tiao','Qu','Jian','Shen','Man','Xi','Qiu','Biao','Ji','Ji','Zhu','Jiang','Xiu','Zhuan','Yong','Zhang','Kang','Xue','Bie','Yu','Qu','Xiang','Bo','Jiao','Xun','Su','Huang','Zun','Shan','Shan','Fan','Gui','Lin','Xun','Miao','Xi','Zeng','Xiang','Fen','Guan','Hou','Kuai','Zei','Sao','Zhan','Gan','Gui','Ying','Li','Chang','Lei','Shu','Ai','Ru','Ji','Xu','Hu','Shu','Li','Lie','Li','Mie','Zhen','Xiang','E','Lu','Guan','Li','Xian','Yu','Dao','Ji','You','Tun','Lu','Fang','Ba','He','Ba','Ping','Nian','Lu','You','Zha','Fu','Ba','Bao','Hou','Pi','Tai','Gui','Jie','Kao','Wei','Er','Tong','Zei','Hou','Kuai','Ji','Jiao','Xian','Zha','Xiang','Xun','Geng','Li','Lian','Jian','Li','Shi','Tiao','Gun','Sha','Huan','Jun','Ji','Yong','Qing','Ling','Qi','Zou','Fei','Kun','Chang','Gu','Ni','Nian','Diao','Jing','Shen','Shi','Zi','Fen','Die','Bi','Chang','Ti','Wen','Wei','Sai','E','Qiu','Fu','Huang','Quan','Jiang','Bian','Sao','Ao','Qi','Ta','Guan','Yao','Pang','Jian','Le','Biao','Xue','Bie','Man','Min','Yong','Wei','Xi','Gui','Shan','Lin','Zun','Hu','Gan','Li','Zhan','Guan','Niao','Yi','Fu','Li','Jiu','Bu','Yan','Fu','Diao','Ji','Feng','Ru','Gan','Shi','Feng','Ming','Bao','Yuan','Zhi','Hu','Qin','Fu','Ban','Wen','Jian','Shi','Yu')