b=('Shu','Xuan','Feng','Shen','Shen','Fu','Xian','Zhe','Wu','Fu','Li','Lang','Bi','Chu','Yuan','You','Jie','Dan','Yan','Ting','Dian','Tui','Hui','Wo','Zhi','Song','Fei','Ju','Mi','Qi','Qi','Yu','Jun','La','Meng','Qiang','Si','Xi','Lun','Li','Die','Tiao','Tao','Kun','Han','Han','Yu','Bang','Fei','Pi','Wei','Dun','Yi','Yuan','Suo','Quan','Qian','Rui','Ni','Qing','Wei','Liang','Guo','Wan','Dong','E','Ban','Di','Wang','Can','Yang','Ying','Guo','Chan','Ding','La','Ke','Jie','Xie','Ting','Mao','Xu','Mian','Yu','Jie','Shi','Xuan','Huang','Yan','Bian','Rou','Wei','Fu','Yuan','Mei','Wei','Fu','Ru','Xie','You','Qiu','Mao','Xia','Ying','Shi','Chong','Tang','Zhu','Zong','Ti','Fu','Yuan','Kui','Meng','La','Du','Hu','Qiu','Die','Li','Wo','Yun','Qu','Nan','Lou','Chun','Rong','Ying','Jiang','Ban','Lang','Pang','Si','Xi','Ci','Xi','Yuan','Weng','Lian','Sou','Ban','Rong','Rong','Ji','Wu','Xiu','Han','Qin','Yi','Bi','Hua','Tang','Yi','Du','Nai','He','Hu','Gui','Ma','Ming','Yi','Wen','Ying','Te','Zhong','Cang','Sao','Qi','Man','Tiao','Shang','Shi','Cao','Chi','Di','Ao','Lu','Wei','Zhi','Tang','Chen','Piao','Qu','Pi','Yu','Jian','Luo','Lou','Qin','Zhong','Yin','Jiang','Shuai','Wen','Xiao','Wan','Zhe','Zhe','Ma','Ma','Guo','Liu','Mao','Xi','Cong','Li','Man','Xiao','Chang','Zhang','Mang','Xiang','Mo','Zui','Si','Qiu','Te','Zhi','Peng','Peng','Jiao','Qu','Bie','Liao','Pan','Gui','Xi','Ji','Zhuan','Huang','Fei','Lao','Jue','Jue','Hui','Yin','Chan','Jiao','Shan','Nao','Xiao','Wu','Chong','Xun','Si','Chu','Cheng','Dang','Li','Xie','Shan','Yi','Jing','Da','Chan','Qi')