b=('Lun','Guo','Ling','Pi','Lu','Li','Qiang','Pou','Juan','Min','Zui','Peng','An','Pi','Xian','Ya','Zhui','Lei','Ke','Kong','Ta','Kun','Du','Nei','Chui','Zi','Zheng','Ben','Nie','Zong','Chun','Tan','Ding','Qi','Qian','Zhui','Ji','Yu','Jin','Guan','Mao','Chang','Tian','Xi','Lian','Tao','Gu','Cuo','Shu','Zhen','Lu','Meng','Lu','Hua','Biao','Ga','Lai','Ken','Fang','Wu','Nai','Wan','Zan','Hu','De','Xian','Pian','Huo','Liang','Fa','Men','Kai','Ying','Di','Lian','Guo','Xian','Du','Tu','Wei','Zong','Fu','Rou','Ji','E','Jun','Chen','Ti','Zha','Hu','Yang','Duan','Xia','Yu','Keng','Sheng','Huang','Wei','Fu','Zhao','Cha','Qie','Shi','Hong','Kui','Tian','Mou','Qiao','Qiao','Hou','Tou','Cong','Huan','Ye','Min','Jian','Duan','Jian','Song','Kui','Hu','Xuan','Duo','Jie','Zhen','Bian','Zhong','Zi','Xiu','Ye','Mei','Pai','Ai','Jie','Qian','Mei','Suo','Da','Bang','Xia','Lian','Suo','Kai','Liu','Yao','Ye','Nou','Weng','Rong','Tang','Suo','Qiang','Li','Shuo','Chui','Bo','Pan','Da','Bi','Sang','Gang','Zi','Wu','Ying','Huang','Tiao','Liu','Kai','Sun','Sha','Sou','Wan','Hao','Zhen','Zhen','Lang','Yi','Yuan','Tang','Nie','Xi','Jia','Ge','Ma','Juan','Song','Zu','Suo','Xia','Feng','Wen','Na','Lu','Suo','Ou','Zu','Tuan','Xiu','Guan','Xuan','Lian','Shou','Ao','Man','Mo','Luo','Bi','Wei','Liu','Di','San','Zong','Yi','Lu','Ao','Keng','Qiang','Cui','Qi','Chang','Tang','Man','Yong','Chan','Feng','Jing','Biao','Shu','Lou','Xiu','Cong','Long','Zan','Jian','Cao','Li','Xia','Xi','Kang','Shuang','Beng','Zhang','Qian','Cheng','Lu','Hua','Ji','Pu','Hui','Qiang','Po','Lin','Se','Xiu','San','Cheng')