b=('Chu','Jing','Nie','Xiao','Bu','Xue','Cun','Mu','Shu','Liang','Yong','Jiao','Chou','Qiao','Mou','Ta','Jian','Qi','Wo','Wei','Chuo','Jie','Ji','Nie','Ju','Nie','Lun','Lu','Leng','Huai','Ju','Chi','Wan','Quan','Ti','Bo','Zu','Qie','Yi','Cu','Zong','Cai','Zong','Peng','Zhi','Zheng','Dian','Zhi','Yu','Duo','Dun','Chuan','Yong','Zhong','Di','Zha','Chen','Chuai','Jian','Gua','Tang','Ju','Fu','Zu','Die','Pian','Rou','Nuo','Ti','Cha','Tui','Jian','Dao','Cuo','Qi','Ta','Qiang','Nian','Dian','Ti','Ji','Nie','Man','Liu','Zan','Bi','Chong','Lu','Liao','Cu','Tang','Dai','Su','Xi','Kui','Ji','Zhi','Qiang','Di','Pan','Zong','Lian','Beng','Zao','Nian','Bie','Tui','Ju','Deng','Ceng','Xian','Fan','Chu','Zhong','Dun','Bo','Cu','Cu','Jue','Jue','Lin','Ta','Qiao','Jue','Pu','Liao','Dun','Cuan','Guan','Zao','Da','Bi','Bi','Zhu','Ju','Chu','Qiao','Dun','Chou','Ji','Wu','Yue','Nian','Lin','Lie','Zhi','Li','Zhi','Chan','Chu','Duan','Wei','Long','Lin','Xian','Wei','Zuan','Lan','Xie','Rang','Sa','Nie','Ta','Qu','Ji','Cuan','Cuo','Xi','Kui','Jue','Lin','Shen','Gong','Dan','Fen','Qu','Ti','Duo','Duo','Gong','Lang','Ren','Luo','Ai','Ji','Ju','Tang','Kong','Lao','Yan','Mei','Kang','Qu','Lou','Lao','Duo','Zhi','Yan','Ti','Dao','Ying','Yu','Che','Ya','Gui','Jun','Wei','Yue','Xin','Dai','Xuan','Fan','Ren','Shan','Kuang','Shu','Tun','Chen','Dai','E','Na','Qi','Mao','Ruan','Kuang','Qian','Zhuan','Hong','Hu','Qu','Kuang','Di','Ling','Dai','Ao','Zhen','Fan','Kuang','Yang','Peng','Bei','Gu','Gu','Pao','Zhu','Rong','E','Ba','Zhou','Zhi','Yao','Ke','Yi','Zhi','Shi','Ping')