b=('Ji','Cha','Zhou','Xun','Yue','Hong','Yu','He','Wan','Ren','Wen','Wen','Qiu','Na','Zi','Tou','Niu','Fou','Ji','Shu','Chun','Pi','Zhen','Sha','Hong','Zhi','Ji','Fen','Yun','Ren','Dan','Jin','Su','Fang','Suo','Cui','Jiu','Za','Ba','Jin','Fu','Zhi','Qi','Zi','Chou','Hong','Za','Lei','Xi','Fu','Xie','Shen','Bo','Zhu','Qu','Ling','Zhu','Shao','Gan','Yang','Fu','Tuo','Zhen','Dai','Chu','Shi','Zhong','Xian','Zu','Jiong','Ban','Qu','Mo','Shu','Zui','Kuang','Jing','Ren','Hang','Xie','Jie','Zhu','Chou','Gua','Bai','Jue','Kuang','Hu','Ci','Huan','Geng','Tao','Jie','Ku','Jiao','Quan','Gai','Luo','Xuan','Beng','Xian','Fu','Gei','Dong','Rong','Tiao','Yin','Lei','Xie','Juan','Xu','Gai','Die','Tong','Si','Jiang','Xiang','Hui','Jue','Zhi','Jian','Juan','Chi','Mian','Zhen','Lu','Cheng','Qiu','Shu','Bang','Tong','Xiao','Huan','Qin','Geng','Xiu','Ti','Tou','Xie','Hong','Xi','Fu','Ting','Sui','Dui','Kun','Fu','Jing','Hu','Zhi','Yan','Jiong','Feng','Ji','Xu','Ren','Zong','Chen','Duo','Li','Lu','Liang','Chou','Quan','Shao','Qi','Qi','Zhun','Qi','Wan','Qian','Xian','Shou','Wei','Qi','Tao','Wan','Gang','Wang','Beng','Zhui','Cai','Guo','Cui','Lun','Liu','Qi','Zhan','Bi','Chuo','Ling','Mian','Qi','Qie','Tian','Zong','Gun','Zou','Xi','Zi','Xing','Liang','Jin','Fei','Rui','Min','Yu','Zong','Fan','Lu','Xu','Ying','Shang','Qi','Xu','Xiang','Jian','Ke','Xian','Ruan','Mian','Ji','Duan','Chong','Di','Min','Miao','Yuan','Xie','Bao','Si','Qiu','Bian','Huan','Geng','Cong','Mian','Wei','Fu','Wei','Tou','Gou','Miao','Xie','Lian','Zong','Bian','Yun','Yin','Ti','Gua','Zhi','Yun','Cheng','Chan','Dai')