b=('Yi','Ding','Kao','Qi','Shang','Xia','Han','Wan','Zhang','San','Shang','Xia','Ji','Bu','Yu','Mian','Gai','Chou','Chou','Zhuan','Qie','Pi','Shi','Shi','Qiu','Bing','Ye','Cong','Dong','Si','Cheng','Diu','Qiu','Liang','Diu','You','Liang','Yan','Bing','Sang','Gun','Jiu','Ge','Ya','Qiang','Zhong','Ji','Jie','Feng','Guan','Chuan','Chan','Lin','Zhuo','Zhu','Ba','Wan','Dan','Wei','Zhu','Jing','Li','Ju','Pie','Fu','Yi','Yi','Nai','Wu','Jiu','Jiu','Tuo','Me','Yi','Yi','Zhi','Wu','Zha','Hu','Fa','Le','Yin','Ping','Pang','Qiao','Hu','Guai','Cheng','Cheng','Yi','Yin','Ya','Mie','Jiu','Qi','Ye','Xi','Xiang','Gai','Jiu','Xia','Hu','Shu','Dou','Shi','Ji','Nang','Jia','Ju','Shi','Mao','Hu','Mai','Luan','Zi','Ru','Xue','Yan','Fu','Sha','Na','Gan','Suo','Yu','Cui','Zhe','Gan','Zhi','Gui','Gan','Luan','Lin','Yi','Jue','Le','Ma','Yu','Zheng','Shi','Shi','Er','Chu','Yu','Kui','Yu','Yun','Hu','Qi','Wu','Jing','Si','Sui','Gen','Gen','Ya','Xie','Ya','Qi','Ya','Ji','Tou','Wang','Kang','Da','Jiao','Hai','Yi','Chan','Heng','Mu','Ye','Xiang','Jing','Ting','Liang','Xiang','Jing','Ye','Qin','Bo','You','Xie','Dan','Lian','Duo','Men','Ren','Ren','Ji','Ji','Wang','Yi','Shen','Ren','Le','Ding','Ze','Jin','Pu','Chou','Ba','Zhang','Jin','Jie','Bing','Reng','Cong','Fo','San','Lun','Bing','Cang','Zi','Shi','Ta','Zhang','Fu','Xian','Xian','Tuo','Hong','Tong','Ren','Qian','Gan','Ge','Bo','Dai','Ling','Yi','Chao','Chang','Sa','Chang','Yi','Mu','Men','Ren','Fan','Chao','Yang','Qian','Zhong','Pi','Wo','Wu','Jian','Jia','Yao','Feng','Cang','Ren','Wang','Fen','Di','Fang')