b=('hyeo','hyeog','hyeokk','hyeogs','hyeon','hyeonj','hyeonh','hyeod','hyeol','hyeolg','hyeolm','hyeolb','hyeols','hyeolt','hyeolp','hyeolh','hyeom','hyeob','hyeobs','hyeos','hyeoss','hyeong','hyeoj','hyeoch','hyeok','hyeot','hyeop','hyeoh','hye','hyeg','hyekk','hyegs','hyen','hyenj','hyenh','hyed','hyel','hyelg','hyelm','hyelb','hyels','hyelt','hyelp','hyelh','hyem','hyeb','hyebs','hyes','hyess','hyeng','hyej','hyech','hyek','hyet','hyep','hyeh','ho','hog','hokk','hogs','hon','honj','honh','hod','hol','holg','holm','holb','hols','holt','holp','holh','hom','hob','hobs','hos','hoss','hong','hoj','hoch','hok','hot','hop','hoh','hwa','hwag','hwakk','hwags','hwan','hwanj','hwanh','hwad','hwal','hwalg','hwalm','hwalb','hwals','hwalt','hwalp','hwalh','hwam','hwab','hwabs','hwas','hwass','hwang','hwaj','hwach','hwak','hwat','hwap','hwah','hwae','hwaeg','hwaekk','hwaegs','hwaen','hwaenj','hwaenh','hwaed','hwael','hwaelg','hwaelm','hwaelb','hwaels','hwaelt','hwaelp','hwaelh','hwaem','hwaeb','hwaebs','hwaes','hwaess','hwaeng','hwaej','hwaech','hwaek','hwaet','hwaep','hwaeh','hoe','hoeg','hoekk','hoegs','hoen','hoenj','hoenh','hoed','hoel','hoelg','hoelm','hoelb','hoels','hoelt','hoelp','hoelh','hoem','hoeb','hoebs','hoes','hoess','hoeng','hoej','hoech','hoek','hoet','hoep','hoeh','hyo','hyog','hyokk','hyogs','hyon','hyonj','hyonh','hyod','hyol','hyolg','hyolm','hyolb','hyols','hyolt','hyolp','hyolh','hyom','hyob','hyobs','hyos','hyoss','hyong','hyoj','hyoch','hyok','hyot','hyop','hyoh','hu','hug','hukk','hugs','hun','hunj','hunh','hud','hul','hulg','hulm','hulb','huls','hult','hulp','hulh','hum','hub','hubs','hus','huss','hung','huj','huch','huk','hut','hup','huh','hwo','hwog','hwokk','hwogs','hwon','hwonj','hwonh','hwod','hwol','hwolg','hwolm','hwolb','hwols','hwolt','hwolp','hwolh','hwom','hwob','hwobs','hwos','hwoss','hwong','hwoj','hwoch','hwok','hwot','hwop','hwoh','hwe','hweg','hwekk','hwegs')