b=('Ku','Ke','Tang','Kun','Ni','Jian','Dui','Jin','Gang','Yu','E','Peng','Gu','Tu','Leng','Fang','Ya','Qian','Kun','An','Shen','Duo','Nao','Tu','Cheng','Yin','Hun','Bi','Lian','Guo','Die','Zhuan','Hou','Bao','Bao','Yu','Di','Mao','Jie','Ruan','Ye','Geng','Kan','Zong','Yu','Huang','E','Yao','Yan','Bao','Ci','Mei','Chang','Du','Tuo','Yin','Feng','Zhong','Jie','Jin','Heng','Gang','Chun','Jian','Ping','Lei','Xiang','Huang','Leng','Duan','Wan','Xuan','Ji','Ji','Kuai','Ying','Ta','Cheng','Yong','Kai','Su','Su','Shi','Mi','Ta','Weng','Cheng','Tu','Tang','Que','Zhong','Li','Zhong','Bang','Sai','Zang','Dui','Tian','Wu','Zheng','Xun','Ge','Zhen','Ai','Gong','Yan','Kan','Tian','Yuan','Wen','Xie','Liu','Hai','Lang','Chang','Peng','Beng','Chen','Lu','Lu','Ou','Qian','Mei','Mo','Zhuan','Shuang','Shu','Lou','Chi','Man','Biao','Jing','Ce','Shu','Zhi','Zhang','Kan','Yong','Dian','Chen','Zhi','Xi','Guo','Qiang','Jin','Di','Shang','Mu','Cui','Yan','Ta','Zeng','Qian','Qiang','Liang','Wei','Zhui','Qiao','Zeng','Xu','Shan','Shan','Ba','Pu','Kuai','Dong','Fan','Que','Mo','Dun','Dun','Zun','Di','Sheng','Duo','Duo','Tan','Deng','Mu','Fen','Huang','Tan','Da','Ye','Zhu','Jian','Ao','Qiang','Ji','Qiao','Ken','Yi','Pi','Bi','Dian','Jiang','Ye','Yong','Xue','Tan','Lan','Ju','Huai','Dang','Rang','Qian','Xun','Xian','Xi','He','Ai','Ya','Dao','Hao','Ruan','Jin','Lei','Kuang','Lu','Yan','Tan','Wei','Huai','Long','Long','Rui','Li','Lin','Rang','Chan','Xun','Yan','Lei','Ba','Wan','Shi','Ren','San','Zhuang','Zhuang','Sheng','Yi','Mai','Ke','Zhu','Zhuang','Hu','Hu','Kun','Yi','Hu','Xu','Kun','Shou','Mang','Zun')