b=('Fan','You','An','Tui','Meng','She','Jin','Gu','Ji','Qiao','Jiao','Yan','Xi','Kan','Mian','Xuan','Shan','Wo','Qian','Huan','Ren','Zhen','Tian','Jue','Xie','Qi','Ang','Mei','Gu','Bei','Tao','Fan','Ju','Chan','Shun','Bi','Mao','Shuo','Gu','Hong','Hua','Luo','Hang','Jia','Quan','Gai','Huang','Bu','Gu','Feng','Mu','Ai','Ying','Shun','Liang','Jie','Chi','Jie','Chou','Ping','Chen','Yan','Du','Di','','Liang','Xian','Biao','Xing','Meng','Ye','Mi','Qi','Qi','Wo','Xie','Yu','Qia','Cheng','Yao','Ying','Yang','Ji','Zong','Xuan','Min','Lou','Kai','Yao','Yan','Sun','Gui','Huang','Ying','Sheng','Cha','Lian','','Xuan','Chuan','Che','Ni','Qu','Miao','Huo','Yu','Zhan','Hu','Ceng','Biao','Qian','Xi','Jiang','Kou','Mai','Mang','Zhan','Bian','Ji','Jue','Nang','Bi','Shi','Shuo','Mo','Lie','Mie','Mo','Xi','Chan','Qu','Jiao','Huo','Xian','Xu','Niu','Tong','Hou','Yu','','Chong','Bo','Zuan','Diao','Zhuo','Ji','Qia','Kwai','Xing','Hui','Shi','Ku','Caam','Dui','Yao','Yu','Bang','Jie','Zhe','Jia','Shi','Di','Dong','Ci','Fu','Min','Zhen','Zhen','Cik','Yan','Qiao','Hang','Gong','Qiao','Lue','Guai','La','Rui','Fa','Cuo','Yan','Gong','Jie','Guai','Guo','Suo','Wo','Zheng','Nie','Diao','Lai','Ta','Cui','Ya','Gun','','','Di','','Mian','Jie','Min','Ju','Yu','Zhen','Zhao','Zha','Xing','','Ban','He','Gou','Hong','Lao','Wu','Bo','Keng','Lu','Cu','Lian','Yi','Qiao','Shu','Saan','Xuan','Jin','Qin','Hui','Su','Chuang','Dun','Long','','Nao','Tan','Dan','Wei','Gan','Da','Li','Ca','Xian','Pan','La','Zhu','Niao','Huai','Ying','Xian','Lan','Mo','Ba','','Gui','Bi','Fu')