b=('Dang','Ma','Sha','Dan','Jue','Li','Fu','Min','E','Huo','Kang','Zhi','Qi','Kan','Jie','Bin','E','Ya','Pi','Zhe','Yan','Sui','Zhuan','Che','Dun','Wa','Yan','Jin','Feng','Fa','Mo','Zha','Ju','Yu','Ke','Tuo','Tuo','Di','Zhai','Zhen','E','Fu','Mu','Zhu','La','Bian','Nu','Ping','Peng','Ling','Pao','Le','Po','Bo','Po','Shen','Za','Ai','Li','Long','Tong','Yong','Li','Kuang','Chu','Keng','Quan','Zhu','Kuang','Gui','E','Nao','Qia','Lu','Wei','Ai','Ge','Xian','Xing','Yan','Dong','Peng','Xi','Lao','Hong','Shuo','Xia','Qiao','Qing','Wei','Qiao','Yi','Keng','Xiao','Que','Chan','Lang','Hong','Yu','Xiao','Xia','Mang','Luo','Yong','Che','Che','Wo','Liu','Ying','Mang','Que','Yan','Sha','Kun','Yu','Chi','Hua','Lu','Chen','Jian','Nue','Song','Zhuo','Keng','Peng','Yan','Zhui','Kong','Cheng','Qi','Zong','Qing','Lin','Jun','Bo','Ding','Min','Diao','Jian','He','Lu','Ai','Sui','Que','Leng','Bei','Yin','Dui','Wu','Qi','Lun','Wan','Dian','Nao','Bei','Qi','Chen','Ruan','Yan','Die','Ding','Du','Tuo','Jie','Ying','Bian','Ke','Bi','Wei','Shuo','Zhen','Duan','Xia','Dang','Ti','Nao','Peng','Jian','Di','Tan','Cha','Tian','Qi','Dun','Feng','Xuan','Que','Que','Ma','Gong','Nian','Su','E','Ci','Liu','Si','Tang','Bang','Hua','Pi','Wei','Sang','Lei','Cuo','Tian','Xia','Xi','Lian','Pan','Wei','Yun','Dui','Zhe','Ke','La','Zhuan','Yao','Gun','Zhuan','Chan','Qi','Ao','Peng','Liu','Lu','Kan','Chuang','Chen','Yin','Lei','Biao','Qi','Mo','Qi','Cui','Zong','Qing','Chuo','Lun','Ji','Shan','Lao','Qu','Zeng','Deng','Jian','Xi','Lin','Ding','Tan','Huang','Pan','Za','Qiao','Di','Li')