b=('qiet','qiex','qie','qiep','quot','quox','quo','quop','qot','qox','qo','qop','qut','qux','qu','qup','qurx','qur','qyt','qyx','qy','qyp','qyrx','qyr','jjit','jjix','jji','jjip','jjiet','jjiex','jjie','jjiep','jjuox','jjuo','jjuop','jjot','jjox','jjo','jjop','jjut','jjux','jju','jjup','jjurx','jjur','jjyt','jjyx','jjy','jjyp','njit','njix','nji','njip','njiet','njiex','njie','njiep','njuox','njuo','njot','njox','njo','njop','njux','nju','njup','njurx','njur','njyt','njyx','njy','njyp','njyrx','njyr','nyit','nyix','nyi','nyip','nyiet','nyiex','nyie','nyiep','nyuox','nyuo','nyuop','nyot','nyox','nyo','nyop','nyut','nyux','nyu','nyup','xit','xix','xi','xip','xiet','xiex','xie','xiep','xuox','xuo','xot','xox','xo','xop','xyt','xyx','xy','xyp','xyrx','xyr','yit','yix','yi','yip','yiet','yiex','yie','yiep','yuot','yuox','yuo','yuop','yot','yox','yo','yop','yut','yux','yu','yup','yurx','yur','yyt','yyx','yy','yyp','yyrx','yyr','','','','QOT','LI','KIT','NYIP','CYP','SSI','GGOP','GEP','MI','HXIT','LYR','BBUT','MOP','YO','PUT','HXUO','TAT','GA','ZUP','CYT','DDUR','BUR','GGUO','NYOP','TU','OP','JJUT','ZOT','PYT','HMO','YIT','VUR','SHY','VEP','ZA','JO','NZUP','JJY','GOT','JJIE','WO','DU','SHUR','LIE','CY','CUOP','CIP','HXOP','SHAT','ZUR','SHOP','CHE','ZZIET','NBIE','KE')