b=('Bai','Chi','Gua','Zhi','Kuo','Duo','Duo','Zhi','Qie','An','Nong','Zhen','Ge','Jiao','Kua','Dong','Na','Tiao','Lie','Zha','Lu','Die','Wa','Jue','Lie','Ju','Zhi','Luan','Ya','Wo','Ta','Xie','Nao','Dang','Jiao','Zheng','Ji','Hui','Xian','Yu','Ai','Tuo','Nuo','Cuo','Bo','Geng','Ti','Zhen','Cheng','Sa','Sa','Keng','Mei','Nong','Ju','Peng','Jian','Yi','Ting','Shan','Rua','Wan','Xie','Cha','Feng','Jiao','Wu','Jun','Jiu','Tong','Kun','Huo','Tu','Zhuo','Pou','Lu','Ba','Han','Shao','Nie','Juan','Ze','Shu','Ye','Jue','Bu','Wan','Bu','Zun','Ye','Zhai','Lu','Sou','Tuo','Lao','Sun','Bang','Jian','Huan','Dao','Wei','Wan','Qin','Peng','She','Lie','Min','Men','Fu','Bai','Ju','Dao','Wo','Ai','Juan','Yue','Zong','Chen','Chui','Jie','Tu','Ben','Na','Nian','Ruo','Zuo','Wo','Qi','Xian','Cheng','Dian','Sao','Lun','Qing','Gang','Duo','Shou','Diao','Pou','Di','Zhang','Hun','Ji','Tao','Qia','Qi','Pai','Shu','Qian','Ling','Ye','Ya','Jue','Zheng','Liang','Gua','Yi','Huo','Shan','Zheng','Lue','Cai','Tan','Che','Bing','Jie','Ti','Kong','Tui','Yan','Cuo','Zhou','Ju','Tian','Qian','Ken','Bai','Pa','Jie','Lu','Guai','Ming','Jie','Zhi','Dan','Meng','Can','Sao','Guan','Peng','Yuan','Nuo','Jian','Zheng','Jiu','Jian','Yu','Yan','Kui','Nan','Hong','Rou','Pi','Wei','Sai','Zou','Xuan','Miao','Ti','Nie','Cha','Shi','Zong','Zhen','Yi','Xun','Yong','Bian','Yang','Huan','Yan','Zan','An','Xu','Ya','Wo','Ke','Chuai','Ji','Ti','La','La','Chen','Kai','Jiu','Jiu','Tu','Jie','Hui','Gen','Chong','Xiao','Die','Xie','Yuan','Qian','Ye','Cha','Zha','Bei','Yao','Wei','Beng','Lan','Wen','Qin')