b=('Pan','Jie','Ye','Hui','Hui','Zai','Cheng','Yin','Wei','Hou','Jian','Yang','Lie','Si','Ji','Er','Xing','Fu','Sa','Se','Zhi','Yin','Wu','Xi','Kao','Zhu','Jiang','Luo','Luo','An','Dong','Ti','Mou','Lei','Yi','Mi','Quan','Jin','Po','Wei','Xiao','Xie','Hong','Xu','Su','Kuang','Tao','Qie','Ju','Er','Zhou','Ru','Ping','Xun','Xiong','Zhi','Guang','Huan','Ming','Huo','Wa','Qia','Pai','Wu','Qu','Liu','Yi','Jia','Jing','Qian','Jiang','Jiao','Zhen','Shi','Zhuo','Ce','Fa','Hui','Ji','Liu','Chan','Hun','Hu','Nong','Xun','Jin','Lie','Qiu','Wei','Zhe','Jun','Han','Bang','Mang','Zhuo','You','Xi','Bo','Dou','Huan','Hong','Yi','Pu','Ying','Lan','Hao','Lang','Han','Li','Geng','Fu','Wu','Lian','Chun','Feng','Yi','Yu','Tong','Lao','Hai','Jin','Jia','Chong','Jiong','Mei','Sui','Cheng','Pei','Xian','Shen','Tu','Kun','Ping','Nie','Han','Jing','Xiao','She','Nian','Tu','Yong','Xiao','Xian','Ting','E','Su','Tun','Juan','Cen','Ti','Li','Shui','Si','Lei','Shui','Tao','Du','Lao','Lai','Lian','Wei','Wo','Yun','Huan','Di','Heng','Run','Jian','Zhang','Se','Fu','Guan','Xing','Shou','Shuan','Ya','Chuo','Zhang','Ye','Kong','Wo','Han','Tuo','Dong','He','Wo','Ju','She','Liang','Hun','Ta','Zhuo','Dian','Qie','De','Juan','Zi','Xi','Xiao','Qi','Gu','Guo','Yan','Lin','Tang','Zhou','Peng','Hao','Chang','Shu','Qi','Fang','Zhi','Lu','Nao','Ju','Tao','Cong','Lei','Zhe','Ping','Fei','Song','Tian','Pi','Dan','Yu','Ni','Yu','Lu','Gan','Mi','Jing','Ling','Lun','Yin','Cui','Qu','Huai','Yu','Nian','Shen','Biao','Chun','Hu','Yuan','Lai','Hun','Qing','Yan','Qian','Tian','Miao','Zhi','Yin','Bo')