b=('Kui','Si','Liu','Nao','Huang','Pie','Sui','Fan','Qiao','Quan','Yang','Tang','Xiang','Jue','Jiao','Zun','Liao','Qie','Lao','Dui','Xin','Zan','Ji','Jian','Zhong','Deng','Ya','Ying','Dui','Jue','Nou','Zan','Pu','Tie','Fan','Cheng','Ding','Shan','Kai','Jian','Fei','Sui','Lu','Juan','Hui','Yu','Lian','Zhuo','Qiao','Jian','Zhuo','Lei','Bi','Tie','Huan','Ye','Duo','Guo','Dang','Ju','Fen','Da','Bei','Yi','Ai','Zong','Xun','Diao','Zhu','Heng','Zhui','Ji','Nie','He','Huo','Qing','Bin','Ying','Kui','Ning','Xu','Jian','Jian','Qian','Cha','Zhi','Mie','Li','Lei','Ji','Zuan','Kuang','Shang','Peng','La','Du','Shuo','Chuo','Lu','Biao','Bao','Lu','Xian','Kuan','Long','E','Lu','Xin','Jian','Lan','Bo','Jian','Yao','Chan','Xiang','Jian','Xi','Guan','Cang','Nie','Lei','Cuan','Qu','Pan','Luo','Zuan','Luan','Zao','Nie','Jue','Tang','Zhu','Lan','Jin','Ga','Yi','Zhen','Ding','Zhao','Po','Liao','Tu','Qian','Chuan','Shan','Sa','Fan','Diao','Men','Nu','Yang','Chai','Xing','Gai','Bu','Tai','Ju','Dun','Chao','Zhong','Na','Bei','Gang','Ban','Qian','Yao','Qin','Jun','Wu','Gou','Kang','Fang','Huo','Tou','Niu','Ba','Yu','Qian','Zheng','Qian','Gu','Bo','Ke','Po','Bu','Bo','Yue','Zuan','Mu','Tan','Jia','Dian','You','Tie','Bo','Ling','Shuo','Qian','Mao','Bao','Shi','Xuan','Ta','Bi','Ni','Pi','Duo','Xing','Kao','Lao','Er','Mang','Ya','You','Cheng','Jia','Ye','Nao','Zhi','Dang','Tong','Lu','Diao','Yin','Kai','Zha','Zhu','Xi','Ding','Diu','Xian','Hua','Quan','Sha','Ha','Diao','Ge','Ming','Zheng','Se','Jiao','Yi','Chan','Chong','Tang','An','Yin','Ru','Zhu','Lao','Pu','Wu','Lai','Te','Lian','Keng')