b=('geul','geulg','geulm','geulb','geuls','geult','geulp','geulh','geum','geub','geubs','geus','geuss','geung','geuj','geuch','geuk','geut','geup','geuh','gui','guig','guikk','guigs','guin','guinj','guinh','guid','guil','guilg','guilm','guilb','guils','guilt','guilp','guilh','guim','guib','guibs','guis','guiss','guing','guij','guich','guik','guit','guip','guih','gi','gig','gikk','gigs','gin','ginj','ginh','gid','gil','gilg','gilm','gilb','gils','gilt','gilp','gilh','gim','gib','gibs','gis','giss','ging','gij','gich','gik','git','gip','gih','kka','kkag','kkakk','kkags','kkan','kkanj','kkanh','kkad','kkal','kkalg','kkalm','kkalb','kkals','kkalt','kkalp','kkalh','kkam','kkab','kkabs','kkas','kkass','kkang','kkaj','kkach','kkak','kkat','kkap','kkah','kkae','kkaeg','kkaekk','kkaegs','kkaen','kkaenj','kkaenh','kkaed','kkael','kkaelg','kkaelm','kkaelb','kkaels','kkaelt','kkaelp','kkaelh','kkaem','kkaeb','kkaebs','kkaes','kkaess','kkaeng','kkaej','kkaech','kkaek','kkaet','kkaep','kkaeh','kkya','kkyag','kkyakk','kkyags','kkyan','kkyanj','kkyanh','kkyad','kkyal','kkyalg','kkyalm','kkyalb','kkyals','kkyalt','kkyalp','kkyalh','kkyam','kkyab','kkyabs','kkyas','kkyass','kkyang','kkyaj','kkyach','kkyak','kkyat','kkyap','kkyah','kkyae','kkyaeg','kkyaekk','kkyaegs','kkyaen','kkyaenj','kkyaenh','kkyaed','kkyael','kkyaelg','kkyaelm','kkyaelb','kkyaels','kkyaelt','kkyaelp','kkyaelh','kkyaem','kkyaeb','kkyaebs','kkyaes','kkyaess','kkyaeng','kkyaej','kkyaech','kkyaek','kkyaet','kkyaep','kkyaeh','kkeo','kkeog','kkeokk','kkeogs','kkeon','kkeonj','kkeonh','kkeod','kkeol','kkeolg','kkeolm','kkeolb','kkeols','kkeolt','kkeolp','kkeolh','kkeom','kkeob','kkeobs','kkeos','kkeoss','kkeong','kkeoj','kkeoch','kkeok','kkeot','kkeop','kkeoh','kke','kkeg','kkekk','kkegs','kken','kkenj','kkenh','kked','kkel','kkelg','kkelm','kkelb','kkels','kkelt','kkelp','kkelh','kkem','kkeb','kkebs','kkes','kkess','kkeng','kkej','kkech','kkek','kket','kkep','kkeh','kkyeo','kkyeog','kkyeokk','kkyeogs','kkyeon','kkyeonj','kkyeonh','kkyeod','kkyeol','kkyeolg','kkyeolm','kkyeolb')