b=('Ming','Sheng','Shi','Yun','Mian','Pan','Fang','Miao','Dan','Mei','Mao','Kan','Xian','Kou','Shi','Yang','Zheng','Yao','Shen','Huo','Da','Zhen','Kuang','Ju','Shen','Yi','Sheng','Mei','Mo','Zhu','Zhen','Zhen','Mian','Shi','Yuan','Die','Ni','Zi','Zi','Chao','Zha','Xuan','Bing','Mi','Long','Sui','Tong','Mi','Die','Di','Ne','Ming','Xuan','Chi','Kuang','Juan','Mou','Zhen','Tiao','Yang','Yan','Mo','Zhong','Mo','Zhe','Zheng','Mei','Suo','Shao','Han','Huan','Di','Cheng','Cuo','Juan','E','Man','Xian','Xi','Kun','Lai','Jian','Shan','Tian','Gun','Wan','Leng','Shi','Qiong','Lie','Ya','Jing','Zheng','Li','Lai','Sui','Juan','Shui','Sui','Du','Bi','Pi','Mu','Hun','Ni','Lu','Yi','Jie','Cai','Zhou','Yu','Hun','Ma','Xia','Xing','Hui','Gun','Zai','Chun','Jian','Mei','Du','Hou','Xuan','Tian','Kui','Gao','Rui','Mao','Xu','Fa','Wo','Miao','Chou','Kui','Mi','Weng','Kou','Dang','Chen','Ke','Sou','Xia','Qiong','Mo','Ming','Man','Shui','Ze','Zhang','Yi','Diao','Kou','Mo','Shun','Cong','Lou','Chi','Man','Piao','Cheng','Gui','Meng','Wan','Run','Pie','Xi','Qiao','Pu','Zhu','Deng','Shen','Shun','Liao','Che','Xian','Kan','Ye','Xu','Tong','Mou','Lin','Gui','Jian','Ye','Ai','Hui','Zhan','Jian','Gu','Zhao','Qu','Mei','Chou','Sao','Ning','Xun','Yao','Huo','Meng','Mian','Pin','Mian','Lei','Kuang','Jue','Xuan','Mian','Huo','Lu','Meng','Long','Guan','Man','Xi','Chu','Tang','Kan','Zhu','Mao','Jin','Jin','Yu','Shuo','Ze','Jue','Shi','Yi','Shen','Zhi','Hou','Shen','Ying','Ju','Zhou','Jiao','Cuo','Duan','Ai','Jiao','Zeng','Yue','Ba','Shi','Ding','Qi','Ji','Zi','Gan','Wu','Zhe','Ku','Gang','Xi','Fan','Kuang')