b=('dwaen','dwaenj','dwaenh','dwaed','dwael','dwaelg','dwaelm','dwaelb','dwaels','dwaelt','dwaelp','dwaelh','dwaem','dwaeb','dwaebs','dwaes','dwaess','dwaeng','dwaej','dwaech','dwaek','dwaet','dwaep','dwaeh','doe','doeg','doekk','doegs','doen','doenj','doenh','doed','doel','doelg','doelm','doelb','doels','doelt','doelp','doelh','doem','doeb','doebs','does','doess','doeng','doej','doech','doek','doet','doep','doeh','dyo','dyog','dyokk','dyogs','dyon','dyonj','dyonh','dyod','dyol','dyolg','dyolm','dyolb','dyols','dyolt','dyolp','dyolh','dyom','dyob','dyobs','dyos','dyoss','dyong','dyoj','dyoch','dyok','dyot','dyop','dyoh','du','dug','dukk','dugs','dun','dunj','dunh','dud','dul','dulg','dulm','dulb','duls','dult','dulp','dulh','dum','dub','dubs','dus','duss','dung','duj','duch','duk','dut','dup','duh','dwo','dwog','dwokk','dwogs','dwon','dwonj','dwonh','dwod','dwol','dwolg','dwolm','dwolb','dwols','dwolt','dwolp','dwolh','dwom','dwob','dwobs','dwos','dwoss','dwong','dwoj','dwoch','dwok','dwot','dwop','dwoh','dwe','dweg','dwekk','dwegs','dwen','dwenj','dwenh','dwed','dwel','dwelg','dwelm','dwelb','dwels','dwelt','dwelp','dwelh','dwem','dweb','dwebs','dwes','dwess','dweng','dwej','dwech','dwek','dwet','dwep','dweh','dwi','dwig','dwikk','dwigs','dwin','dwinj','dwinh','dwid','dwil','dwilg','dwilm','dwilb','dwils','dwilt','dwilp','dwilh','dwim','dwib','dwibs','dwis','dwiss','dwing','dwij','dwich','dwik','dwit','dwip','dwih','dyu','dyug','dyukk','dyugs','dyun','dyunj','dyunh','dyud','dyul','dyulg','dyulm','dyulb','dyuls','dyult','dyulp','dyulh','dyum','dyub','dyubs','dyus','dyuss','dyung','dyuj','dyuch','dyuk','dyut','dyup','dyuh','deu','deug','deukk','deugs','deun','deunj','deunh','deud','deul','deulg','deulm','deulb','deuls','deult','deulp','deulh','deum','deub','deubs','deus','deuss','deung','deuj','deuch','deuk','deut','deup','deuh','dui','duig','duikk','duigs','duin','duinj','duinh','duid')