b=('mil','milg','milm','milb','mils','milt','milp','milh','mim','mib','mibs','mis','miss','ming','mij','mich','mik','mit','mip','mih','ba','bag','bakk','bags','ban','banj','banh','bad','bal','balg','balm','balb','bals','balt','balp','balh','bam','bab','babs','bas','bass','bang','baj','bach','bak','bat','bap','bah','bae','baeg','baekk','baegs','baen','baenj','baenh','baed','bael','baelg','baelm','baelb','baels','baelt','baelp','baelh','baem','baeb','baebs','baes','baess','baeng','baej','baech','baek','baet','baep','baeh','bya','byag','byakk','byags','byan','byanj','byanh','byad','byal','byalg','byalm','byalb','byals','byalt','byalp','byalh','byam','byab','byabs','byas','byass','byang','byaj','byach','byak','byat','byap','byah','byae','byaeg','byaekk','byaegs','byaen','byaenj','byaenh','byaed','byael','byaelg','byaelm','byaelb','byaels','byaelt','byaelp','byaelh','byaem','byaeb','byaebs','byaes','byaess','byaeng','byaej','byaech','byaek','byaet','byaep','byaeh','beo','beog','beokk','beogs','beon','beonj','beonh','beod','beol','beolg','beolm','beolb','beols','beolt','beolp','beolh','beom','beob','beobs','beos','beoss','beong','beoj','beoch','beok','beot','beop','beoh','be','beg','bekk','begs','ben','benj','benh','bed','bel','belg','belm','belb','bels','belt','belp','belh','bem','beb','bebs','bes','bess','beng','bej','bech','bek','bet','bep','beh','byeo','byeog','byeokk','byeogs','byeon','byeonj','byeonh','byeod','byeol','byeolg','byeolm','byeolb','byeols','byeolt','byeolp','byeolh','byeom','byeob','byeobs','byeos','byeoss','byeong','byeoj','byeoch','byeok','byeot','byeop','byeoh','bye','byeg','byekk','byegs','byen','byenj','byenh','byed','byel','byelg','byelm','byelb','byels','byelt','byelp','byelh','byem','byeb','byebs','byes','byess','byeng','byej','byech','byek','byet','byep','byeh','bo','bog','bokk','bogs','bon','bonj','bonh','bod','bol','bolg','bolm','bolb')