b=('nyaess','nyaeng','nyaej','nyaech','nyaek','nyaet','nyaep','nyaeh','neo','neog','neokk','neogs','neon','neonj','neonh','neod','neol','neolg','neolm','neolb','neols','neolt','neolp','neolh','neom','neob','neobs','neos','neoss','neong','neoj','neoch','neok','neot','neop','neoh','ne','neg','nekk','negs','nen','nenj','nenh','ned','nel','nelg','nelm','nelb','nels','nelt','nelp','nelh','nem','neb','nebs','nes','ness','neng','nej','nech','nek','net','nep','neh','nyeo','nyeog','nyeokk','nyeogs','nyeon','nyeonj','nyeonh','nyeod','nyeol','nyeolg','nyeolm','nyeolb','nyeols','nyeolt','nyeolp','nyeolh','nyeom','nyeob','nyeobs','nyeos','nyeoss','nyeong','nyeoj','nyeoch','nyeok','nyeot','nyeop','nyeoh','nye','nyeg','nyekk','nyegs','nyen','nyenj','nyenh','nyed','nyel','nyelg','nyelm','nyelb','nyels','nyelt','nyelp','nyelh','nyem','nyeb','nyebs','nyes','nyess','nyeng','nyej','nyech','nyek','nyet','nyep','nyeh','no','nog','nokk','nogs','non','nonj','nonh','nod','nol','nolg','nolm','nolb','nols','nolt','nolp','nolh','nom','nob','nobs','nos','noss','nong','noj','noch','nok','not','nop','noh','nwa','nwag','nwakk','nwags','nwan','nwanj','nwanh','nwad','nwal','nwalg','nwalm','nwalb','nwals','nwalt','nwalp','nwalh','nwam','nwab','nwabs','nwas','nwass','nwang','nwaj','nwach','nwak','nwat','nwap','nwah','nwae','nwaeg','nwaekk','nwaegs','nwaen','nwaenj','nwaenh','nwaed','nwael','nwaelg','nwaelm','nwaelb','nwaels','nwaelt','nwaelp','nwaelh','nwaem','nwaeb','nwaebs','nwaes','nwaess','nwaeng','nwaej','nwaech','nwaek','nwaet','nwaep','nwaeh','noe','noeg','noekk','noegs','noen','noenj','noenh','noed','noel','noelg','noelm','noelb','noels','noelt','noelp','noelh','noem','noeb','noebs','noes','noess','noeng','noej','noech','noek','noet','noep','noeh','nyo','nyog','nyokk','nyogs','nyon','nyonj','nyonh','nyod','nyol','nyolg','nyolm','nyolb','nyols','nyolt','nyolp','nyolh','nyom','nyob','nyobs','nyos','nyoss','nyong','nyoj','nyoch')