b=('Cheng','Tiao','Zhi','Cui','Mei','Xie','Cui','Xie','Mai','Mai','Ji','Xie','Nin','Kuai','Sa','Zang','Qi','Nao','Mi','Nong','Luan','Wan','Bo','Wen','Wan','Xiu','Jiao','Jing','You','Heng','Cuo','Lie','Shan','Ting','Mei','Chun','Shen','Qian','De','Juan','Cu','Xiu','Xin','Tuo','Pao','Cheng','Nei','Pu','Dou','Tuo','Niao','Nao','Pi','Gu','Luo','Li','Lian','Zhang','Cui','Jie','Liang','Shui','Pi','Biao','Lun','Pian','Lei','Kui','Chui','Dan','Tian','Nei','Jing','Nai','La','Ye','Yan','Ren','Shen','Chuo','Fu','Fu','Ju','Fei','Qiang','Wan','Dong','Pi','Guo','Zong','Ding','Wo','Mei','Ni','Zhuan','Chi','Cou','Luo','Ou','Di','An','Xing','Nao','Shu','Shuan','Nan','Yun','Zhong','Rou','E','Sai','Tu','Yao','Jian','Wei','Jiao','Yu','Jia','Duan','Bi','Chang','Fu','Xian','Ni','Mian','Wa','Teng','Tui','Bang','Qian','Lu','Wa','Shou','Tang','Su','Zhui','Ge','Yi','Bo','Liao','Ji','Pi','Xie','Gao','Lu','Bin','Ou','Chang','Lu','Guo','Pang','Chuai','Biao','Jiang','Fu','Tang','Mo','Xi','Zhuan','Lu','Jiao','Ying','Lu','Zhi','Xue','Cun','Lin','Tong','Peng','Ni','Chuai','Liao','Cui','Gui','Xiao','Teng','Fan','Zhi','Jiao','Shan','Hu','Cui','Run','Xiang','Sui','Fen','Ying','Shan','Zhua','Dan','Kuai','Nong','Tun','Lian','Bi','Yong','Jue','Chu','Yi','Juan','La','Lian','Sao','Tun','Gu','Qi','Cui','Bin','Xun','Nao','Wo','Zang','Xian','Biao','Xing','Kuan','La','Yan','Lu','Huo','Za','Luo','Qu','Zang','Luan','Ni','Za','Chen','Qian','Wo','Guang','Zang','Lin','Guang','Zi','Jiao','Nie','Chou','Ji','Gao','Chou','Mian','Nie','Zhi','Zhi','Ge','Jian','Die','Zhi','Xiu','Tai','Zhen','Jiu','Xian','Yu','Cha')