b=('Di','Zhuang','Le','Lang','Chen','Cong','Li','Xiu','Qing','Shuang','Fan','Tong','Guan','Ze','Su','Lei','Lu','Liang','Mi','Lou','Chao','Su','Ke','Chu','Tang','Biao','Lu','Jiu','Zhe','Zha','Shu','Zhang','Man','Mo','Niao','Yang','Tiao','Peng','Zhu','Sha','Xi','Quan','Heng','Jian','Cong','Ji','Yan','Qiang','Xue','Ying','Er','Xun','Zhi','Qiao','Zui','Cong','Pu','Shu','Hua','Kui','Zhen','Zun','Yue','Shan','Xi','Chun','Dian','Fa','Gan','Mo','Wu','Qiao','Rao','Lin','Liu','Qiao','Xian','Run','Fan','Zhan','Tuo','Lao','Yun','Shun','Dun','Cheng','Tang','Meng','Ju','Cheng','Su','Jue','Jue','Dian','Hui','Ji','Nuo','Xiang','Tuo','Ning','Rui','Zhu','Tong','Zeng','Fen','Qiong','Ran','Heng','Qian','Gu','Liu','Lao','Gao','Chu','Xi','Sheng','Zi','San','Ji','Dou','Jing','Lu','Jian','Chu','Yuan','Ta','Shu','Jiang','Tan','Lin','Nong','Yin','Xi','Hui','Shan','Zui','Xuan','Cheng','Gan','Ju','Zui','Yi','Qin','Pu','Yan','Lei','Feng','Hui','Dang','Ji','Sui','Bo','Ping','Cheng','Chu','Zhua','Gui','Ji','Jie','Jia','Qing','Zhai','Jian','Qiang','Dao','Yi','Biao','Song','She','Lin','Li','Cha','Meng','Yin','Tao','Tai','Mian','Qi','Tuan','Bin','Huo','Ji','Qian','Ni','Ning','Yi','Gao','Kan','Yin','Nou','Qing','Yan','Qi','Mi','Zhao','Gui','Chun','Ji','Kui','Po','Deng','Chu','Ge','Mian','You','Zhi','Huang','Qian','Lei','Lei','Sa','Lu','Li','Cuan','Lu','Mie','Hui','Ou','Lu','Zhi','Gao','Du','Yuan','Li','Fei','Zhuo','Sou','Lian','Jiang','Chu','Qing','Zhu','Lu','Yan','Li','Zhu','Chen','Jie','E','Su','Huai','Nie','Yu','Long','Lai','Jiao','Xian','Gui','Ju','Xiao','Ling','Ying','Jian','Yin','You','Ying')