b=('Tui','Song','Shi','Tao','Pang','Hou','Ni','Dun','Jiong','Xuan','Xun','Bu','You','Xiao','Qiu','Tou','Zhu','Qiu','Di','Di','Tu','Jing','Ti','Dou','Yi','Zhe','Tong','Guang','Wu','Shi','Cheng','Su','Zao','Qun','Feng','Lian','Suo','Hui','Li','Gu','Lai','Ben','Cuo','Jue','Beng','Huan','Dai','Lu','You','Zhou','Jin','Yu','Chuo','Kui','Wei','Ti','Yi','Da','Yuan','Luo','Bi','Nuo','Yu','Dang','Sui','Dun','Sui','Yan','Chuan','Chi','Ti','Yu','Shi','Zhen','You','Yun','E','Bian','Guo','E','Xia','Huang','Qiu','Dao','Da','Wei','Nan','Yi','Gou','Yao','Chou','Liu','Xun','Ta','Di','Chi','Yuan','Su','Ta','Qian','Ma','Yao','Guan','Zhang','Ao','Shi','Ca','Chi','Su','Zao','Zhe','Dun','Di','Lou','Chi','Cuo','Lin','Zun','Rao','Qian','Xuan','Yu','Yi','E','Liao','Ju','Shi','Bi','Yao','Mai','Xie','Sui','Hai','Zhan','Teng','Er','Miao','Bian','Bian','La','Li','Yuan','Yao','Luo','Li','Yi','Ting','Deng','Qi','Yong','Shan','Han','Yu','Mang','Ru','Qiong','Xi','Kuang','Fu','Kang','Bin','Fang','Xing','Na','Xin','Shen','Bang','Yuan','Cun','Huo','Xie','Bang','Wu','Ju','You','Han','Tai','Qiu','Bi','Pi','Bing','Shao','Bei','Wa','Di','Zou','Ye','Lin','Kuang','Gui','Zhu','Shi','Ku','Yu','Gai','He','Qie','Zhi','Ji','Huan','Hou','Xing','Jiao','Xi','Gui','Nuo','Lang','Jia','Kuai','Zheng','Lang','Yun','Yan','Cheng','Dou','Xi','Lu','Fu','Wu','Fu','Gao','Hao','Lang','Jia','Geng','Jun','Ying','Bo','Xi','Bei','Li','Yun','Bu','Xiao','Qi','Pi','Qing','Guo','Zhou','Tan','Zou','Ping','Lai','Ni','Chen','You','Bu','Xiang','Dan','Ju','Yong','Qiao','Yi','Dou','Yan','Mei')