b=('Huai','Tai','Song','Wu','Ou','Chang','Chuang','Ju','Yi','Bao','Chao','Min','Pei','Zuo','Zen','Yang','Ju','Ban','Nu','Nao','Zheng','Pa','Bu','Tie','Hu','Hu','Ju','Da','Lian','Si','Chou','Di','Dai','Yi','Tu','You','Fu','Ji','Peng','Xing','Yuan','Ni','Guai','Fu','Xi','Bi','You','Qie','Xuan','Cong','Bing','Huang','Xu','Chu','Bi','Shu','Xi','Tan','Yong','Zong','Dui','Mo','Zhi','Yi','Shi','Nen','Xun','Shi','Xi','Lao','Heng','Kuang','Mou','Zhi','Xie','Lian','Tiao','Huang','Die','Hao','Kong','Gui','Heng','Xi','Jiao','Shu','Si','Hu','Qiu','Yang','Hui','Hui','Chi','Jia','Yi','Xiong','Guai','Lin','Hui','Zi','Xu','Chi','Shang','Nu','Hen','En','Ke','Dong','Tian','Gong','Quan','Xi','Qia','Yue','Peng','Ken','De','Hui','E','Xiao','Tong','Yan','Kai','Ce','Nao','Yun','Mang','Yong','Yong','Yuan','Pi','Kun','Qiao','Yue','Yu','Tu','Jie','Xi','Zhe','Lin','Ti','Han','Hao','Qie','Ti','Bu','Yi','Qian','Hui','Xi','Bei','Man','Yi','Heng','Song','Quan','Cheng','Kui','Wu','Wu','You','Li','Liang','Huan','Cong','Yi','Yue','Li','Nin','Nao','E','Que','Xuan','Qian','Wu','Min','Cong','Fei','Bei','De','Cui','Chang','Men','San','Ji','Guan','Guan','Xing','Dao','Qi','Kong','Tian','Lun','Xi','Kan','Gun','Ni','Qing','Chou','Dun','Guo','Zhan','Jing','Wan','Yuan','Jin','Ji','Lan','Yu','Huo','He','Quan','Tan','Ti','Ti','Nie','Wang','Chuo','Hu','Hun','Xi','Chang','Xin','Wei','Hui','E','Suo','Zong','Jian','Yong','Dian','Ju','Can','Cheng','De','Bei','Qie','Can','Dan','Guan','Duo','Nao','Yun','Xiang','Zhui','Die','Huang','Chun','Qiong','Re','Xing','Ce','Bian','Min','Zong','Ti')