b=('Yan','Yan','Ding','Fu','Qiu','Qiu','Jiao','Hong','Ji','Fan','Xun','Diao','Hong','Chai','Tao','Xu','Jie','Yi','Ren','Xun','Yin','Shan','Qi','Tuo','Ji','Xun','Yin','E','Fen','Ya','Yao','Song','Shen','Yin','Xin','Jue','Xiao','Ne','Chen','You','Zhi','Xiong','Fang','Xin','Chao','She','Yan','Sa','Zhun','Xu','Yi','Yi','Su','Chi','He','Shen','He','Xu','Zhen','Zhu','Zheng','Gou','Zi','Zi','Zhan','Gu','Fu','Jian','Die','Ling','Di','Yang','Li','Nao','Pan','Zhou','Gan','Yi','Ju','Yao','Zha','Yi','Yi','Qu','Zhao','Ping','Bi','Xiong','Qu','Ba','Da','Zu','Tao','Zhu','Ci','Zhe','Yong','Xu','Xun','Yi','Huang','He','Shi','Cha','Xiao','Shi','Hen','Cha','Gou','Gui','Quan','Hui','Jie','Hua','Gai','Xiang','Wei','Shen','Zhou','Tong','Mi','Zhan','Ming','E','Hui','Yan','Xiong','Gua','Er','Bing','Tiao','Yi','Lei','Zhu','Kuang','Kua','Wu','Yu','Teng','Ji','Zhi','Ren','Cu','Lang','E','Kuang','Ei','Shi','Ting','Dan','Bei','Chan','You','Keng','Qiao','Qin','Shua','An','Yu','Xiao','Cheng','Jie','Xian','Wu','Wu','Gao','Song','Bu','Hui','Jing','Shuo','Zhen','Shuo','Du','Hua','Chang','Shui','Jie','Ke','Qu','Cong','Xiao','Sui','Wang','Xian','Fei','Chi','Ta','Yi','Ni','Yin','Diao','Pi','Zhuo','Chan','Chen','Zhun','Ji','Qi','Tan','Zhui','Wei','Ju','Qing','Dong','Zheng','Ze','Zou','Qian','Zhuo','Liang','Jian','Chu','Hao','Lun','Shen','Biao','Hua','Pian','Yu','Die','Xu','Pian','Shi','Xuan','Shi','Hun','Hua','E','Zhong','Di','Xie','Fu','Pu','Ting','Jian','Qi','Yu','Zi','Zhuan','Xi','Hui','Yin','An','Xian','Nan','Chen','Feng','Zhu','Yang','Yan','Huang','Xuan','Ge','Nuo','Qi')