b=('Lu','Mu','Mao','Tong','Rong','Chang','Pu','Lu','Zhan','Sao','Zhan','Meng','Lu','Qu','Die','Shi','Di','Min','Jue','Mang','Qi','Pie','Nai','Qi','Dao','Xian','Chuan','Fen','Yang','Nei','Bin','Fu','Shen','Dong','Qing','Qi','Yin','Xi','Hai','Yang','An','Ya','Ke','Qing','Ya','Dong','Dan','Lu','Qing','Yang','Yun','Yun','Shui','Shui','Zheng','Bing','Yong','Dang','Shui','Le','Ni','Tun','Fan','Gui','Ting','Zhi','Qiu','Bin','Ze','Mian','Cuan','Hui','Diao','Han','Cha','Zhuo','Chuan','Wan','Fan','Da','Xi','Tuo','Mang','Qiu','Qi','Shan','Pin','Han','Qian','Wu','Wu','Xun','Si','Ru','Gong','Jiang','Chi','Wu','Tu','Jiu','Tang','Zhi','Zhi','Qian','Mi','Gu','Wang','Jing','Jing','Rui','Jun','Hong','Tai','Quan','Ji','Bian','Bian','Gan','Wen','Zhong','Fang','Xiong','Jue','Hu','Niu','Qi','Fen','Xu','Xu','Qin','Yi','Wo','Yun','Yuan','Hang','Yan','Chen','Chen','Dan','You','Dun','Hu','Huo','Qi','Mu','Nu','Mei','Da','Mian','Mi','Chong','Pang','Bi','Sha','Zhi','Pei','Pan','Zhui','Za','Gou','Liu','Mei','Ze','Feng','Ou','Li','Lun','Cang','Feng','Wei','Hu','Mo','Mei','Shu','Ju','Za','Tuo','Tuo','Tuo','He','Li','Mi','Yi','Fa','Fei','You','Tian','Zhi','Zhao','Gu','Zhan','Yan','Si','Kuang','Jiong','Ju','Xie','Qiu','Yi','Jia','Zhong','Quan','Po','Hui','Mi','Ben','Ze','Zhu','Le','You','Gu','Hong','Gan','Fa','Mao','Si','Hu','Ping','Ci','Fan','Zhi','Su','Ning','Cheng','Ling','Pao','Bo','Qi','Si','Ni','Ju','Sa','Zhu','Sheng','Lei','Xuan','Jue','Fu','Pan','Min','Tai','Yang','Ji','Yong','Guan','Beng','Xue','Long','Lu','Dan','Luo','Xie','Po','Ze','Jing','Yin')