b=('it','ix','i','ip','iet','iex','ie','iep','at','ax','a','ap','uox','uo','uop','ot','ox','o','op','ex','e','w','bit','bix','bi','bip','biet','biex','bie','biep','bat','bax','ba','bap','buox','buo','buop','bot','box','bo','bop','bex','be','bep','but','bux','bu','bup','burx','bur','byt','byx','by','byp','byrx','byr','pit','pix','pi','pip','piex','pie','piep','pat','pax','pa','pap','puox','puo','puop','pot','pox','po','pop','put','pux','pu','pup','purx','pur','pyt','pyx','py','pyp','pyrx','pyr','bbit','bbix','bbi','bbip','bbiet','bbiex','bbie','bbiep','bbat','bbax','bba','bbap','bbuox','bbuo','bbuop','bbot','bbox','bbo','bbop','bbex','bbe','bbep','bbut','bbux','bbu','bbup','bburx','bbur','bbyt','bbyx','bby','bbyp','nbit','nbix','nbi','nbip','nbiex','nbie','nbiep','nbat','nbax','nba','nbap','nbot','nbox','nbo','nbop','nbut','nbux','nbu','nbup','nburx','nbur','nbyt','nbyx','nby','nbyp','nbyrx','nbyr','hmit','hmix','hmi','hmip','hmiex','hmie','hmiep','hmat','hmax','hma','hmap','hmuox','hmuo','hmuop','hmot','hmox','hmo','hmop','hmut','hmux','hmu','hmup','hmurx','hmur','hmyx','hmy','hmyp','hmyrx','hmyr','mit','mix','mi','mip','miex','mie','miep','mat','max','ma','map','muot','muox','muo','muop','mot','mox','mo','mop','mex','me','mut','mux','mu','mup','murx','mur','myt','myx','my','myp','fit','fix','fi','fip','fat','fax','fa','fap','fox','fo','fop','fut','fux','fu','fup','furx','fur','fyt','fyx','fy','fyp','vit','vix','vi','vip','viet','viex','vie','viep','vat','vax','va','vap','vot','vox','vo','vop','vex','vep','vut','vux','vu','vup','vurx','vur','vyt','vyx','vy','vyp','vyrx','vyr')