b=('ga','gag','gakk','gags','gan','ganj','ganh','gad','gal','galg','galm','galb','gals','galt','galp','galh','gam','gab','gabs','gas','gass','gang','gaj','gach','gak','gat','gap','gah','gae','gaeg','gaekk','gaegs','gaen','gaenj','gaenh','gaed','gael','gaelg','gaelm','gaelb','gaels','gaelt','gaelp','gaelh','gaem','gaeb','gaebs','gaes','gaess','gaeng','gaej','gaech','gaek','gaet','gaep','gaeh','gya','gyag','gyakk','gyags','gyan','gyanj','gyanh','gyad','gyal','gyalg','gyalm','gyalb','gyals','gyalt','gyalp','gyalh','gyam','gyab','gyabs','gyas','gyass','gyang','gyaj','gyach','gyak','gyat','gyap','gyah','gyae','gyaeg','gyaekk','gyaegs','gyaen','gyaenj','gyaenh','gyaed','gyael','gyaelg','gyaelm','gyaelb','gyaels','gyaelt','gyaelp','gyaelh','gyaem','gyaeb','gyaebs','gyaes','gyaess','gyaeng','gyaej','gyaech','gyaek','gyaet','gyaep','gyaeh','geo','geog','geokk','geogs','geon','geonj','geonh','geod','geol','geolg','geolm','geolb','geols','geolt','geolp','geolh','geom','geob','geobs','geos','geoss','geong','geoj','geoch','geok','geot','geop','geoh','ge','geg','gekk','gegs','gen','genj','genh','ged','gel','gelg','gelm','gelb','gels','gelt','gelp','gelh','gem','geb','gebs','ges','gess','geng','gej','gech','gek','get','gep','geh','gyeo','gyeog','gyeokk','gyeogs','gyeon','gyeonj','gyeonh','gyeod','gyeol','gyeolg','gyeolm','gyeolb','gyeols','gyeolt','gyeolp','gyeolh','gyeom','gyeob','gyeobs','gyeos','gyeoss','gyeong','gyeoj','gyeoch','gyeok','gyeot','gyeop','gyeoh','gye','gyeg','gyekk','gyegs','gyen','gyenj','gyenh','gyed','gyel','gyelg','gyelm','gyelb','gyels','gyelt','gyelp','gyelh','gyem','gyeb','gyebs','gyes','gyess','gyeng','gyej','gyech','gyek','gyet','gyep','gyeh','go','gog','gokk','gogs','gon','gonj','gonh','god','gol','golg','golm','golb','gols','golt','golp','golh','gom','gob','gobs','gos','goss','gong','goj','goch','gok','got','gop','goh','gwa','gwag','gwakk','gwags')