b=('Kai','Bian','Yi','Qi','Nong','Fen','Ju','Yan','Yi','Zang','Bi','Yi','Yi','Er','San','Shi','Er','Shi','Shi','Gong','Diao','Yin','Hu','Fu','Hong','Wu','Tui','Chi','Jiang','Ba','Shen','Di','Zhang','Jue','Tao','Fu','Di','Mi','Xian','Hu','Chao','Nu','Jing','Zhen','Yi','Mi','Quan','Wan','Shao','Ruo','Xuan','Jing','Diao','Zhang','Jiang','Qiang','Peng','Dan','Qiang','Bi','Bi','She','Dan','Jian','Gou','Ge','Fa','Bi','Kou','Jian','Bie','Xiao','Dan','Guo','Jiang','Hong','Mi','Guo','Wan','Jue','Ji','Ji','Gui','Dang','Lu','Lu','Tuan','Hui','Zhi','Hui','Hui','Yi','Yi','Yi','Yi','Yue','Yue','Shan','Xing','Wen','Tong','Yan','Yan','Yu','Chi','Cai','Biao','Diao','Bin','Peng','Yong','Piao','Zhang','Ying','Chi','Chi','Zhuo','Tuo','Ji','Fang','Zhong','Yi','Wang','Che','Bi','Di','Ling','Fu','Wang','Zheng','Cu','Wang','Jing','Dai','Xi','Xun','Hen','Yang','Huai','Lu','Hou','Wang','Cheng','Zhi','Xu','Jing','Tu','Cong','Zhi','Lai','Cong','De','Pai','Xi','Dong','Ji','Chang','Zhi','Cong','Zhou','Lai','Yu','Xie','Jie','Jian','Shi','Jia','Bian','Huang','Fu','Xun','Wei','Pang','Yao','Wei','Xi','Zheng','Piao','Ti','De','Zheng','Zheng','Bie','De','Chong','Che','Jiao','Hui','Jiao','Hui','Mei','Long','Xiang','Bao','Qu','Xin','Xin','Bi','Yi','Le','Ren','Dao','Ding','Gai','Ji','Ren','Ren','Chan','Tan','Te','Te','Gan','Qi','Shi','Cun','Zhi','Wang','Mang','Xi','Fan','Ying','Tian','Min','Wen','Zhong','Chong','Wu','Ji','Wu','Xi','Jia','You','Wan','Cong','Song','Kuai','Yu','Bian','Zhi','Qi','Cui','Chen','Tai','Tun','Qian','Nian','Hun','Xiong','Niu','Kuang','Xian','Xin','Kang','Hu','Kai','Fen')