b=('hwen','hwenj','hwenh','hwed','hwel','hwelg','hwelm','hwelb','hwels','hwelt','hwelp','hwelh','hwem','hweb','hwebs','hwes','hwess','hweng','hwej','hwech','hwek','hwet','hwep','hweh','hwi','hwig','hwikk','hwigs','hwin','hwinj','hwinh','hwid','hwil','hwilg','hwilm','hwilb','hwils','hwilt','hwilp','hwilh','hwim','hwib','hwibs','hwis','hwiss','hwing','hwij','hwich','hwik','hwit','hwip','hwih','hyu','hyug','hyukk','hyugs','hyun','hyunj','hyunh','hyud','hyul','hyulg','hyulm','hyulb','hyuls','hyult','hyulp','hyulh','hyum','hyub','hyubs','hyus','hyuss','hyung','hyuj','hyuch','hyuk','hyut','hyup','hyuh','heu','heug','heukk','heugs','heun','heunj','heunh','heud','heul','heulg','heulm','heulb','heuls','heult','heulp','heulh','heum','heub','heubs','heus','heuss','heung','heuj','heuch','heuk','heut','heup','heuh','hui','huig','huikk','huigs','huin','huinj','huinh','huid','huil','huilg','huilm','huilb','huils','huilt','huilp','huilh','huim','huib','huibs','huis','huiss','huing','huij','huich','huik','huit','huip','huih','hi','hig','hikk','higs','hin','hinj','hinh','hid','hil','hilg','hilm','hilb','hils','hilt','hilp','hilh','him','hib','hibs','his','hiss','hing','hij','hich','hik','hit','hip','hih')