b=('Hu','Xi','Shu','He','Xun','Ku','Juan','Xiao','Xi','Yan','Han','Zhuang','Jun','Di','Xie','Ji','Wu','Yan','Lu','Han','Yan','Huan','Men','Ju','Dao','Bei','Fen','Lin','Kun','Hun','Tun','Xi','Cui','Wu','Hong','Chao','Fu','Wo','Jiao','Cong','Feng','Ping','Qiong','Ruo','Xi','Qiong','Xin','Chao','Yan','Yan','Yi','Jue','Yu','Gang','Ran','Pi','Xiong','Gang','Sheng','Chang','Shao','Xiong','Nian','Geng','Wei','Chen','He','Kui','Zhong','Duan','Xia','Hui','Feng','Lian','Xuan','Xing','Huang','Jiao','Jian','Bi','Ying','Zhu','Wei','Tuan','Shan','Xi','Nuan','Nuan','Chan','Yan','Jiong','Jiong','Yu','Mei','Sha','Wei','Zha','Jin','Qiong','Rou','Mei','Huan','Xu','Zhao','Wei','Fan','Qiu','Sui','Yang','Lie','Zhu','Jie','Zao','Gua','Bao','Hu','Yun','Nan','Shi','Liang','Bian','Gou','Tui','Tang','Chao','Shan','En','Bo','Huang','Xie','Xi','Wu','Xi','Yun','He','He','Xi','Yun','Xiong','Nai','Shan','Qiong','Yao','Xun','Mi','Lian','Ying','Wu','Rong','Gong','Yan','Qiang','Liu','Xi','Bi','Biao','Cong','Lu','Jian','Shu','Yi','Lou','Peng','Sui','Yi','Teng','Jue','Zong','Yun','Hu','Yi','Zhi','Ao','Wei','Liu','Han','Ou','Re','Jiong','Man','Kun','Shang','Cuan','Zeng','Jian','Xi','Xi','Xi','Yi','Xiao','Chi','Huang','Chan','Ye','Tan','Ran','Yan','Xun','Qiao','Jun','Deng','Dun','Shen','Jiao','Fen','Si','Liao','Yu','Lin','Tong','Shao','Fen','Fan','Yan','Xun','Lan','Mei','Tang','Yi','Jiong','Men','Jing','Jiao','Ying','Yu','Yi','Xue','Lan','Tai','Zao','Can','Sui','Xi','Que','Zong','Lian','Hui','Zhu','Xie','Ling','Wei','Yi','Xie','Zhao','Hui','Da','Nong','Lan','Ru','Xian','He','Xun','Jin','Chou','Dao','Yao')