b=('Hai','Ren','Tian','Jiao','Jia','Bing','Yao','Tong','Ci','Xiang','Yang','Juan','Er','Yan','Le','Xi','Can','Bo','Nei','E','Bu','Jun','Dou','Su','Yu','Shi','Yao','Hun','Guo','Shi','Jian','Zhui','Bing','Xian','Bu','Ye','Tan','Fei','Zhang','Wei','Guan','E','Nuan','Yun','Hu','Huang','Tie','Hui','Jian','Hou','Ai','Tang','Fen','Wei','Gu','Cha','Song','Tang','Bo','Gao','Xi','Kui','Liu','Sou','Tao','Ye','Wen','Mo','Tang','Man','Bi','Yu','Xiu','Jin','San','Kui','Zhuan','Shan','Chi','Dan','Yi','Ji','Rao','Cheng','Yong','Tao','Wei','Xiang','Zhan','Fen','Hai','Meng','Yan','Mo','Chan','Xiang','Luo','Zan','Nang','Shi','Ding','Ji','Tuo','Tang','Tun','Xi','Ren','Yu','Chi','Fan','Yin','Jian','Shi','Bao','Si','Duo','Yi','Er','Rao','Xiang','He','Le','Jiao','Xi','Bing','Bo','Dou','E','Yu','Nei','Jun','Guo','Hun','Xian','Guan','Cha','Kui','Gu','Sou','Chan','Ye','Mo','Bo','Liu','Xiu','Jin','Man','San','Zhuan','Nang','Shou','Kui','Guo','Xiang','Fen','Bo','Ni','Bi','Bo','Tu','Han','Fei','Jian','An','Ai','Fu','Xian','Yun','Xin','Fen','Pin','Xin','Ma','Yu','Feng','Han','Di','Tuo','Zhe','Chi','Xun','Zhu','Zhi','Pei','Xin','Ri','Sa','Yun','Wen','Zhi','Dan','Lu','You','Bo','Bao','Jue','Tuo','Yi','Qu','Wen','Qu','Jiong','Po','Zhao','Yuan','Pei','Zhou','Ju','Zhu','Nu','Ju','Pi','Zang','Jia','Ling','Zhen','Tai','Fu','Yang','Shi','Bi','Tuo','Tuo','Si','Liu','Ma','Pian','Tao','Zhi','Rong','Teng','Dong','Xun','Quan','Shen','Jiong','Er','Hai','Bo','Zhu','Yin','Luo','Zhou','Dan','Hai','Liu','Ju','Song','Qin','Mang','Lang','Han','Tu','Xuan','Tui','Jun')