b=('Hu','Qi','He','Cui','Tao','Chun','Bi','Chang','Huan','Fei','Lai','Qi','Meng','Ping','Wei','Dan','Sha','Huan','Yan','Yi','Tiao','Qi','Wan','Ce','Nai','Zhen','Tuo','Jiu','Tie','Luo','Bi','Yi','Pan','Bo','Pao','Ding','Ying','Ying','Ying','Xiao','Sa','Qiu','Ke','Xiang','Wan','Yu','Yu','Fu','Lian','Xuan','Xuan','Nan','Ce','Wo','Chun','Xiao','Yu','Bian','Mao','An','E','Luo','Ying','Kuo','Kuo','Jiang','Mian','Zuo','Zuo','Zu','Bao','Rou','Xi','Ye','An','Qu','Jian','Fu','Lu','Jing','Pen','Feng','Hong','Hong','Hou','Yan','Tu','Zhe','Zi','Xiang','Ren','Ge','Qia','Qing','Mi','Huang','Shen','Pu','Gai','Dong','Zhou','Jian','Wei','Bo','Wei','Pa','Ji','Hu','Zang','Jia','Duan','Yao','Sui','Cong','Quan','Wei','Zhen','Kui','Ting','Hun','Xi','Shi','Qi','Lan','Zong','Yao','Yuan','Mei','Yun','Shu','Di','Zhuan','Guan','Ran','Xue','Chan','Kai','Kui','Hua','Jiang','Lou','Wei','Pai','You','Sou','Yin','Shi','Chun','Shi','Yun','Zhen','Lang','Ru','Meng','Li','Que','Suan','Yuan','Li','Ju','Xi','Bang','Chu','Xu','Tu','Liu','Huo','Dian','Qian','Zu','Po','Cuo','Yuan','Chu','Yu','Kuai','Pan','Pu','Pu','Na','Shuo','Xi','Fen','Yun','Zheng','Jian','Ji','Ruo','Cang','En','Mi','Hao','Sun','Zhen','Ming','Sou','Xu','Liu','Xi','Gu','Lang','Rong','Weng','Gai','Cuo','Shi','Tang','Luo','Ru','Suo','Xuan','Bei','Yao','Gui','Bi','Zong','Gun','Zuo','Tiao','Ce','Pei','Lan','Dan','Ji','Li','Shen','Lang','Yu','Ling','Ying','Mo','Diao','Tiao','Mao','Tong','Chu','Peng','An','Lian','Cong','Xi','Ping','Qiu','Jin','Chun','Jie','Wei','Tui','Cao','Yu','Yi','Zi','Liao','Bi','Lu','Xu')