b=('Yao','Lao','Lao','Kao','Mao','Zhe','Qi','Gou','Gou','Gou','Die','Die','Er','Shua','Ruan','Nai','Nai','Duan','Lei','Ting','Zi','Geng','Chao','Hao','Yun','Ba','Pi','Yi','Si','Qu','Jia','Ju','Huo','Chu','Lao','Lun','Ji','Tang','Ou','Lou','Nou','Jiang','Pang','Zha','Lou','Ji','Lao','Huo','You','Mo','Huai','Er','Yi','Ding','Ye','Da','Song','Qin','Yun','Chi','Dan','Dan','Hong','Geng','Zhi','Pan','Nie','Dan','Zhen','Che','Ling','Zheng','You','Wa','Liao','Long','Zhi','Ning','Tiao','Er','Ya','Tie','Gua','Xu','Lian','Hao','Sheng','Lie','Pin','Jing','Ju','Bi','Di','Guo','Wen','Xu','Ping','Cong','Ding','Ni','Ting','Ju','Cong','Kui','Lian','Kui','Cong','Lian','Weng','Kui','Lian','Lian','Cong','Ao','Sheng','Song','Ting','Kui','Nie','Zhi','Dan','Ning','Qie','Ni','Ting','Ting','Long','Yu','Yu','Zhao','Si','Su','Yi','Su','Si','Zhao','Zhao','Rou','Yi','Le','Ji','Qiu','Ken','Cao','Ge','Bo','Huan','Huang','Chi','Ren','Xiao','Ru','Zhou','Yuan','Du','Gang','Rong','Gan','Cha','Wo','Chang','Gu','Zhi','Han','Fu','Fei','Fen','Pei','Pang','Jian','Fang','Zhun','You','Na','Ang','Ken','Ran','Gong','Yu','Wen','Yao','Qi','Pi','Qian','Xi','Xi','Fei','Ken','Jing','Tai','Shen','Zhong','Zhang','Xie','Shen','Wei','Zhou','Die','Dan','Fei','Ba','Bo','Qu','Tian','Bei','Gua','Tai','Zi','Fei','Zhi','Ni','Ping','Zi','Fu','Pang','Zhen','Xian','Zuo','Pei','Jia','Sheng','Zhi','Bao','Mu','Qu','Hu','Ke','Chi','Yin','Xu','Yang','Long','Dong','Ka','Lu','Jing','Nu','Yan','Pang','Kua','Yi','Guang','Hai','Ge','Dong','Chi','Jiao','Xiong','Xiong','Er','An','Heng','Pian','Neng','Zi','Gui')