b=('toels','toelt','toelp','toelh','toem','toeb','toebs','toes','toess','toeng','toej','toech','toek','toet','toep','toeh','tyo','tyog','tyokk','tyogs','tyon','tyonj','tyonh','tyod','tyol','tyolg','tyolm','tyolb','tyols','tyolt','tyolp','tyolh','tyom','tyob','tyobs','tyos','tyoss','tyong','tyoj','tyoch','tyok','tyot','tyop','tyoh','tu','tug','tukk','tugs','tun','tunj','tunh','tud','tul','tulg','tulm','tulb','tuls','tult','tulp','tulh','tum','tub','tubs','tus','tuss','tung','tuj','tuch','tuk','tut','tup','tuh','two','twog','twokk','twogs','twon','twonj','twonh','twod','twol','twolg','twolm','twolb','twols','twolt','twolp','twolh','twom','twob','twobs','twos','twoss','twong','twoj','twoch','twok','twot','twop','twoh','twe','tweg','twekk','twegs','twen','twenj','twenh','twed','twel','twelg','twelm','twelb','twels','twelt','twelp','twelh','twem','tweb','twebs','twes','twess','tweng','twej','twech','twek','twet','twep','tweh','twi','twig','twikk','twigs','twin','twinj','twinh','twid','twil','twilg','twilm','twilb','twils','twilt','twilp','twilh','twim','twib','twibs','twis','twiss','twing','twij','twich','twik','twit','twip','twih','tyu','tyug','tyukk','tyugs','tyun','tyunj','tyunh','tyud','tyul','tyulg','tyulm','tyulb','tyuls','tyult','tyulp','tyulh','tyum','tyub','tyubs','tyus','tyuss','tyung','tyuj','tyuch','tyuk','tyut','tyup','tyuh','teu','teug','teukk','teugs','teun','teunj','teunh','teud','teul','teulg','teulm','teulb','teuls','teult','teulp','teulh','teum','teub','teubs','teus','teuss','teung','teuj','teuch','teuk','teut','teup','teuh','tui','tuig','tuikk','tuigs','tuin','tuinj','tuinh','tuid','tuil','tuilg','tuilm','tuilb','tuils','tuilt','tuilp','tuilh','tuim','tuib','tuibs','tuis','tuiss','tuing','tuij','tuich','tuik','tuit','tuip','tuih','ti','tig','tikk','tigs','tin','tinj','tinh','tid','til','tilg','tilm','tilb','tils','tilt','tilp','tilh')