b=('ppwok','ppwot','ppwop','ppwoh','ppwe','ppweg','ppwekk','ppwegs','ppwen','ppwenj','ppwenh','ppwed','ppwel','ppwelg','ppwelm','ppwelb','ppwels','ppwelt','ppwelp','ppwelh','ppwem','ppweb','ppwebs','ppwes','ppwess','ppweng','ppwej','ppwech','ppwek','ppwet','ppwep','ppweh','ppwi','ppwig','ppwikk','ppwigs','ppwin','ppwinj','ppwinh','ppwid','ppwil','ppwilg','ppwilm','ppwilb','ppwils','ppwilt','ppwilp','ppwilh','ppwim','ppwib','ppwibs','ppwis','ppwiss','ppwing','ppwij','ppwich','ppwik','ppwit','ppwip','ppwih','ppyu','ppyug','ppyukk','ppyugs','ppyun','ppyunj','ppyunh','ppyud','ppyul','ppyulg','ppyulm','ppyulb','ppyuls','ppyult','ppyulp','ppyulh','ppyum','ppyub','ppyubs','ppyus','ppyuss','ppyung','ppyuj','ppyuch','ppyuk','ppyut','ppyup','ppyuh','ppeu','ppeug','ppeukk','ppeugs','ppeun','ppeunj','ppeunh','ppeud','ppeul','ppeulg','ppeulm','ppeulb','ppeuls','ppeult','ppeulp','ppeulh','ppeum','ppeub','ppeubs','ppeus','ppeuss','ppeung','ppeuj','ppeuch','ppeuk','ppeut','ppeup','ppeuh','ppui','ppuig','ppuikk','ppuigs','ppuin','ppuinj','ppuinh','ppuid','ppuil','ppuilg','ppuilm','ppuilb','ppuils','ppuilt','ppuilp','ppuilh','ppuim','ppuib','ppuibs','ppuis','ppuiss','ppuing','ppuij','ppuich','ppuik','ppuit','ppuip','ppuih','ppi','ppig','ppikk','ppigs','ppin','ppinj','ppinh','ppid','ppil','ppilg','ppilm','ppilb','ppils','ppilt','ppilp','ppilh','ppim','ppib','ppibs','ppis','ppiss','pping','ppij','ppich','ppik','ppit','ppip','ppih','sa','sag','sakk','sags','san','sanj','sanh','sad','sal','salg','salm','salb','sals','salt','salp','salh','sam','sab','sabs','sas','sass','sang','saj','sach','sak','sat','sap','sah','sae','saeg','saekk','saegs','saen','saenj','saenh','saed','sael','saelg','saelm','saelb','saels','saelt','saelp','saelh','saem','saeb','saebs','saes','saess','saeng','saej','saech','saek','saet','saep','saeh','sya','syag','syakk','syags','syan','syanj','syanh','syad','syal','syalg','syalm','syalb','syals','syalt','syalp','syalh','syam','syab','syabs','syas','syass','syang','syaj','syach','syak','syat','syap','syah')