b=('jun','junj','junh','jud','jul','julg','julm','julb','juls','jult','julp','julh','jum','jub','jubs','jus','juss','jung','juj','juch','juk','jut','jup','juh','jwo','jwog','jwokk','jwogs','jwon','jwonj','jwonh','jwod','jwol','jwolg','jwolm','jwolb','jwols','jwolt','jwolp','jwolh','jwom','jwob','jwobs','jwos','jwoss','jwong','jwoj','jwoch','jwok','jwot','jwop','jwoh','jwe','jweg','jwekk','jwegs','jwen','jwenj','jwenh','jwed','jwel','jwelg','jwelm','jwelb','jwels','jwelt','jwelp','jwelh','jwem','jweb','jwebs','jwes','jwess','jweng','jwej','jwech','jwek','jwet','jwep','jweh','jwi','jwig','jwikk','jwigs','jwin','jwinj','jwinh','jwid','jwil','jwilg','jwilm','jwilb','jwils','jwilt','jwilp','jwilh','jwim','jwib','jwibs','jwis','jwiss','jwing','jwij','jwich','jwik','jwit','jwip','jwih','jyu','jyug','jyukk','jyugs','jyun','jyunj','jyunh','jyud','jyul','jyulg','jyulm','jyulb','jyuls','jyult','jyulp','jyulh','jyum','jyub','jyubs','jyus','jyuss','jyung','jyuj','jyuch','jyuk','jyut','jyup','jyuh','jeu','jeug','jeukk','jeugs','jeun','jeunj','jeunh','jeud','jeul','jeulg','jeulm','jeulb','jeuls','jeult','jeulp','jeulh','jeum','jeub','jeubs','jeus','jeuss','jeung','jeuj','jeuch','jeuk','jeut','jeup','jeuh','jui','juig','juikk','juigs','juin','juinj','juinh','juid','juil','juilg','juilm','juilb','juils','juilt','juilp','juilh','juim','juib','juibs','juis','juiss','juing','juij','juich','juik','juit','juip','juih','ji','jig','jikk','jigs','jin','jinj','jinh','jid','jil','jilg','jilm','jilb','jils','jilt','jilp','jilh','jim','jib','jibs','jis','jiss','jing','jij','jich','jik','jit','jip','jih','jja','jjag','jjakk','jjags','jjan','jjanj','jjanh','jjad','jjal','jjalg','jjalm','jjalb','jjals','jjalt','jjalp','jjalh','jjam','jjab','jjabs','jjas','jjass','jjang','jjaj','jjach','jjak','jjat','jjap','jjah','jjae','jjaeg','jjaekk','jjaegs','jjaen','jjaenj','jjaenh','jjaed')