b=('gwan','gwanj','gwanh','gwad','gwal','gwalg','gwalm','gwalb','gwals','gwalt','gwalp','gwalh','gwam','gwab','gwabs','gwas','gwass','gwang','gwaj','gwach','gwak','gwat','gwap','gwah','gwae','gwaeg','gwaekk','gwaegs','gwaen','gwaenj','gwaenh','gwaed','gwael','gwaelg','gwaelm','gwaelb','gwaels','gwaelt','gwaelp','gwaelh','gwaem','gwaeb','gwaebs','gwaes','gwaess','gwaeng','gwaej','gwaech','gwaek','gwaet','gwaep','gwaeh','goe','goeg','goekk','goegs','goen','goenj','goenh','goed','goel','goelg','goelm','goelb','goels','goelt','goelp','goelh','goem','goeb','goebs','goes','goess','goeng','goej','goech','goek','goet','goep','goeh','gyo','gyog','gyokk','gyogs','gyon','gyonj','gyonh','gyod','gyol','gyolg','gyolm','gyolb','gyols','gyolt','gyolp','gyolh','gyom','gyob','gyobs','gyos','gyoss','gyong','gyoj','gyoch','gyok','gyot','gyop','gyoh','gu','gug','gukk','gugs','gun','gunj','gunh','gud','gul','gulg','gulm','gulb','guls','gult','gulp','gulh','gum','gub','gubs','gus','guss','gung','guj','guch','guk','gut','gup','guh','gwo','gwog','gwokk','gwogs','gwon','gwonj','gwonh','gwod','gwol','gwolg','gwolm','gwolb','gwols','gwolt','gwolp','gwolh','gwom','gwob','gwobs','gwos','gwoss','gwong','gwoj','gwoch','gwok','gwot','gwop','gwoh','gwe','gweg','gwekk','gwegs','gwen','gwenj','gwenh','gwed','gwel','gwelg','gwelm','gwelb','gwels','gwelt','gwelp','gwelh','gwem','gweb','gwebs','gwes','gwess','gweng','gwej','gwech','gwek','gwet','gwep','gweh','gwi','gwig','gwikk','gwigs','gwin','gwinj','gwinh','gwid','gwil','gwilg','gwilm','gwilb','gwils','gwilt','gwilp','gwilh','gwim','gwib','gwibs','gwis','gwiss','gwing','gwij','gwich','gwik','gwit','gwip','gwih','gyu','gyug','gyukk','gyugs','gyun','gyunj','gyunh','gyud','gyul','gyulg','gyulm','gyulb','gyuls','gyult','gyulp','gyulh','gyum','gyub','gyubs','gyus','gyuss','gyung','gyuj','gyuch','gyuk','gyut','gyup','gyuh','geu','geug','geukk','geugs','geun','geunj','geunh','geud')