b=('Xiao','Suo','Li','Zeng','Chu','Guo','Gao','E','Xiu','Cuo','Lue','Feng','Xin','Liu','Kai','Jian','Rui','Ti','Lang','Qin','Ju','A','Qiang','Zhe','Nuo','Cuo','Mao','Ben','Qi','De','Ke','Kun','Chang','Xi','Gu','Luo','Chui','Zhui','Jin','Zhi','Xian','Juan','Huo','Pei','Tan','Ding','Jian','Ju','Meng','Zi','Qie','Ying','Kai','Qiang','Si','E','Cha','Qiao','Zhong','Duan','Sou','Huang','Huan','Ai','Du','Mei','Lou','Zi','Fei','Mei','Mo','Zhen','Bo','Ge','Nie','Tang','Juan','Nie','Na','Liu','Gao','Bang','Yi','Jia','Bin','Rong','Biao','Tang','Man','Luo','Beng','Yong','Jing','Di','Zu','Xuan','Liu','Chan','Jue','Liao','Pu','Lu','Dui','Lan','Pu','Cuan','Qiang','Deng','Huo','Lei','Huan','Zhuo','Lian','Yi','Cha','Biao','La','Chan','Xiang','Zhang','Chang','Jiu','Ao','Die','Qu','Liao','Mi','Zhang','Men','Ma','Shuan','Shan','Huo','Men','Yan','Bi','Han','Bi','Shan','Kai','Kang','Beng','Hong','Run','San','Xian','Xian','Jian','Min','Xia','Shui','Dou','Zha','Nao','Zhan','Peng','Xia','Ling','Bian','Bi','Run','Ai','Guan','Ge','Ge','Fa','Chu','Hong','Gui','Min','Se','Kun','Lang','Lu','Ting','Sha','Ju','Yue','Yue','Chan','Qu','Lin','Chang','Shai','Kun','Yan','Wen','Yan','E','Hun','Yu','Wen','Hong','Bao','Hong','Qu','Yao','Wen','Ban','An','Wei','Yin','Kuo','Que','Lan','Du','Quan','Feng','Tian','Nie','Ta','Kai','He','Que','Chuang','Guan','Dou','Qi','Kui','Tang','Guan','Piao','Kan','Xi','Hui','Chan','Pi','Dang','Huan','Ta','Wen','Ta','Men','Shuan','Shan','Yan','Han','Bi','Wen','Chuang','Run','Wei','Xian','Hong','Jian','Min','Kang','Men','Zha','Nao','Gui','Wen','Ta','Min','Lu','Kai')