b=('Xu','Ji','Mu','Chen','Xiao','Zha','Ting','Zhen','Pei','Mei','Ling','Qi','Zhou','Huo','Sha','Fei','Hong','Zhan','Yin','Ni','Zhu','Tun','Lin','Ling','Dong','Ying','Wu','Ling','Shuang','Ling','Xia','Hong','Yin','Mai','Mai','Yun','Liu','Meng','Bin','Wu','Wei','Kuo','Yin','Xi','Yi','Ai','Dan','Teng','San','Yu','Lu','Long','Dai','Ji','Pang','Yang','Ba','Pi','Wei','Feng','Xi','Ji','Mai','Meng','Meng','Lei','Li','Huo','Ai','Fei','Dai','Long','Ling','Ai','Feng','Li','Bao','He','He','He','Bing','Qing','Qing','Jing','Tian','Zhen','Jing','Cheng','Qing','Jing','Jing','Dian','Jing','Tian','Fei','Fei','Kao','Mi','Mian','Mian','Bao','Ye','Tian','Hui','Ye','Ge','Ding','Cha','Qian','Ren','Di','Du','Wu','Ren','Qin','Jin','Xue','Niu','Ba','Yin','Sa','Na','Mo','Zu','Da','Ban','Yi','Yao','Tao','Bei','Jie','Hong','Pao','Yang','Bing','Yin','Ge','Tao','Jie','Xie','An','An','Hen','Gong','Qia','Da','Qiao','Ting','Man','Ying','Sui','Tiao','Qiao','Xuan','Kong','Beng','Ta','Shang','Bing','Kuo','Ju','La','Xie','Rou','Bang','Eng','Qiu','Qiu','He','Qiao','Mu','Ju','Jian','Bian','Di','Jian','Wen','Tao','Gou','Ta','Bei','Xie','Pan','Ge','Bi','Kuo','Tang','Lou','Gui','Qiao','Xue','Ji','Jian','Jiang','Chan','Da','Hu','Xian','Qian','Du','Wa','Jian','Lan','Wei','Ren','Fu','Mei','Quan','Ge','Wei','Qiao','Han','Chang','Kuo','Rou','Yun','She','Wei','Ge','Bai','Tao','Gou','Yun','Gao','Bi','Wei','Sui','Du','Wa','Du','Wei','Ren','Fu','Han','Wei','Yun','Tao','Jiu','Jiu','Xian','Xie','Xian','Ji','Yin','Za','Yun','Shao','Le','Peng','Huang','Ying','Yun','Peng','An','Yin','Xiang')