b=('chwik','chwit','chwip','chwih','chyu','chyug','chyukk','chyugs','chyun','chyunj','chyunh','chyud','chyul','chyulg','chyulm','chyulb','chyuls','chyult','chyulp','chyulh','chyum','chyub','chyubs','chyus','chyuss','chyung','chyuj','chyuch','chyuk','chyut','chyup','chyuh','cheu','cheug','cheukk','cheugs','cheun','cheunj','cheunh','cheud','cheul','cheulg','cheulm','cheulb','cheuls','cheult','cheulp','cheulh','cheum','cheub','cheubs','cheus','cheuss','cheung','cheuj','cheuch','cheuk','cheut','cheup','cheuh','chui','chuig','chuikk','chuigs','chuin','chuinj','chuinh','chuid','chuil','chuilg','chuilm','chuilb','chuils','chuilt','chuilp','chuilh','chuim','chuib','chuibs','chuis','chuiss','chuing','chuij','chuich','chuik','chuit','chuip','chuih','chi','chig','chikk','chigs','chin','chinj','chinh','chid','chil','chilg','chilm','chilb','chils','chilt','chilp','chilh','chim','chib','chibs','chis','chiss','ching','chij','chich','chik','chit','chip','chih','ka','kag','kakk','kags','kan','kanj','kanh','kad','kal','kalg','kalm','kalb','kals','kalt','kalp','kalh','kam','kab','kabs','kas','kass','kang','kaj','kach','kak','kat','kap','kah','kae','kaeg','kaekk','kaegs','kaen','kaenj','kaenh','kaed','kael','kaelg','kaelm','kaelb','kaels','kaelt','kaelp','kaelh','kaem','kaeb','kaebs','kaes','kaess','kaeng','kaej','kaech','kaek','kaet','kaep','kaeh','kya','kyag','kyakk','kyags','kyan','kyanj','kyanh','kyad','kyal','kyalg','kyalm','kyalb','kyals','kyalt','kyalp','kyalh','kyam','kyab','kyabs','kyas','kyass','kyang','kyaj','kyach','kyak','kyat','kyap','kyah','kyae','kyaeg','kyaekk','kyaegs','kyaen','kyaenj','kyaenh','kyaed','kyael','kyaelg','kyaelm','kyaelb','kyaels','kyaelt','kyaelp','kyaelh','kyaem','kyaeb','kyaebs','kyaes','kyaess','kyaeng','kyaej','kyaech','kyaek','kyaet','kyaep','kyaeh','keo','keog','keokk','keogs','keon','keonj','keonh','keod','keol','keolg','keolm','keolb','keols','keolt','keolp','keolh','keom','keob','keobs','keos','keoss','keong','keoj','keoch','keok','keot','keop','keoh')