b=('ke','keg','kekk','kegs','ken','kenj','kenh','ked','kel','kelg','kelm','kelb','kels','kelt','kelp','kelh','kem','keb','kebs','kes','kess','keng','kej','kech','kek','ket','kep','keh','kyeo','kyeog','kyeokk','kyeogs','kyeon','kyeonj','kyeonh','kyeod','kyeol','kyeolg','kyeolm','kyeolb','kyeols','kyeolt','kyeolp','kyeolh','kyeom','kyeob','kyeobs','kyeos','kyeoss','kyeong','kyeoj','kyeoch','kyeok','kyeot','kyeop','kyeoh','kye','kyeg','kyekk','kyegs','kyen','kyenj','kyenh','kyed','kyel','kyelg','kyelm','kyelb','kyels','kyelt','kyelp','kyelh','kyem','kyeb','kyebs','kyes','kyess','kyeng','kyej','kyech','kyek','kyet','kyep','kyeh','ko','kog','kokk','kogs','kon','konj','konh','kod','kol','kolg','kolm','kolb','kols','kolt','kolp','kolh','kom','kob','kobs','kos','koss','kong','koj','koch','kok','kot','kop','koh','kwa','kwag','kwakk','kwags','kwan','kwanj','kwanh','kwad','kwal','kwalg','kwalm','kwalb','kwals','kwalt','kwalp','kwalh','kwam','kwab','kwabs','kwas','kwass','kwang','kwaj','kwach','kwak','kwat','kwap','kwah','kwae','kwaeg','kwaekk','kwaegs','kwaen','kwaenj','kwaenh','kwaed','kwael','kwaelg','kwaelm','kwaelb','kwaels','kwaelt','kwaelp','kwaelh','kwaem','kwaeb','kwaebs','kwaes','kwaess','kwaeng','kwaej','kwaech','kwaek','kwaet','kwaep','kwaeh','koe','koeg','koekk','koegs','koen','koenj','koenh','koed','koel','koelg','koelm','koelb','koels','koelt','koelp','koelh','koem','koeb','koebs','koes','koess','koeng','koej','koech','koek','koet','koep','koeh','kyo','kyog','kyokk','kyogs','kyon','kyonj','kyonh','kyod','kyol','kyolg','kyolm','kyolb','kyols','kyolt','kyolp','kyolh','kyom','kyob','kyobs','kyos','kyoss','kyong','kyoj','kyoch','kyok','kyot','kyop','kyoh','ku','kug','kukk','kugs','kun','kunj','kunh','kud','kul','kulg','kulm','kulb','kuls','kult','kulp','kulh','kum','kub','kubs','kus','kuss','kung','kuj','kuch','kuk','kut','kup','kuh','kwo','kwog','kwokk','kwogs')