b=('Bu','Zhang','Lei','Qiang','Man','Yan','Ling','Ji','Biao','Gun','Han','Di','Su','Lu','She','Shang','Di','Mie','Xun','Man','Bo','Di','Cuo','Zhe','Shen','Xuan','Wei','Hu','Ao','Mi','Lou','Cu','Zhong','Cai','Po','Jiang','Mi','Cong','Niao','Hui','Juan','Yin','Jian','Nian','Shu','Yin','Guo','Chen','Hu','Sha','Kou','Qian','Ma','Zang','Ze','Qiang','Dou','Lian','Lin','Kou','Ai','Bi','Li','Wei','Ji','Qian','Sheng','Fan','Meng','Ou','Chan','Dian','Xun','Jiao','Rui','Rui','Lei','Yu','Qiao','Chu','Hua','Jian','Mai','Yun','Bao','You','Qu','Lu','Rao','Hui','E','Ti','Fei','Jue','Zui','Fa','Ru','Fen','Kui','Shun','Rui','Ya','Xu','Fu','Jue','Dang','Wu','Dong','Si','Xiao','Xi','Long','Wen','Shao','Qi','Jian','Yun','Sun','Ling','Yu','Xia','Weng','Ji','Hong','Si','Nong','Lei','Xuan','Yun','Yu','Xi','Hao','Bao','Hao','Ai','Wei','Hui','Hui','Ji','Ci','Xiang','Wan','Mie','Yi','Leng','Jiang','Can','Shen','Qiang','Lian','Ke','Yuan','Da','Ti','Tang','Xue','Bi','Zhan','Sun','Xian','Fan','Ding','Xie','Gu','Xie','Shu','Jian','Hao','Hong','Sa','Xin','Xun','Yao','Bai','Sou','Shu','Xun','Dui','Pin','Wei','Ning','Chou','Mai','Ru','Piao','Tai','Ji','Zao','Chen','Zhen','Er','Ni','Ying','Gao','Cong','Xiao','Qi','Fa','Jian','Xu','Kui','Ji','Bian','Diao','Mi','Lan','Jin','Cang','Miao','Qiong','Qie','Xian','Liao','Ou','Xian','Su','Lu','Yi','Xu','Xie','Li','Yi','La','Lei','Jiao','Di','Zhi','Bei','Teng','Yao','Mo','Huan','Biao','Fan','Sou','Tan','Tui','Qiong','Qiao','Wei','Liu','Hui','Ou','Gao','Yun','Bao','Li','Shu','Chu','Ai','Lin','Zao','Xuan','Qin','Lai','Huo')