b=('pyuk','pyut','pyup','pyuh','peu','peug','peukk','peugs','peun','peunj','peunh','peud','peul','peulg','peulm','peulb','peuls','peult','peulp','peulh','peum','peub','peubs','peus','peuss','peung','peuj','peuch','peuk','peut','peup','peuh','pui','puig','puikk','puigs','puin','puinj','puinh','puid','puil','puilg','puilm','puilb','puils','puilt','puilp','puilh','puim','puib','puibs','puis','puiss','puing','puij','puich','puik','puit','puip','puih','pi','pig','pikk','pigs','pin','pinj','pinh','pid','pil','pilg','pilm','pilb','pils','pilt','pilp','pilh','pim','pib','pibs','pis','piss','ping','pij','pich','pik','pit','pip','pih','ha','hag','hakk','hags','han','hanj','hanh','had','hal','halg','halm','halb','hals','halt','halp','halh','ham','hab','habs','has','hass','hang','haj','hach','hak','hat','hap','hah','hae','haeg','haekk','haegs','haen','haenj','haenh','haed','hael','haelg','haelm','haelb','haels','haelt','haelp','haelh','haem','haeb','haebs','haes','haess','haeng','haej','haech','haek','haet','haep','haeh','hya','hyag','hyakk','hyags','hyan','hyanj','hyanh','hyad','hyal','hyalg','hyalm','hyalb','hyals','hyalt','hyalp','hyalh','hyam','hyab','hyabs','hyas','hyass','hyang','hyaj','hyach','hyak','hyat','hyap','hyah','hyae','hyaeg','hyaekk','hyaegs','hyaen','hyaenj','hyaenh','hyaed','hyael','hyaelg','hyaelm','hyaelb','hyaels','hyaelt','hyaelp','hyaelh','hyaem','hyaeb','hyaebs','hyaes','hyaess','hyaeng','hyaej','hyaech','hyaek','hyaet','hyaep','hyaeh','heo','heog','heokk','heogs','heon','heonj','heonh','heod','heol','heolg','heolm','heolb','heols','heolt','heolp','heolh','heom','heob','heobs','heos','heoss','heong','heoj','heoch','heok','heot','heop','heoh','he','heg','hekk','hegs','hen','henj','henh','hed','hel','helg','helm','helb','hels','helt','help','helh','hem','heb','hebs','hes','hess','heng','hej','hech','hek','het','hep','heh')