b=('dae','daeg','daekk','daegs','daen','daenj','daenh','daed','dael','daelg','daelm','daelb','daels','daelt','daelp','daelh','daem','daeb','daebs','daes','daess','daeng','daej','daech','daek','daet','daep','daeh','dya','dyag','dyakk','dyags','dyan','dyanj','dyanh','dyad','dyal','dyalg','dyalm','dyalb','dyals','dyalt','dyalp','dyalh','dyam','dyab','dyabs','dyas','dyass','dyang','dyaj','dyach','dyak','dyat','dyap','dyah','dyae','dyaeg','dyaekk','dyaegs','dyaen','dyaenj','dyaenh','dyaed','dyael','dyaelg','dyaelm','dyaelb','dyaels','dyaelt','dyaelp','dyaelh','dyaem','dyaeb','dyaebs','dyaes','dyaess','dyaeng','dyaej','dyaech','dyaek','dyaet','dyaep','dyaeh','deo','deog','deokk','deogs','deon','deonj','deonh','deod','deol','deolg','deolm','deolb','deols','deolt','deolp','deolh','deom','deob','deobs','deos','deoss','deong','deoj','deoch','deok','deot','deop','deoh','de','deg','dekk','degs','den','denj','denh','ded','del','delg','delm','delb','dels','delt','delp','delh','dem','deb','debs','des','dess','deng','dej','dech','dek','det','dep','deh','dyeo','dyeog','dyeokk','dyeogs','dyeon','dyeonj','dyeonh','dyeod','dyeol','dyeolg','dyeolm','dyeolb','dyeols','dyeolt','dyeolp','dyeolh','dyeom','dyeob','dyeobs','dyeos','dyeoss','dyeong','dyeoj','dyeoch','dyeok','dyeot','dyeop','dyeoh','dye','dyeg','dyekk','dyegs','dyen','dyenj','dyenh','dyed','dyel','dyelg','dyelm','dyelb','dyels','dyelt','dyelp','dyelh','dyem','dyeb','dyebs','dyes','dyess','dyeng','dyej','dyech','dyek','dyet','dyep','dyeh','do','dog','dokk','dogs','don','donj','donh','dod','dol','dolg','dolm','dolb','dols','dolt','dolp','dolh','dom','dob','dobs','dos','doss','dong','doj','doch','dok','dot','dop','doh','dwa','dwag','dwakk','dwags','dwan','dwanj','dwanh','dwad','dwal','dwalg','dwalm','dwalb','dwals','dwalt','dwalp','dwalh','dwam','dwab','dwabs','dwas','dwass','dwang','dwaj','dwach','dwak','dwat','dwap','dwah','dwae','dwaeg','dwaekk','dwaegs')