b=('Pan','Yang','Lei','Ca','Shu','Zan','Nian','Xian','Jun','Huo','Li','La','Huan','Ying','Lu','Long','Qian','Qian','Zan','Qian','Lan','Xian','Ying','Mei','Rang','Chan','Weng','Cuan','Xie','She','Luo','Jun','Mi','Chi','Zan','Luan','Tan','Zuan','Li','Dian','Wa','Dang','Jiao','Jue','Lan','Li','Nang','Zhi','Gui','Gui','Qi','Xun','Pu','Pu','Shou','Kao','You','Gai','Yi','Gong','Gan','Ban','Fang','Zheng','Po','Dian','Kou','Min','Wu','Gu','He','Ce','Xiao','Mi','Chu','Ge','Di','Xu','Jiao','Min','Chen','Jiu','Shen','Duo','Yu','Chi','Ao','Bai','Xu','Jiao','Duo','Lian','Nie','Bi','Chang','Dian','Duo','Yi','Gan','San','Ke','Yan','Dun','Ji','Tou','Xiao','Duo','Jiao','Jing','Yang','Xia','Min','Shu','Ai','Qiao','Ai','Zheng','Di','Zhen','Fu','Shu','Liao','Qu','Xiong','Yi','Jiao','Shan','Jiao','Zhuo','Yi','Lian','Bi','Li','Xiao','Xiao','Wen','Xue','Qi','Qi','Zhai','Bin','Jue','Zhai','Lang','Fei','Ban','Ban','Lan','Yu','Lan','Wei','Dou','Sheng','Liao','Jia','Hu','Xie','Jia','Yu','Zhen','Jiao','Wo','Tiao','Dou','Jin','Chi','Yin','Fu','Qiang','Zhan','Qu','Zhuo','Zhan','Duan','Cuo','Si','Xin','Zhuo','Zhuo','Qin','Lin','Zhuo','Chu','Duan','Zhu','Fang','Chan','Hang','Yu','Shi','Pei','You','Mei','Pang','Qi','Zhan','Mao','Lu','Pei','Pi','Liu','Fu','Fang','Xuan','Jing','Jing','Ni','Zu','Zhao','Yi','Liu','Shao','Jian','Yu','Yi','Qi','Zhi','Fan','Piao','Fan','Zhan','Kuai','Sui','Yu','Wu','Ji','Ji','Ji','Huo','Ri','Dan','Jiu','Zhi','Zao','Xie','Tiao','Xun','Xu','Ga','La','Gan','Han','Tai','Di','Xu','Chan','Shi','Kuang','Yang','Shi','Wang','Min','Min','Tun','Chun','Wu')