b=('Qiao','Chou','Bei','Xuan','Wei','Ge','Qian','Wei','Yu','Yu','Bi','Xuan','Huan','Min','Bi','Yi','Mian','Yong','Kai','Dang','Yin','E','Chen','Mao','Qia','Ke','Yu','Ai','Qie','Yan','Nuo','Gan','Yun','Zong','Sai','Leng','Fen','Ying','Kui','Kui','Que','Gong','Yun','Su','Su','Qi','Yao','Song','Huang','Ji','Gu','Ju','Chuang','Ni','Xie','Kai','Zheng','Yong','Cao','Xun','Shen','Bo','Kai','Yuan','Xi','Hun','Yong','Yang','Li','Sao','Tao','Yin','Ci','Xu','Qian','Tai','Huang','Yun','Shen','Ming','Gong','She','Cong','Piao','Mu','Mu','Guo','Chi','Can','Can','Can','Cui','Min','Te','Zhang','Tong','Ao','Shuang','Man','Guan','Que','Zao','Jiu','Hui','Kai','Lian','Ou','Song','Qin','Yin','Lu','Shang','Wei','Tuan','Man','Qian','She','Yong','Qing','Kang','Di','Zhi','Lou','Juan','Qi','Qi','Yu','Ping','Liao','Cong','You','Chong','Zhi','Tong','Cheng','Qi','Qu','Peng','Bei','Bie','Qiong','Jiao','Zeng','Chi','Lian','Ping','Kui','Hui','Qiao','Cheng','Yin','Yin','Xi','Xi','Dan','Tan','Duo','Dui','Dui','Su','Jue','Ce','Xiao','Fan','Fen','Lao','Lao','Chong','Han','Qi','Xian','Min','Jing','Liao','Wu','Can','Jue','Cu','Xian','Tan','Sheng','Pi','Yi','Chu','Xian','Nao','Dan','Tan','Jing','Song','Han','Jiao','Wei','Xuan','Dong','Qin','Qin','Ju','Cao','Ken','Xie','Ying','Ao','Mao','Yi','Lin','Se','Jun','Huai','Men','Lan','Ai','Lin','Yan','Kuo','Xia','Chi','Yu','Yin','Dai','Meng','Ai','Meng','Dui','Qi','Mo','Lan','Men','Chou','Zhi','Nuo','Nuo','Yan','Yang','Bo','Zhi','Kuang','Kuang','You','Fu','Liu','Mie','Cheng','Hui','Chan','Meng','Lan','Huai','Xuan','Rang','Chan','Ji','Ju','Huan','She','Yi')