b=('tim','tib','tibs','tis','tiss','ting','tij','tich','tik','tit','tip','tih','pa','pag','pakk','pags','pan','panj','panh','pad','pal','palg','palm','palb','pals','palt','palp','palh','pam','pab','pabs','pas','pass','pang','paj','pach','pak','pat','pap','pah','pae','paeg','paekk','paegs','paen','paenj','paenh','paed','pael','paelg','paelm','paelb','paels','paelt','paelp','paelh','paem','paeb','paebs','paes','paess','paeng','paej','paech','paek','paet','paep','paeh','pya','pyag','pyakk','pyags','pyan','pyanj','pyanh','pyad','pyal','pyalg','pyalm','pyalb','pyals','pyalt','pyalp','pyalh','pyam','pyab','pyabs','pyas','pyass','pyang','pyaj','pyach','pyak','pyat','pyap','pyah','pyae','pyaeg','pyaekk','pyaegs','pyaen','pyaenj','pyaenh','pyaed','pyael','pyaelg','pyaelm','pyaelb','pyaels','pyaelt','pyaelp','pyaelh','pyaem','pyaeb','pyaebs','pyaes','pyaess','pyaeng','pyaej','pyaech','pyaek','pyaet','pyaep','pyaeh','peo','peog','peokk','peogs','peon','peonj','peonh','peod','peol','peolg','peolm','peolb','peols','peolt','peolp','peolh','peom','peob','peobs','peos','peoss','peong','peoj','peoch','peok','peot','peop','peoh','pe','peg','pekk','pegs','pen','penj','penh','ped','pel','pelg','pelm','pelb','pels','pelt','pelp','pelh','pem','peb','pebs','pes','pess','peng','pej','pech','pek','pet','pep','peh','pyeo','pyeog','pyeokk','pyeogs','pyeon','pyeonj','pyeonh','pyeod','pyeol','pyeolg','pyeolm','pyeolb','pyeols','pyeolt','pyeolp','pyeolh','pyeom','pyeob','pyeobs','pyeos','pyeoss','pyeong','pyeoj','pyeoch','pyeok','pyeot','pyeop','pyeoh','pye','pyeg','pyekk','pyegs','pyen','pyenj','pyenh','pyed','pyel','pyelg','pyelm','pyelb','pyels','pyelt','pyelp','pyelh','pyem','pyeb','pyebs','pyes','pyess','pyeng','pyej','pyech','pyek','pyet','pyep','pyeh','po','pog','pokk','pogs','pon','ponj','ponh','pod','pol','polg','polm','polb','pols','polt','polp','polh','pom','pob','pobs','pos')