b=('yeoss','yeong','yeoj','yeoch','yeok','yeot','yeop','yeoh','ye','yeg','yekk','yegs','yen','yenj','yenh','yed','yel','yelg','yelm','yelb','yels','yelt','yelp','yelh','yem','yeb','yebs','yes','yess','yeng','yej','yech','yek','yet','yep','yeh','o','og','okk','ogs','on','onj','onh','od','ol','olg','olm','olb','ols','olt','olp','olh','om','ob','obs','os','oss','ong','oj','och','ok','ot','op','oh','wa','wag','wakk','wags','wan','wanj','wanh','wad','wal','walg','walm','walb','wals','walt','walp','walh','wam','wab','wabs','was','wass','wang','waj','wach','wak','wat','wap','wah','wae','waeg','waekk','waegs','waen','waenj','waenh','waed','wael','waelg','waelm','waelb','waels','waelt','waelp','waelh','waem','waeb','waebs','waes','waess','waeng','waej','waech','waek','waet','waep','waeh','oe','oeg','oekk','oegs','oen','oenj','oenh','oed','oel','oelg','oelm','oelb','oels','oelt','oelp','oelh','oem','oeb','oebs','oes','oess','oeng','oej','oech','oek','oet','oep','oeh','yo','yog','yokk','yogs','yon','yonj','yonh','yod','yol','yolg','yolm','yolb','yols','yolt','yolp','yolh','yom','yob','yobs','yos','yoss','yong','yoj','yoch','yok','yot','yop','yoh','u','ug','ukk','ugs','un','unj','unh','ud','ul','ulg','ulm','ulb','uls','ult','ulp','ulh','um','ub','ubs','us','uss','ung','uj','uch','uk','ut','up','uh','wo','wog','wokk','wogs','won','wonj','wonh','wod','wol','wolg','wolm','wolb','wols','wolt','wolp','wolh','wom','wob','wobs','wos','woss','wong','woj','woch','wok','wot','wop','woh','we','weg','wekk','wegs','wen','wenj','wenh','wed','wel','welg','welm','welb','wels','welt','welp','welh','wem','web','webs','wes','wess','weng','wej','wech')