b=('poss','pong','poj','poch','pok','pot','pop','poh','pwa','pwag','pwakk','pwags','pwan','pwanj','pwanh','pwad','pwal','pwalg','pwalm','pwalb','pwals','pwalt','pwalp','pwalh','pwam','pwab','pwabs','pwas','pwass','pwang','pwaj','pwach','pwak','pwat','pwap','pwah','pwae','pwaeg','pwaekk','pwaegs','pwaen','pwaenj','pwaenh','pwaed','pwael','pwaelg','pwaelm','pwaelb','pwaels','pwaelt','pwaelp','pwaelh','pwaem','pwaeb','pwaebs','pwaes','pwaess','pwaeng','pwaej','pwaech','pwaek','pwaet','pwaep','pwaeh','poe','poeg','poekk','poegs','poen','poenj','poenh','poed','poel','poelg','poelm','poelb','poels','poelt','poelp','poelh','poem','poeb','poebs','poes','poess','poeng','poej','poech','poek','poet','poep','poeh','pyo','pyog','pyokk','pyogs','pyon','pyonj','pyonh','pyod','pyol','pyolg','pyolm','pyolb','pyols','pyolt','pyolp','pyolh','pyom','pyob','pyobs','pyos','pyoss','pyong','pyoj','pyoch','pyok','pyot','pyop','pyoh','pu','pug','pukk','pugs','pun','punj','punh','pud','pul','pulg','pulm','pulb','puls','pult','pulp','pulh','pum','pub','pubs','pus','puss','pung','puj','puch','puk','put','pup','puh','pwo','pwog','pwokk','pwogs','pwon','pwonj','pwonh','pwod','pwol','pwolg','pwolm','pwolb','pwols','pwolt','pwolp','pwolh','pwom','pwob','pwobs','pwos','pwoss','pwong','pwoj','pwoch','pwok','pwot','pwop','pwoh','pwe','pweg','pwekk','pwegs','pwen','pwenj','pwenh','pwed','pwel','pwelg','pwelm','pwelb','pwels','pwelt','pwelp','pwelh','pwem','pweb','pwebs','pwes','pwess','pweng','pwej','pwech','pwek','pwet','pwep','pweh','pwi','pwig','pwikk','pwigs','pwin','pwinj','pwinh','pwid','pwil','pwilg','pwilm','pwilb','pwils','pwilt','pwilp','pwilh','pwim','pwib','pwibs','pwis','pwiss','pwing','pwij','pwich','pwik','pwit','pwip','pwih','pyu','pyug','pyukk','pyugs','pyun','pyunj','pyunh','pyud','pyul','pyulg','pyulm','pyulb','pyuls','pyult','pyulp','pyulh','pyum','pyub','pyubs','pyus','pyuss','pyung','pyuj','pyuch')