b=('tyal','tyalg','tyalm','tyalb','tyals','tyalt','tyalp','tyalh','tyam','tyab','tyabs','tyas','tyass','tyang','tyaj','tyach','tyak','tyat','tyap','tyah','tyae','tyaeg','tyaekk','tyaegs','tyaen','tyaenj','tyaenh','tyaed','tyael','tyaelg','tyaelm','tyaelb','tyaels','tyaelt','tyaelp','tyaelh','tyaem','tyaeb','tyaebs','tyaes','tyaess','tyaeng','tyaej','tyaech','tyaek','tyaet','tyaep','tyaeh','teo','teog','teokk','teogs','teon','teonj','teonh','teod','teol','teolg','teolm','teolb','teols','teolt','teolp','teolh','teom','teob','teobs','teos','teoss','teong','teoj','teoch','teok','teot','teop','teoh','te','teg','tekk','tegs','ten','tenj','tenh','ted','tel','telg','telm','telb','tels','telt','telp','telh','tem','teb','tebs','tes','tess','teng','tej','tech','tek','tet','tep','teh','tyeo','tyeog','tyeokk','tyeogs','tyeon','tyeonj','tyeonh','tyeod','tyeol','tyeolg','tyeolm','tyeolb','tyeols','tyeolt','tyeolp','tyeolh','tyeom','tyeob','tyeobs','tyeos','tyeoss','tyeong','tyeoj','tyeoch','tyeok','tyeot','tyeop','tyeoh','tye','tyeg','tyekk','tyegs','tyen','tyenj','tyenh','tyed','tyel','tyelg','tyelm','tyelb','tyels','tyelt','tyelp','tyelh','tyem','tyeb','tyebs','tyes','tyess','tyeng','tyej','tyech','tyek','tyet','tyep','tyeh','to','tog','tokk','togs','ton','tonj','tonh','tod','tol','tolg','tolm','tolb','tols','tolt','tolp','tolh','tom','tob','tobs','tos','toss','tong','toj','toch','tok','tot','top','toh','twa','twag','twakk','twags','twan','twanj','twanh','twad','twal','twalg','twalm','twalb','twals','twalt','twalp','twalh','twam','twab','twabs','twas','twass','twang','twaj','twach','twak','twat','twap','twah','twae','twaeg','twaekk','twaegs','twaen','twaenj','twaenh','twaed','twael','twaelg','twaelm','twaelb','twaels','twaelt','twaelp','twaelh','twaem','twaeb','twaebs','twaes','twaess','twaeng','twaej','twaech','twaek','twaet','twaep','twaeh','toe','toeg','toekk','toegs','toen','toenj','toenh','toed','toel','toelg','toelm','toelb')