b=('He','Lan','Biao','Rong','Li','Mo','Bao','Ruo','Lu','La','Ao','Xun','Kuang','Shuo','Liao','Li','Lu','Jue','Liao','Yan','Xi','Xie','Long','Ye','Can','Rang','Yue','Lan','Cong','Jue','Chong','Guan','Ju','Che','Mi','Tang','Lan','Zhu','Lan','Ling','Cuan','Yu','Zhao','Zhao','Pa','Zheng','Pao','Cheng','Yuan','Ai','Wei','Han','Jue','Jue','Fu','Ye','Ba','Die','Ye','Yao','Zu','Shuang','Er','Pan','Chuang','Ke','Zang','Die','Qiang','Yong','Qiang','Pian','Ban','Pan','Chao','Jian','Pai','Du','Chuang','Yu','Zha','Bian','Die','Bang','Bo','Chuang','You','You','Du','Ya','Cheng','Niu','Niu','Pin','Jiu','Mou','Ta','Mu','Lao','Ren','Mang','Fang','Mao','Mu','Gang','Wu','Yan','Ge','Bei','Si','Jian','Gu','You','Ge','Sheng','Mu','Di','Qian','Quan','Quan','Zi','Te','Xi','Mang','Keng','Qian','Wu','Gu','Xi','Li','Li','Pou','Ji','Gang','Zhi','Ben','Quan','Chun','Du','Ju','Jia','Jian','Feng','Pian','Ke','Ju','Kao','Chu','Xi','Bei','Luo','Jie','Ma','San','Wei','Mao','Dun','Tong','Qiao','Jiang','Xi','Li','Du','Lie','Pai','Piao','Bo','Xi','Chou','Wei','Kui','Chou','Quan','Quan','Ba','Fan','Qiu','Ji','Chai','Zhuo','An','Ge','Zhuang','Guang','Ma','You','Kang','Bo','Hou','Ya','Yin','Huan','Zhuang','Yun','Kuang','Niu','Di','Kuang','Zhong','Mu','Bei','Pi','Ju','Yi','Sheng','Pao','Xia','Tuo','Hu','Ling','Fei','Pi','Ni','Yao','You','Gou','Xue','Ju','Dan','Bo','Ku','Xian','Ning','Huan','Hen','Jiao','He','Zhao','Ji','Xun','Shan','Ta','Rong','Shou','Tong','Lao','Du','Xia','Shi','Kuai','Zheng','Yu','Sun','Yu','Bi','Mang','Xi','Juan','Li','Xia','Yin','Suan','Lang','Bei','Zhi','Yan')