b=('Mang','Zhu','Wan','Du','Ji','Jiao','Ba','Suan','Ji','Qin','Zhao','Sun','Ya','Zhui','Yuan','Hu','Hang','Xiao','Cen','Bi','Bi','Jian','Yi','Dong','Shan','Sheng','Da','Di','Zhu','Na','Chi','Gu','Li','Qie','Min','Bao','Tiao','Si','Fu','Ce','Ben','Fa','Da','Zi','Di','Ling','Ze','Nu','Fu','Gou','Fan','Jia','Gan','Fan','Shi','Mao','Po','Ti','Jian','Qiong','Long','Min','Bian','Luo','Gui','Qu','Chi','Yin','Yao','Xian','Bi','Qiong','Kuo','Deng','Xiao','Jin','Quan','Sun','Ru','Fa','Kuang','Zhu','Tong','Ji','Da','Hang','Ce','Zhong','Kou','Lai','Bi','Shai','Dang','Zheng','Ce','Fu','Yun','Tu','Pa','Li','Lang','Ju','Guan','Jian','Han','Tong','Xia','Zhi','Cheng','Suan','Shi','Zhu','Zuo','Xiao','Shao','Ting','Ce','Yan','Gao','Kuai','Gan','Chou','Kuang','Gang','Yun','O','Qian','Xiao','Jian','Pou','Lai','Zou','Bi','Bi','Bi','Ge','Tai','Guai','Yu','Jian','Dao','Gu','Chi','Zheng','Qing','Sha','Zhou','Lu','Bo','Ji','Lin','Suan','Jun','Fu','Zha','Gu','Kong','Qian','Qian','Jun','Chui','Guan','Yuan','Ce','Zu','Bo','Ze','Qie','Tuo','Luo','Dan','Xiao','Ruo','Jian','Xuan','Bian','Sun','Xiang','Xian','Ping','Zhen','Xing','Hu','Yi','Zhu','Yue','Chun','Lu','Wu','Dong','Shuo','Ji','Jie','Huang','Xing','Mei','Fan','Chuan','Zhuan','Pian','Feng','Zhu','Huang','Qie','Hou','Qiu','Miao','Qian','Gu','Kui','Shi','Lou','Yun','He','Tang','Yue','Chou','Gao','Fei','Ruo','Zheng','Gou','Nie','Qian','Xiao','Cuan','Long','Peng','Du','Li','Bi','Zhuo','Chu','Shai','Chi','Zhu','Qiang','Long','Lan','Jian','Bu','Li','Hui','Bi','Di','Cong','Yan','Peng','Can','Zhuan','Pi','Piao','Dou','Yu','Mie','Tuan')