b=('dit','dix','di','dip','diex','die','diep','dat','dax','da','dap','duox','duo','dot','dox','do','dop','dex','de','dep','dut','dux','du','dup','durx','dur','tit','tix','ti','tip','tiex','tie','tiep','tat','tax','ta','tap','tuot','tuox','tuo','tuop','tot','tox','to','top','tex','te','tep','tut','tux','tu','tup','turx','tur','ddit','ddix','ddi','ddip','ddiex','ddie','ddiep','ddat','ddax','dda','ddap','dduox','dduo','dduop','ddot','ddox','ddo','ddop','ddex','dde','ddep','ddut','ddux','ddu','ddup','ddurx','ddur','ndit','ndix','ndi','ndip','ndiex','ndie','ndat','ndax','nda','ndap','ndot','ndox','ndo','ndop','ndex','nde','ndep','ndut','ndux','ndu','ndup','ndurx','ndur','hnit','hnix','hni','hnip','hniet','hniex','hnie','hniep','hnat','hnax','hna','hnap','hnuox','hnuo','hnot','hnox','hnop','hnex','hne','hnep','hnut','nit','nix','ni','nip','niex','nie','niep','nax','na','nap','nuox','nuo','nuop','not','nox','no','nop','nex','ne','nep','nut','nux','nu','nup','nurx','nur','hlit','hlix','hli','hlip','hliex','hlie','hliep','hlat','hlax','hla','hlap','hluox','hluo','hluop','hlox','hlo','hlop','hlex','hle','hlep','hlut','hlux','hlu','hlup','hlurx','hlur','hlyt','hlyx','hly','hlyp','hlyrx','hlyr','lit','lix','li','lip','liet','liex','lie','liep','lat','lax','la','lap','luot','luox','luo','luop','lot','lox','lo','lop','lex','le','lep','lut','lux','lu','lup','lurx','lur','lyt','lyx','ly','lyp','lyrx','lyr','git','gix','gi','gip','giet','giex','gie','giep','gat','gax','ga','gap','guot','guox','guo','guop','got','gox','go','gop','get','gex','ge','gep','gut','gux','gu','gup','gurx','gur','kit','kix','ki','kip','kiex','kie','kiep','kat')