b=('chyess','chyeng','chyej','chyech','chyek','chyet','chyep','chyeh','cho','chog','chokk','chogs','chon','chonj','chonh','chod','chol','cholg','cholm','cholb','chols','cholt','cholp','cholh','chom','chob','chobs','chos','choss','chong','choj','choch','chok','chot','chop','choh','chwa','chwag','chwakk','chwags','chwan','chwanj','chwanh','chwad','chwal','chwalg','chwalm','chwalb','chwals','chwalt','chwalp','chwalh','chwam','chwab','chwabs','chwas','chwass','chwang','chwaj','chwach','chwak','chwat','chwap','chwah','chwae','chwaeg','chwaekk','chwaegs','chwaen','chwaenj','chwaenh','chwaed','chwael','chwaelg','chwaelm','chwaelb','chwaels','chwaelt','chwaelp','chwaelh','chwaem','chwaeb','chwaebs','chwaes','chwaess','chwaeng','chwaej','chwaech','chwaek','chwaet','chwaep','chwaeh','choe','choeg','choekk','choegs','choen','choenj','choenh','choed','choel','choelg','choelm','choelb','choels','choelt','choelp','choelh','choem','choeb','choebs','choes','choess','choeng','choej','choech','choek','choet','choep','choeh','chyo','chyog','chyokk','chyogs','chyon','chyonj','chyonh','chyod','chyol','chyolg','chyolm','chyolb','chyols','chyolt','chyolp','chyolh','chyom','chyob','chyobs','chyos','chyoss','chyong','chyoj','chyoch','chyok','chyot','chyop','chyoh','chu','chug','chukk','chugs','chun','chunj','chunh','chud','chul','chulg','chulm','chulb','chuls','chult','chulp','chulh','chum','chub','chubs','chus','chuss','chung','chuj','chuch','chuk','chut','chup','chuh','chwo','chwog','chwokk','chwogs','chwon','chwonj','chwonh','chwod','chwol','chwolg','chwolm','chwolb','chwols','chwolt','chwolp','chwolh','chwom','chwob','chwobs','chwos','chwoss','chwong','chwoj','chwoch','chwok','chwot','chwop','chwoh','chwe','chweg','chwekk','chwegs','chwen','chwenj','chwenh','chwed','chwel','chwelg','chwelm','chwelb','chwels','chwelt','chwelp','chwelh','chwem','chweb','chwebs','chwes','chwess','chweng','chwej','chwech','chwek','chwet','chwep','chweh','chwi','chwig','chwikk','chwigs','chwin','chwinj','chwinh','chwid','chwil','chwilg','chwilm','chwilb','chwils','chwilt','chwilp','chwilh','chwim','chwib','chwibs','chwis','chwiss','chwing','chwij','chwich')